@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance <licensing@enovance.com>
+# Copyright 2013 eNovance <licensing@enovance.com>
 #
 # Authors: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
 #
@@ -20,15 +19,16 @@
 import abc
 import croniter
 import datetime
-import pytz
 
 from ceilometerclient import client as ceiloclient
 from oslo.config import cfg
+from oslo.utils import timeutils
+import pytz
 import six
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import timeutils
+
 
 LOG = log.getLogger(__name__)
 
@@ -36,6 +36,8 @@ UNKNOWN = 'insufficient data'
 OK = 'ok'
 ALARM = 'alarm'
 
+cfg.CONF.import_group('service_credentials', 'ceilometer.service')
+
 
 @six.add_metaclass(abc.ABCMeta)
 class Evaluator(object):
@@ -84,13 +86,14 @@ class Evaluator(object):
 
     @classmethod
     def within_time_constraint(cls, alarm):
-        """Check whether the alarm is within at least one of its time
-        constraints. If there are none, then the answer is yes.
+        """Check whether the alarm is within at least one of its time limits.
+
+        If there are none, then the answer is yes.
         """
         if not alarm.time_constraints:
             return True
 
-        now_utc = timeutils.utcnow()
+        now_utc = timeutils.utcnow().replace(tzinfo=pytz.utc)
         for tc in alarm.time_constraints:
             tz = pytz.timezone(tc['timezone']) if tc['timezone'] else None
             now_tz = now_utc.astimezone(tz) if tz else now_utc
@@ -105,7 +108,9 @@ class Evaluator(object):
 
     @staticmethod
     def _is_exact_match(cron, ts):
-        """Handle edge case where if the timestamp is the same as the
+        """Handle edge in case when both parameters are equal.
+
+        Handle edge case where if the timestamp is the same as the
         cron point in time to the minute, croniter returns the previous
         start, not the current. We can check this by first going one
         step back and then one step forward and check if we are
@@ -117,8 +122,8 @@ class Evaluator(object):
 
     @abc.abstractmethod
     def evaluate(self, alarm):
-        '''interface definition
+        """Interface definition.
 
         evaluate an alarm
         alarm Alarm: an instance of the Alarm
-        '''
+        """
