@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Red Hat, Inc
+# Copyright 2013 Red Hat, Inc
 #
 # Author: Eoghan Glynn <eglynn@redhat.com>
 # Author: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
@@ -20,11 +19,12 @@
 import datetime
 import operator
 
+from oslo.utils import timeutils
+
 from ceilometer.alarm import evaluator
 from ceilometer.alarm.evaluator import utils
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import timeutils
 
 LOG = log.getLogger(__name__)
 
@@ -69,8 +69,7 @@ class ThresholdEvaluator(evaluator.Evaluator):
 
     @staticmethod
     def _sanitize(alarm, statistics):
-        """Sanitize statistics.
-        """
+        """Sanitize statistics."""
         LOG.debug(_('sanitize stats %s') % statistics)
         if alarm.rule.get('exclude_outliers'):
             key = operator.attrgetter('count')
@@ -104,8 +103,10 @@ class ThresholdEvaluator(evaluator.Evaluator):
             return []
 
     def _sufficient(self, alarm, statistics):
-        """Ensure there is sufficient data for evaluation,
-           transitioning to unknown otherwise.
+        """Check for the sufficiency of the data for evaluation.
+
+        Ensure there is sufficient data for evaluation, transitioning to
+        unknown otherwise.
         """
         sufficient = len(statistics) >= self.quorum
         if not sufficient and alarm.state != evaluator.UNKNOWN:
@@ -119,8 +120,7 @@ class ThresholdEvaluator(evaluator.Evaluator):
 
     @staticmethod
     def _reason_data(disposition, count, most_recent):
-        """Create a reason data dictionary for this evaluator type.
-        """
+        """Create a reason data dictionary for this evaluator type."""
         return {'type': 'threshold', 'disposition': disposition,
                 'count': count, 'most_recent': most_recent}
 
