@@ -1,7 +1,6 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Red Hat, Inc
-# Copyright © 2013 eNovance <licensing@enovance.com>
+# Copyright 2013 Red Hat, Inc
+# Copyright 2013 eNovance <licensing@enovance.com>
 #
 # Authors: Eoghan Glynn <eglynn@redhat.com>
 #          Julien Danjou <julien@danjou.info>
@@ -22,16 +21,16 @@ import abc
 
 from ceilometerclient import client as ceiloclient
 from oslo.config import cfg
+from oslo.utils import netutils
 import six
 from stevedore import extension
 
-from ceilometer.alarm.partition import coordination
+from ceilometer.alarm.partition import coordination as alarm_coordination
 from ceilometer.alarm import rpc as rpc_alarm
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer import coordination as coordination
+from ceilometer import messaging
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import network_utils
-from ceilometer.openstack.common.rpc import dispatcher as rpc_dispatcher
-from ceilometer.openstack.common.rpc import service as rpc_service
 from ceilometer.openstack.common import service as os_service
 
 
@@ -50,6 +49,8 @@ cfg.CONF.import_opt('notifier_rpc_topic', 'ceilometer.alarm.rpc',
                     group='alarm')
 cfg.CONF.import_opt('partition_rpc_topic', 'ceilometer.alarm.rpc',
                     group='alarm')
+cfg.CONF.import_opt('heartbeat', 'ceilometer.coordination',
+                    group='coordination')
 
 LOG = log.getLogger(__name__)
 
@@ -111,6 +112,45 @@ class AlarmService(object):
         pass
 
 
+class AlarmEvaluationService(AlarmService, os_service.Service):
+
+    PARTITIONING_GROUP_NAME = "alarm_evaluator"
+
+    def __init__(self):
+        super(AlarmEvaluationService, self).__init__()
+        self._load_evaluators()
+        self.api_client = None
+        self.partition_coordinator = coordination.PartitionCoordinator()
+
+    def start(self):
+        super(AlarmEvaluationService, self).start()
+        self.partition_coordinator.start()
+        self.partition_coordinator.join_group(self.PARTITIONING_GROUP_NAME)
+
+        # allow time for coordination if necessary
+        delay_start = self.partition_coordinator.is_active()
+
+        if self.evaluators:
+            interval = cfg.CONF.alarm.evaluation_interval
+            self.tg.add_timer(
+                interval,
+                self._evaluate_assigned_alarms,
+                initial_delay=interval if delay_start else None)
+        if self.partition_coordinator.is_active():
+            heartbeat_interval = min(cfg.CONF.coordination.heartbeat,
+                                     cfg.CONF.alarm.evaluation_interval / 4)
+            self.tg.add_timer(heartbeat_interval,
+                              self.partition_coordinator.heartbeat)
+        # Add a dummy thread to have wait() working
+        self.tg.add_timer(604800, lambda: None)
+
+    def _assigned_alarms(self):
+        all_alarms = self._client.alarms.list(q=[{'field': 'enabled',
+                                                  'value': True}])
+        return self.partition_coordinator.extract_my_subset(
+            self.PARTITIONING_GROUP_NAME, all_alarms)
+
+
 class SingletonAlarmService(AlarmService, os_service.Service):
 
     def __init__(self):
@@ -134,28 +174,17 @@ class SingletonAlarmService(AlarmService, os_service.Service):
                                             'value': True}])
 
 
-cfg.CONF.import_opt('host', 'ceilometer.service')
-
-
-class PartitionedAlarmService(AlarmService, rpc_service.Service):
+class PartitionedAlarmService(AlarmService, os_service.Service):
 
     def __init__(self):
-        super(PartitionedAlarmService, self).__init__(
-            cfg.CONF.host,
-            cfg.CONF.alarm.partition_rpc_topic,
-            self
-        )
+        super(PartitionedAlarmService, self).__init__()
+        transport = messaging.get_transport()
+        self.rpc_server = messaging.get_rpc_server(
+            transport, cfg.CONF.alarm.partition_rpc_topic, self)
+
         self._load_evaluators()
         self.api_client = None
-        self.partition_coordinator = coordination.PartitionCoordinator()
-
-    def initialize_service_hook(self, service):
-        LOG.debug(_('initialize_service_hooks'))
-        self.conn.create_worker(
-            cfg.CONF.alarm.partition_rpc_topic,
-            rpc_dispatcher.RpcDispatcher([self]),
-            'ceilometer.alarm.' + cfg.CONF.alarm.partition_rpc_topic,
-        )
+        self.partition_coordinator = alarm_coordination.PartitionCoordinator()
 
     def start(self):
         super(PartitionedAlarmService, self).start()
@@ -174,9 +203,14 @@ class PartitionedAlarmService(AlarmService, rpc_service.Service):
                 eval_interval,
                 self._evaluate_assigned_alarms,
                 eval_interval)
+        self.rpc_server.start()
         # Add a dummy thread to have wait() working
         self.tg.add_timer(604800, lambda: None)
 
+    def stop(self):
+        self.rpc_server.stop()
+        super(PartitionedAlarmService, self).stop()
+
     def _assigned_alarms(self):
         return self.partition_coordinator.assigned_alarms(self._client)
 
@@ -193,32 +227,34 @@ class PartitionedAlarmService(AlarmService, rpc_service.Service):
                                             data.get('alarms'))
 
 
-class AlarmNotifierService(rpc_service.Service):
+class AlarmNotifierService(os_service.Service):
 
     EXTENSIONS_NAMESPACE = "ceilometer.alarm.notifier"
 
-    def __init__(self, host, topic):
-        super(AlarmNotifierService, self).__init__(host, topic, self)
-        self.notifiers = extension.ExtensionManager(self.EXTENSIONS_NAMESPACE,
-                                                    invoke_on_load=True)
+    notifiers = extension.ExtensionManager(EXTENSIONS_NAMESPACE,
+                                           invoke_on_load=True)
+    notifiers_schemas = notifiers.map(lambda x: x.name)
+
+    def __init__(self):
+        super(AlarmNotifierService, self).__init__()
+        transport = messaging.get_transport()
+        self.rpc_server = messaging.get_rpc_server(
+            transport, cfg.CONF.alarm.notifier_rpc_topic, self)
 
     def start(self):
         super(AlarmNotifierService, self).start()
+        self.rpc_server.start()
         # Add a dummy thread to have wait() working
         self.tg.add_timer(604800, lambda: None)
 
-    def initialize_service_hook(self, service):
-        LOG.debug(_('initialize_service_hooks'))
-        self.conn.create_worker(
-            cfg.CONF.alarm.notifier_rpc_topic,
-            rpc_dispatcher.RpcDispatcher([self]),
-            'ceilometer.alarm.' + cfg.CONF.alarm.notifier_rpc_topic,
-        )
+    def stop(self):
+        self.rpc_server.stop()
+        super(AlarmNotifierService, self).stop()
 
     def _handle_action(self, action, alarm_id, previous,
                        current, reason, reason_data):
         try:
-            action = network_utils.urlsplit(action)
+            action = netutils.urlsplit(action)
         except Exception:
             LOG.error(
                 _("Unable to parse action %(action)s for alarm %(alarm_id)s"),
@@ -247,17 +283,16 @@ class AlarmNotifierService(rpc_service.Service):
     def notify_alarm(self, context, data):
         """Notify that alarm has been triggered.
 
-        data should be a dict with the following keys:
-        - actions, the URL of the action to run;
-          this is a mapped to extensions automatically
-        - alarm_id, the ID of the alarm that has been triggered
-        - previous, the previous state of the alarm
-        - current, the new state the alarm has transitioned to
-        - reason, the reason the alarm changed its state
-        - reason_data, a dict representation of the reason
+           :param context: Request context.
+           :param data: (dict):
 
-        :param context: Request context.
-        :param data: A dict as described above.
+             - actions, the URL of the action to run; this is mapped to
+               extensions automatically
+             - alarm_id, the ID of the alarm that has been triggered
+             - previous, the previous state of the alarm
+             - current, the new state the alarm has transitioned to
+             - reason, the reason the alarm changed its state
+             - reason_data, a dict representation of the reason
         """
         actions = data.get('actions')
         if not actions:
