@@ -1,6 +1,8 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 #
+# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -15,10 +17,8 @@
 """Simple logging storage backend.
 """
 
-from oslo_log import log
-
 from ceilometer.alarm.storage import base
-from ceilometer.i18n import _LI
+from ceilometer.openstack.common import log
 
 LOG = log.getLogger(__name__)
 
@@ -33,8 +33,7 @@ class Connection(base.Connection):
         pass
 
     def get_alarms(self, name=None, user=None, state=None, meter=None,
-                   project=None, enabled=None, alarm_id=None,
-                   alarm_type=None, severity=None):
+                   project=None, enabled=None, alarm_id=None, pagination=None):
         """Yields a lists of alarms that match filters."""
         return []
 
@@ -47,15 +46,4 @@ class Connection(base.Connection):
         return alarm
 
     def delete_alarm(self, alarm_id):
-        """Delete an alarm and its history data."""
-
-    def clear_expired_alarm_history_data(self, alarm_history_ttl):
-        """Clear expired alarm history data from the backend storage system.
-
-        Clearing occurs according to the time-to-live.
-
-        :param alarm_history_ttl: Number of seconds to keep alarm history
-                                  records for.
-        """
-        LOG.info(_LI('Dropping alarm history data with TTL %d'),
-                 alarm_history_ttl)
+        """Delete an alarm."""
