@@ -1,3 +1,7 @@
+#
+# Author: John Tran <jhtran@att.com>
+#         Julien Danjou <julien@danjou.info>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -13,19 +17,16 @@
 """SQLAlchemy storage backend."""
 
 from __future__ import absolute_import
-import datetime
 import os
 
-from oslo_config import cfg
-from oslo_db.sqlalchemy import session as db_session
-from oslo_log import log
-from oslo_utils import timeutils
+from oslo.config import cfg
+from oslo.db.sqlalchemy import session as db_session
 from sqlalchemy import desc
 
+import ceilometer
 from ceilometer.alarm.storage import base
 from ceilometer.alarm.storage import models as alarm_api_models
-from ceilometer.i18n import _LI
-from ceilometer import storage
+from ceilometer.openstack.common import log
 from ceilometer.storage.sqlalchemy import models
 from ceilometer.storage.sqlalchemy import utils as sql_utils
 from ceilometer import utils
@@ -80,20 +81,14 @@ class Connection(base.Connection):
     )
 
     def __init__(self, url):
-        # Set max_retries to 0, since oslo.db in certain cases may attempt
-        # to retry making the db connection retried max_retries ^ 2 times
-        # in failure case and db reconnection has already been implemented
-        # in storage.__init__.get_connection_from_config function
-        options = dict(cfg.CONF.database.items())
-        options['max_retries'] = 0
-        # oslo.db doesn't support options defined by Ceilometer
-        for opt in storage.OPTS:
-            options.pop(opt.name, None)
-        self._engine_facade = db_session.EngineFacade(url, **options)
+        self._engine_facade = db_session.EngineFacade(
+            url,
+            **dict(cfg.CONF.database.items())
+        )
 
     def upgrade(self):
         # NOTE(gordc): to minimise memory, only import migration when needed
-        from oslo_db.sqlalchemy import migration
+        from oslo.db.sqlalchemy import migration
         path = os.path.join(os.path.abspath(os.path.dirname(__file__)),
                             '..', '..', 'storage', 'sqlalchemy',
                             'migrate_repo')
@@ -103,6 +98,7 @@ class Connection(base.Connection):
         engine = self._engine_facade.get_engine()
         for table in reversed(models.Base.metadata.sorted_tables):
             engine.execute(table.delete())
+        self._engine_facade._session_maker.close_all()
         engine.dispose()
 
     def _retrieve_data(self, filter_expr, orderby, limit, table):
@@ -110,10 +106,8 @@ class Connection(base.Connection):
             return []
 
         session = self._engine_facade.get_session()
-        engine = self._engine_facade.get_engine()
         query = session.query(table)
-        transformer = sql_utils.QueryTransformer(table, query,
-                                                 dialect=engine.dialect.name)
+        transformer = sql_utils.QueryTransformer(table, query)
         if filter_expr is not None:
             transformer.apply_filter(filter_expr)
 
@@ -142,28 +136,27 @@ class Connection(base.Connection):
                                           row.insufficient_data_actions),
                                       rule=row.rule,
                                       time_constraints=row.time_constraints,
-                                      repeat_actions=row.repeat_actions,
-                                      severity=row.severity)
+                                      repeat_actions=row.repeat_actions)
 
     def _retrieve_alarms(self, query):
         return (self._row_to_alarm_model(x) for x in query.all())
 
     def get_alarms(self, name=None, user=None, state=None, meter=None,
-                   project=None, enabled=None, alarm_id=None,
-                   alarm_type=None, severity=None):
-        """Yields a lists of alarms that match filters.
+                   project=None, enabled=None, alarm_id=None, pagination=None):
+        """Yields a lists of alarms that match filters
 
-        :param name: Optional name for alarm.
         :param user: Optional ID for user that owns the resource.
         :param state: Optional string for alarm state.
         :param meter: Optional string for alarms associated with meter.
         :param project: Optional ID for project that owns the resource.
         :param enabled: Optional boolean to list disable alarm.
         :param alarm_id: Optional alarm_id to return one alarm.
-        :param alarm_type: Optional alarm type.
-        :param severity: Optional alarm severity
+        :param pagination: Optional pagination query.
         """
 
+        if pagination:
+            raise ceilometer.NotImplementedError('Pagination not implemented')
+
         session = self._engine_facade.get_session()
         query = session.query(models.Alarm)
         if name is not None:
@@ -178,12 +171,7 @@ class Connection(base.Connection):
             query = query.filter(models.Alarm.alarm_id == alarm_id)
         if state is not None:
             query = query.filter(models.Alarm.state == state)
-        if alarm_type is not None:
-            query = query.filter(models.Alarm.type == alarm_type)
-        if severity is not None:
-            query = query.filter(models.Alarm.severity == severity)
 
-        query = query.order_by(desc(models.Alarm.timestamp))
         alarms = self._retrieve_alarms(query)
 
         # TODO(cmart): improve this by using sqlalchemy.func factory
@@ -220,7 +208,7 @@ class Connection(base.Connection):
         return self._row_to_alarm_model(alarm_row)
 
     def delete_alarm(self, alarm_id):
-        """Delete an alarm and its history data.
+        """Delete an alarm
 
         :param alarm_id: ID of the alarm to delete
         """
@@ -228,9 +216,6 @@ class Connection(base.Connection):
         with session.begin():
             session.query(models.Alarm).filter(
                 models.Alarm.alarm_id == alarm_id).delete()
-            # FIXME(liusheng): we should use delete cascade
-            session.query(models.AlarmChange).filter(
-                models.AlarmChange.alarm_id == alarm_id).delete()
 
     @staticmethod
     def _row_to_alarm_change_model(row):
@@ -258,10 +243,9 @@ class Connection(base.Connection):
                                    models.AlarmChange)
 
     def get_alarm_changes(self, alarm_id, on_behalf_of,
-                          user=None, project=None, alarm_type=None,
-                          severity=None, start_timestamp=None,
-                          start_timestamp_op=None, end_timestamp=None,
-                          end_timestamp_op=None):
+                          user=None, project=None, type=None,
+                          start_timestamp=None, start_timestamp_op=None,
+                          end_timestamp=None, end_timestamp_op=None):
         """Yields list of AlarmChanges describing alarm history
 
         Changes are always sorted in reverse order of occurrence, given
@@ -279,8 +263,7 @@ class Connection(base.Connection):
                              administrative user, indicating all projects)
         :param user: Optional ID of user to return changes for
         :param project: Optional ID of project to return changes for
-        :param alarm_type: Optional change type
-        :param severity: Optional alarm severity
+        :project type: Optional change type
         :param start_timestamp: Optional modified timestamp start range
         :param start_timestamp_op: Optional timestamp start range operation
         :param end_timestamp: Optional modified timestamp end range
@@ -297,10 +280,8 @@ class Connection(base.Connection):
             query = query.filter(models.AlarmChange.user_id == user)
         if project is not None:
             query = query.filter(models.AlarmChange.project_id == project)
-        if alarm_type is not None:
-            query = query.filter(models.AlarmChange.type == alarm_type)
-        if severity is not None:
-            query = query.filter(models.AlarmChange.severity == severity)
+        if type is not None:
+            query = query.filter(models.AlarmChange.type == type)
         if start_timestamp:
             if start_timestamp_op == 'gt':
                 query = query.filter(
@@ -327,21 +308,3 @@ class Connection(base.Connection):
                 event_id=alarm_change['event_id'])
             alarm_change_row.update(alarm_change)
             session.add(alarm_change_row)
-
-    def clear_expired_alarm_history_data(self, alarm_history_ttl):
-        """Clear expired alarm history data from the backend storage system.
-
-        Clearing occurs according to the time-to-live.
-
-        :param alarm_history_ttl: Number of seconds to keep alarm history
-                                  records for.
-        """
-        session = self._engine_facade.get_session()
-        with session.begin():
-            valid_start = (timeutils.utcnow() -
-                           datetime.timedelta(seconds=alarm_history_ttl))
-            deleted_rows = (session.query(models.AlarmChange)
-                            .filter(models.AlarmChange.timestamp < valid_start)
-                            .delete())
-            LOG.info(_LI("%d alarm histories are removed from database"),
-                     deleted_rows)
