@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -23,9 +22,9 @@ from wsgiref import simple_server
 
 import netaddr
 from oslo.config import cfg
+from paste import deploy
 import pecan
 
-from ceilometer.api import acl
 from ceilometer.api import config as api_config
 from ceilometer.api import hooks
 from ceilometer.api import middleware
@@ -34,17 +33,26 @@ from ceilometer import storage
 
 LOG = log.getLogger(__name__)
 
+CONF = cfg.CONF
+CONF.import_opt('debug', 'ceilometer.openstack.common.log')
+
 auth_opts = [
-    cfg.StrOpt('auth_strategy',
-               default='keystone',
-               help='The strategy to use for auth: noauth or keystone.'),
-    cfg.BoolOpt('enable_v1_api',
-                default=True,
-                help='Deploy the deprecated v1 API.'),
+    cfg.StrOpt('api_paste_config',
+               default="api_paste.ini",
+               help="Configuration file for WSGI definition of API."
+               ),
+]
+
+api_opts = [
+    cfg.BoolOpt('pecan_debug',
+                default=CONF.debug,
+                help='Toggle Pecan Debug Middleware. '
+                'Defaults to global debug value.'
+                ),
 ]
 
-CONF = cfg.CONF
 CONF.register_opts(auth_opts)
+CONF.register_opts(api_opts, group='api')
 
 
 def get_pecan_config():
@@ -57,8 +65,8 @@ def setup_app(pecan_config=None, extra_hooks=None):
     # FIXME: Replace DBHook with a hooks.TransactionHook
     app_hooks = [hooks.ConfigHook(),
                  hooks.DBHook(
-                     storage.get_connection(cfg.CONF),
-                 ),
+                     storage.get_connection_from_config(cfg.CONF, 'metering'),
+                     storage.get_connection_from_config(cfg.CONF, 'alarm'),),
                  hooks.PipelineHook(),
                  hooks.TranslationHook()]
     if extra_hooks:
@@ -73,32 +81,26 @@ def setup_app(pecan_config=None, extra_hooks=None):
         pecan_config.app.root,
         static_root=pecan_config.app.static_root,
         template_path=pecan_config.app.template_path,
-        debug=CONF.debug,
+        debug=CONF.api.pecan_debug,
         force_canonical=getattr(pecan_config.app, 'force_canonical', True),
         hooks=app_hooks,
         wrap_app=middleware.ParsableErrorMiddleware,
         guess_content_type_from_ext=False
     )
 
-    if getattr(pecan_config.app, 'enable_acl', True):
-        return acl.install(app, cfg.CONF)
-
     return app
 
 
 class VersionSelectorApplication(object):
     def __init__(self):
         pc = get_pecan_config()
-        pc.app.debug = CONF.debug
-        pc.app.enable_acl = (CONF.auth_strategy == 'keystone')
-        if cfg.CONF.enable_v1_api:
-            from ceilometer.api.v1 import app as v1app
-            self.v1 = v1app.make_app(cfg.CONF, enable_acl=pc.app.enable_acl)
-        else:
-            def not_found(environ, start_response):
-                start_response('404 Not Found', [])
-                return []
-            self.v1 = not_found
+        pc.app.debug = CONF.api.pecan_debug
+
+        def not_found(environ, start_response):
+            start_response('404 Not Found', [])
+            return []
+
+        self.v1 = not_found
         self.v2 = setup_app(pecan_config=pc)
 
     def __call__(self, environ, start_response):
@@ -121,14 +123,44 @@ def get_server_cls(host):
     return server_cls
 
 
-def build_server():
-    # Build the WSGI app
-    root = VersionSelectorApplication()
+def get_handler_cls():
+    cls = simple_server.WSGIRequestHandler
 
+    # old-style class doesn't support super
+    class CeilometerHandler(cls, object):
+        def address_string(self):
+            if cfg.CONF.api.enable_reverse_dns_lookup:
+                return super(CeilometerHandler, self).address_string()
+            else:
+                # disable reverse dns lookup, directly return ip address
+                return self.client_address[0]
+
+    return CeilometerHandler
+
+
+def load_app():
+    # Build the WSGI app
+    cfg_file = None
+    cfg_path = cfg.CONF.api_paste_config
+    if not os.path.isabs(cfg_path):
+        cfg_file = CONF.find_file(cfg_path)
+    elif os.path.exists(cfg_path):
+        cfg_file = cfg_path
+
+    if not cfg_file:
+        raise cfg.ConfigFilesNotFoundError([cfg.CONF.api_paste_config])
+    LOG.info("Full WSGI config used: %s" % cfg_file)
+    return deploy.loadapp("config:" + cfg_file)
+
+
+def build_server():
+    app = load_app()
     # Create the WSGI server and start it
     host, port = cfg.CONF.api.host, cfg.CONF.api.port
     server_cls = get_server_cls(host)
-    srv = simple_server.make_server(host, port, root, server_cls)
+
+    srv = simple_server.make_server(host, port, app,
+                                    server_cls, get_handler_cls())
 
     LOG.info(_('Starting server in PID %s') % os.getpid())
     LOG.info(_("Configuration:"))
@@ -141,4 +173,9 @@ def build_server():
     else:
         LOG.info(_("serving on http://%(host)s:%(port)s") % (
                  {'host': host, 'port': port}))
+
     return srv
+
+
+def app_factory(global_config, **local_conf):
+    return VersionSelectorApplication()
