@@ -1,7 +1,6 @@
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2013 IBM Corp.
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -29,20 +28,18 @@ import webob
 
 from ceilometer.api import hooks
 from ceilometer.openstack.common import gettextutils
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 
 LOG = log.getLogger(__name__)
 
 
 class ParsableErrorMiddleware(object):
-    """Replace error body with something the client can parse.
-    """
+    """Replace error body with something the client can parse."""
 
     @staticmethod
     def best_match_language(accept_language):
-        """Determines best available locale from the Accept-Language
-        header.
+        """Determines best available locale from the Accept-Language header.
 
         :returns: the best language match or None if the 'Accept-Language'
                   header was not available in the request.
@@ -61,8 +58,7 @@ class ParsableErrorMiddleware(object):
         state = {}
 
         def replacement_start_response(status, headers, exc_info=None):
-            """Overrides the default response to make errors parsable.
-            """
+            """Overrides the default response to make errors parsable."""
             try:
                 status_code = int(status.split(' ')[0])
                 state['status_code'] = status_code
