@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012-2013 eNovance <licensing@enovance.com>
+# Copyright 2012-2013 eNovance <licensing@enovance.com>
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -20,9 +19,18 @@ from keystoneclient.v2_0 import client as ksclient
 from oslo.config import cfg
 
 from ceilometer import agent
-from ceilometer.openstack.common.gettextutils import _  # noqa
 from ceilometer.openstack.common import log
 
+OPTS = [
+    cfg.StrOpt('partitioning_group_prefix',
+               default=None,
+               help='Work-load partitioning group prefix. Use only if you '
+                    'want to run multiple central agents with different '
+                    'config files. For each sub-group of the central agent '
+                    'pool with the same partitioning_group_prefix a disjoint '
+                    'subset of pollsters should be loaded.'),
+]
+cfg.CONF.register_opts(OPTS, group='central')
 cfg.CONF.import_group('service_credentials', 'ceilometer.service')
 
 LOG = log.getLogger(__name__)
@@ -31,7 +39,8 @@ LOG = log.getLogger(__name__)
 class AgentManager(agent.AgentManager):
 
     def __init__(self):
-        super(AgentManager, self).__init__('central')
+        super(AgentManager, self).__init__(
+            'central', group_prefix=cfg.CONF.central.partitioning_group_prefix)
 
     def interval_task(self, task):
         try:
@@ -45,7 +54,6 @@ class AgentManager(agent.AgentManager):
                 region_name=cfg.CONF.service_credentials.os_region_name,
                 insecure=cfg.CONF.service_credentials.insecure)
         except Exception as e:
-            LOG.error(_('Skip interval_task because Keystone error: %s'), e)
-            return
+            self.keystone = e
 
         super(AgentManager, self).interval_task(task)
