@@ -14,17 +14,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import cotyledon
-from cotyledon import oslo_config_glue
-
 from ceilometer import collector
+from ceilometer.openstack.common import service as os_service
 from ceilometer import service
 
 
 def main():
-    conf = service.prepare_service()
-    sm = cotyledon.ServiceManager()
-    sm.add(collector.CollectorService, workers=conf.collector.workers,
-           args=(conf,))
-    oslo_config_glue.setup(sm, conf)
-    sm.run()
+    service.prepare_service()
+    launcher = os_service.ProcessLauncher()
+    launcher.launch_service(
+        collector.CollectorService(),
+        workers=service.get_workers('collector'))
+    launcher.wait()
