@@ -1,7 +1,6 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 eNovance <licensing@enovance.com>
-# Copyright © 2012 Red Hat, Inc
+# Copyright 2012 eNovance <licensing@enovance.com>
+# Copyright 2012 Red Hat, Inc
 #
 # Author: Julien Danjou <julien@danjou.info>
 # Author: Eoghan Glynn <eglynn@redhat.com>
@@ -20,12 +19,14 @@
 
 import copy
 
+from oslo.utils import timeutils
+
+import ceilometer
 from ceilometer.compute import plugin
 from ceilometer.compute.pollsters import util
 from ceilometer.compute.virt import inspector as virt_inspector
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import timeutils
 from ceilometer import sample
 
 LOG = log.getLogger(__name__)
@@ -41,8 +42,8 @@ class _Base(plugin.ComputePollster):
         metadata = copy.copy(vnic_data)
         resource_metadata = dict(zip(metadata._fields, metadata))
         resource_metadata['instance_id'] = instance.id
-        resource_metadata['instance_type'] = \
-            instance.flavor['id'] if instance.flavor else None
+        resource_metadata['instance_type'] = (instance.flavor['id'] if
+                                              instance.flavor else None)
 
         if vnic_data.fref is not None:
             rid = vnic_data.fref
@@ -68,10 +69,12 @@ class _Base(plugin.ComputePollster):
         instance_name = util.instance_name(instance)
         return inspector.inspect_vnics(instance_name)
 
-    def _get_rx_info(self, info):
+    @staticmethod
+    def _get_rx_info(info):
         return info.rx_bytes
 
-    def _get_tx_info(self, info):
+    @staticmethod
+    def _get_tx_info(info):
         return info.tx_bytes
 
     def _get_vnics_for_instance(self, cache, inspector, instance):
@@ -102,23 +105,22 @@ class _Base(plugin.ComputePollster):
             except virt_inspector.InstanceNotFoundException as err:
                 # Instance was deleted while getting samples. Ignore it.
                 LOG.debug(_('Exception while getting samples %s'), err)
-            except NotImplementedError:
+            except ceilometer.NotImplementedError:
                 # Selected inspector does not implement this pollster.
                 LOG.debug(_('%(inspector)s does not provide data for '
-                            ' %(pollster)s'), ({
-                          'inspector': manager.inspector.__class__.__name__,
-                          'pollster': self.__class__.__name__}))
+                            ' %(pollster)s'),
+                          {'inspector': manager.inspector.__class__.__name__,
+                           'pollster': self.__class__.__name__})
             except Exception as err:
-                LOG.warning(_('Ignoring instance %(name)s: %(error)s') % (
-                            {'name': instance_name, 'error': err}))
-                LOG.exception(err)
+                LOG.exception(_('Ignoring instance %(name)s: %(error)s'),
+                              {'name': instance_name, 'error': err})
 
 
 class _RateBase(_Base):
 
     NET_USAGE_MESSAGE = ' '.join(["NETWORK RATE:", "%s %s:",
-                                 "read-bytes-rate=%d",
-                                 "write-bytes-rate=%d"])
+                                  "read-bytes-rate=%d",
+                                  "write-bytes-rate=%d"])
 
     CACHE_KEY_VNIC = 'vnic-rates'
 
@@ -126,10 +128,12 @@ class _RateBase(_Base):
         return inspector.inspect_vnic_rates(instance,
                                             self._inspection_duration)
 
-    def _get_rx_info(self, info):
+    @staticmethod
+    def _get_rx_info(info):
         return info.rx_bytes_rate
 
-    def _get_tx_info(self, info):
+    @staticmethod
+    def _get_tx_info(info):
         return info.tx_bytes_rate
 
 
