@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 Red Hat, Inc
+# Copyright 2012 Red Hat, Inc
 #
 # Author: Eoghan Glynn <eglynn@redhat.com>
 #
@@ -19,9 +18,10 @@
 
 from lxml import etree
 from oslo.config import cfg
+import six
 
 from ceilometer.compute.virt import inspector as virt_inspector
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log as logging
 
 libvirt = None
@@ -43,6 +43,22 @@ CONF = cfg.CONF
 CONF.register_opts(libvirt_opts)
 
 
+def retry_on_disconnect(function):
+    def decorator(self, *args, **kwargs):
+        try:
+            return function(self, *args, **kwargs)
+        except libvirt.libvirtError as e:
+            if (e.get_error_code() == libvirt.VIR_ERR_SYSTEM_ERROR and
+                e.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
+                                         libvirt.VIR_FROM_RPC)):
+                LOG.debug('Connection to libvirt broken')
+                self.connection = None
+                return function(self, *args, **kwargs)
+            else:
+                raise
+    return decorator
+
+
 class LibvirtInspector(virt_inspector.Inspector):
 
     per_type_uris = dict(uml='uml:///system', xen='xen:///', lxc='lxc:///')
@@ -56,35 +72,27 @@ class LibvirtInspector(virt_inspector.Inspector):
                                                           'qemu:///system')
 
     def _get_connection(self):
-        if not self.connection or not self._test_connection():
+        if not self.connection:
             global libvirt
             if libvirt is None:
                 libvirt = __import__('libvirt')
-
-            LOG.debug(_('Connecting to libvirt: %s'), self.uri)
+            LOG.debug('Connecting to libvirt: %s', self.uri)
             self.connection = libvirt.openReadOnly(self.uri)
 
         return self.connection
 
-    def _test_connection(self):
-        try:
-            self.connection.getCapabilities()
-            return True
-        except libvirt.libvirtError as e:
-            if (e.get_error_code() == libvirt.VIR_ERR_SYSTEM_ERROR and
-                e.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
-                                         libvirt.VIR_FROM_RPC)):
-                LOG.debug(_('Connection to libvirt broke'))
-                return False
-            raise
-
+    @retry_on_disconnect
     def _lookup_by_name(self, instance_name):
         try:
             return self._get_connection().lookupByName(instance_name)
         except Exception as ex:
             if not libvirt or not isinstance(ex, libvirt.libvirtError):
-                raise virt_inspector.InspectorException(unicode(ex))
+                raise virt_inspector.InspectorException(six.text_type(ex))
             error_code = ex.get_error_code()
+            if (error_code == libvirt.VIR_ERR_SYSTEM_ERROR and
+                ex.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
+                                          libvirt.VIR_FROM_RPC)):
+                raise
             msg = ("Error from libvirt while looking up %(instance_name)s: "
                    "[Error Code %(error_code)s] "
                    "%(ex)s" % {'instance_name': instance_name,
@@ -92,27 +100,31 @@ class LibvirtInspector(virt_inspector.Inspector):
                                'ex': ex})
             raise virt_inspector.InstanceNotFoundException(msg)
 
+    @retry_on_disconnect
+    def inspect_instance(self, domain_id):
+        domain = self._get_connection().lookupByID(domain_id)
+        return virt_inspector.Instance(name=domain.name(),
+                                       UUID=domain.UUIDString())
+
+    @retry_on_disconnect
     def inspect_instances(self):
         if self._get_connection().numOfDomains() > 0:
             for domain_id in self._get_connection().listDomainsID():
-                try:
-                    # We skip domains with ID 0 (hypervisors).
-                    if domain_id != 0:
-                        domain = self._get_connection().lookupByID(domain_id)
-                        yield virt_inspector.Instance(name=domain.name(),
-                                                      UUID=domain.UUIDString())
-                except libvirt.libvirtError:
-                    # Instance was deleted while listing... ignore it
-                    pass
+                if domain_id != 0:
+                    try:
+                        yield self.inspect_instance(domain_id)
+                    except libvirt.libvirtError:
+                        # Instance was deleted while listing... ignore it
+                        pass
 
     def inspect_cpus(self, instance_name):
         domain = self._lookup_by_name(instance_name)
-        (__, __, __, num_cpu, cpu_time) = domain.info()
-        return virt_inspector.CPUStats(number=num_cpu, time=cpu_time)
+        dom_info = domain.info()
+        return virt_inspector.CPUStats(number=dom_info[3], time=dom_info[4])
 
     def inspect_vnics(self, instance_name):
         domain = self._lookup_by_name(instance_name)
-        (state, __, __, __, __) = domain.info()
+        state = domain.info()[0]
         if state == libvirt.VIR_DOMAIN_SHUTOFF:
             LOG.warn(_('Failed to inspect vnics of %(instance_name)s, '
                        'domain is in state of SHUTOFF'),
@@ -138,17 +150,16 @@ class LibvirtInspector(virt_inspector.Inspector):
                           for p in iface.findall('filterref/parameter'))
             interface = virt_inspector.Interface(name=name, mac=mac_address,
                                                  fref=fref, parameters=params)
-            rx_bytes, rx_packets, __, __, \
-                tx_bytes, tx_packets, __, __ = domain.interfaceStats(name)
-            stats = virt_inspector.InterfaceStats(rx_bytes=rx_bytes,
-                                                  rx_packets=rx_packets,
-                                                  tx_bytes=tx_bytes,
-                                                  tx_packets=tx_packets)
+            dom_stats = domain.interfaceStats(name)
+            stats = virt_inspector.InterfaceStats(rx_bytes=dom_stats[0],
+                                                  rx_packets=dom_stats[1],
+                                                  tx_bytes=dom_stats[4],
+                                                  tx_packets=dom_stats[5])
             yield (interface, stats)
 
     def inspect_disks(self, instance_name):
         domain = self._lookup_by_name(instance_name)
-        (state, __, __, __, __) = domain.info()
+        state = domain.info()[0]
         if state == libvirt.VIR_DOMAIN_SHUTOFF:
             LOG.warn(_('Failed to inspect disks of %(instance_name)s, '
                        'domain is in state of SHUTOFF'),
