@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2013 IBM Corp
 #
@@ -15,11 +14,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from oslo.utils import timeutils
 
 from ceilometer import dispatcher
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import timeutils
 from ceilometer.publisher import utils as publisher_utils
 from ceilometer import storage
 
@@ -27,7 +26,7 @@ LOG = log.getLogger(__name__)
 
 
 class DatabaseDispatcher(dispatcher.Base):
-    '''Dispatcher class for recording metering data into database.
+    """Dispatcher class for recording metering data into database.
 
     The dispatcher class which records each meter into a database configured
     in ceilometer configuration file.
@@ -36,10 +35,10 @@ class DatabaseDispatcher(dispatcher.Base):
     ceilometer.conf file
 
     dispatchers = database
-    '''
+    """
     def __init__(self, conf):
         super(DatabaseDispatcher, self).__init__(conf)
-        self.storage_conn = storage.get_connection(conf)
+        self.storage_conn = storage.get_connection_from_config(conf)
 
     def record_metering_data(self, data):
         # We may have receive only one counter on the wire
