@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -23,20 +22,41 @@ import itertools
 
 import glanceclient
 from oslo.config import cfg
+from oslo.utils import timeutils
 
-from ceilometer.openstack.common import timeutils
-from ceilometer import plugin
+from ceilometer.central import plugin
 from ceilometer import sample
 
 
-class _Base(plugin.PollsterBase):
+OPTS = [
+    cfg.IntOpt('glance_page_size',
+               default=0,
+               help="Number of items to request in "
+                    "each paginated Glance API request "
+                    "(parameter used by glancecelient). "
+                    "If this is less than or equal to 0, "
+                    "page size is not specified "
+                    "(default value in glanceclient is used)."),
+]
+
+service_types_opts = [
+    cfg.StrOpt('glance',
+               default='image',
+               help='Glance service type.'),
+]
+
+cfg.CONF.register_opts(OPTS)
+cfg.CONF.register_opts(service_types_opts, group='service_types')
+
+
+class _Base(plugin.CentralPollster):
+
+    @property
+    def default_discovery(self):
+        return 'endpoint:%s' % cfg.CONF.service_types.glance
 
     @staticmethod
-    def get_glance_client(ksclient):
-        endpoint = ksclient.service_catalog.url_for(
-            service_type='image',
-            endpoint_type=cfg.CONF.service_credentials.os_endpoint_type)
-
+    def get_glance_client(ksclient, endpoint):
         # hard-code v1 glance API version selection while v2 API matures
         service_credentials = cfg.CONF.service_credentials
         return glanceclient.Client('1', endpoint,
@@ -44,15 +64,17 @@ class _Base(plugin.PollsterBase):
                                    cacert=service_credentials.os_cacert,
                                    insecure=service_credentials.insecure)
 
-    def _get_images(self, ksclient):
-        client = self.get_glance_client(ksclient)
-        #TODO(eglynn): use pagination to protect against unbounded
-        #              memory usage
+    def _get_images(self, ksclient, endpoint):
+        client = self.get_glance_client(ksclient, endpoint)
+        page_size = cfg.CONF.glance_page_size
+        kwargs = {}
+        if page_size > 0:
+            kwargs['page_size'] = page_size
         rawImageList = list(itertools.chain(
-            client.images.list(filters={"is_public": True}),
-            #TODO(eglynn): extend glance API with all_tenants logic to
+            client.images.list(filters={"is_public": True}, **kwargs),
+            # TODO(eglynn): extend glance API with all_tenants logic to
             #              avoid second call to retrieve private images
-            client.images.list(filters={"is_public": False})))
+            client.images.list(filters={"is_public": False}, **kwargs)))
 
         # When retrieving images from glance, glance will check
         # whether the user is of 'admin_role' which is
@@ -63,7 +85,7 @@ class _Base(plugin.PollsterBase):
         # all the public images together with private images.
         # As a result, if the user/tenant has an admin role
         # for ceilometer to collect image list,
-        # the _Base.iter_images method will return a image list
+        # the _Base.iter_images method will return an image list
         # which contains duplicate images. Add the following
         # code to avoid recording down duplicate image events.
         imageIdSet = set(image.id for image in rawImageList)
@@ -73,11 +95,12 @@ class _Base(plugin.PollsterBase):
                 imageIdSet -= set([image.id])
                 yield image
 
-    def _iter_images(self, ksclient, cache):
+    def _iter_images(self, ksclient, cache, endpoint):
         """Iterate over all images."""
-        if 'images' not in cache:
-            cache['images'] = list(self._get_images(ksclient))
-        return iter(cache['images'])
+        key = '%s-images' % endpoint
+        if key not in cache:
+            cache[key] = list(self._get_images(ksclient, endpoint))
+        return iter(cache[key])
 
     @staticmethod
     def extract_image_metadata(image):
@@ -98,39 +121,38 @@ class _Base(plugin.PollsterBase):
                         "checksum",
                         "deleted_at",
                         "min_ram",
-                        "size",
-                    ])
+                        "size", ])
 
 
 class ImagePollster(_Base):
-
-    def get_samples(self, manager, cache, resources=[]):
-        for image in self._iter_images(manager.keystone, cache):
-            yield sample.Sample(
-                name='image',
-                type=sample.TYPE_GAUGE,
-                unit='image',
-                volume=1,
-                user_id=None,
-                project_id=image.owner,
-                resource_id=image.id,
-                timestamp=timeutils.isotime(),
-                resource_metadata=self.extract_image_metadata(image),
-            )
+    def get_samples(self, manager, cache, resources):
+        for endpoint in resources:
+            for image in self._iter_images(manager.keystone, cache, endpoint):
+                yield sample.Sample(
+                    name='image',
+                    type=sample.TYPE_GAUGE,
+                    unit='image',
+                    volume=1,
+                    user_id=None,
+                    project_id=image.owner,
+                    resource_id=image.id,
+                    timestamp=timeutils.isotime(),
+                    resource_metadata=self.extract_image_metadata(image),
+                )
 
 
 class ImageSizePollster(_Base):
-
-    def get_samples(self, manager, cache, resources=[]):
-        for image in self._iter_images(manager.keystone, cache):
-            yield sample.Sample(
-                name='image.size',
-                type=sample.TYPE_GAUGE,
-                unit='B',
-                volume=image.size,
-                user_id=None,
-                project_id=image.owner,
-                resource_id=image.id,
-                timestamp=timeutils.isotime(),
-                resource_metadata=self.extract_image_metadata(image),
-            )
+    def get_samples(self, manager, cache, resources):
+        for endpoint in resources:
+            for image in self._iter_images(manager.keystone, cache, endpoint):
+                yield sample.Sample(
+                    name='image.size',
+                    type=sample.TYPE_GAUGE,
+                    unit='B',
+                    volume=image.size,
+                    user_id=None,
+                    project_id=image.owner,
+                    resource_id=image.id,
+                    timestamp=timeutils.isotime(),
+                    resource_metadata=self.extract_image_metadata(image),
+                )
