@@ -1,6 +1,8 @@
 #
 # Copyright 2014 Red Hat
 #
+# Author: Chris Dent <chdent@redhat.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -16,13 +18,24 @@
 notification events.
 """
 
-from oslo_log import log
+from oslo.config import cfg
+from oslo import messaging
 
-from ceilometer.pipeline import sample as endpoint
+from ceilometer.openstack.common import log
+from ceilometer import plugin
 from ceilometer import sample
 
 LOG = log.getLogger(__name__)
 
+OPTS = [
+    cfg.StrOpt('ironic_exchange',
+               default='ironic',
+               help='Exchange name for Ironic notifications.'),
+]
+
+
+cfg.CONF.register_opts(OPTS)
+
 
 # Map unit name to SI
 UNIT_MAP = {
@@ -54,7 +67,7 @@ class InvalidSensorData(ValueError):
     pass
 
 
-class SensorNotification(endpoint.SampleEndpoint):
+class SensorNotification(plugin.NotificationBase):
     """A generic class for extracting samples from sensor data notifications.
 
     A notification message can contain multiple samples from multiple
@@ -68,6 +81,13 @@ class SensorNotification(endpoint.SampleEndpoint):
     event_types = ['hardware.ipmi.*']
     metric = None
 
+    @staticmethod
+    def get_targets(conf):
+        """oslo.messaging.TargetS for this plugin."""
+        return [messaging.Target(topic=topic,
+                                 exchange=conf.ironic_exchange)
+                for topic in conf.notification_topics]
+
     def _get_sample(self, message):
         try:
             return (payload for _, payload
@@ -75,12 +95,8 @@ class SensorNotification(endpoint.SampleEndpoint):
         except KeyError:
             return []
 
-    @staticmethod
-    def _package_payload(message, payload):
+    def _package_payload(self, message, payload):
         # NOTE(chdent): How much of the payload should we keep?
-        # FIXME(gordc): ironic adds timestamp and event_type in its payload
-        # which we are using below. we should probably just use oslo.messaging
-        # values instead?
         payload['node'] = message['payload']['node_uuid']
         info = {'publisher_id': message['publisher_id'],
                 'timestamp': message['payload']['timestamp'],
@@ -90,7 +106,7 @@ class SensorNotification(endpoint.SampleEndpoint):
                 'payload': payload}
         return info
 
-    def build_sample(self, message):
+    def process_notification(self, message):
         """Read and process a notification.
 
         The guts of a message are in dict value of a 'payload' key
@@ -134,11 +150,10 @@ class SensorNotification(endpoint.SampleEndpoint):
                         resource_id=resource_id,
                         message=info,
                         user_id=info['user_id'],
-                        project_id=info['project_id'],
-                        timestamp=info['timestamp'])
+                        project_id=info['project_id'])
 
             except InvalidSensorData as exc:
-                LOG.warning(
+                LOG.warn(
                     'invalid sensor data for %(resource)s: %(error)s' %
                     dict(resource=resource_id, error=exc)
                 )
