@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -21,8 +20,9 @@
 """
 
 from oslo.config import cfg
+import oslo.messaging
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 from ceilometer import plugin
 from ceilometer import sample
@@ -50,30 +50,28 @@ class NetworkNotificationBase(plugin.NotificationBase):
             # there is no resource id assigned by Neutron yet. So we ignore
             # the *.create.start notification for now and only listen the
             # *.create.end to make sure the resource id is existed.
-            '%s.create.end' % (self.resource_name),
-            '%s.update.*' % (self.resource_name),
-            '%s.exists' % (self.resource_name),
+            '%s.create.end' % self.resource_name,
+            '%s.update.*' % self.resource_name,
+            '%s.exists' % self.resource_name,
             # FIXME(dhellmann): Neutron delete notifications do
             # not include the same metadata as the other messages,
             # so we ignore them for now. This isn't ideal, since
             # it may mean we miss charging for some amount of time,
             # but it is better than throwing away the existing
             # metadata for a resource when it is deleted.
-            ##'%s.delete.start' % (self.resource_name),
+            # '%s.delete.start' % (self.resource_name),
         ]
 
     @staticmethod
-    def get_exchange_topics(conf):
-        """Return a sequence of ExchangeTopics defining the exchange and topics
-        to be connected for this plugin.
+    def get_targets(conf):
+        """Return a sequence of oslo.messaging.Target
 
+        This sequence is defining the exchange and topics to be connected for
+        this plugin.
         """
-        return [
-            plugin.ExchangeTopics(
-                exchange=conf.neutron_control_exchange,
-                topics=set(topic + ".info"
-                           for topic in conf.notification_topics)),
-        ]
+        return [oslo.messaging.Target(topic=topic,
+                                      exchange=conf.neutron_control_exchange)
+                for topic in conf.notification_topics]
 
     def process_notification(self, message):
         LOG.info(_('network notification %r') % message)
@@ -117,41 +115,41 @@ class NetworkNotificationBase(plugin.NotificationBase):
 
 
 class Network(NetworkNotificationBase):
-    """Listen for Neutron network notifications in order to mediate with the
-    metering framework.
+    """Listen for Neutron network notifications.
 
+    Listen in order to mediate with the metering framework.
     """
     resource_name = 'network'
 
 
 class Subnet(NetworkNotificationBase):
-    """Listen for Neutron notifications in order to mediate with the
-    metering framework.
+    """Listen for Neutron notifications.
 
+    Listen in order to mediate with the metering framework.
     """
     resource_name = 'subnet'
 
 
 class Port(NetworkNotificationBase):
-    """Listen for Neutron notifications in order to mediate with the
-    metering framework.
+    """Listen for Neutron notifications.
 
+    Listen in order to mediate with the metering framework.
     """
     resource_name = 'port'
 
 
 class Router(NetworkNotificationBase):
-    """Listen for Neutron notifications in order to mediate with the
-    metering framework.
+    """Listen for Neutron notifications.
 
+    Listen in order to mediate with the metering framework.
     """
     resource_name = 'router'
 
 
 class FloatingIP(NetworkNotificationBase):
-    """Listen for Neutron notifications in order to mediate with the
-    metering framework.
+    """Listen for Neutron notifications.
 
+    Listen in order to mediate with the metering framework.
     """
     resource_name = 'floatingip'
     counter_name = 'ip.floating'
@@ -159,9 +157,9 @@ class FloatingIP(NetworkNotificationBase):
 
 
 class Bandwidth(NetworkNotificationBase):
-    """Listen for Neutron notifications in order to mediate with the
-    metering framework.
+    """Listen for Neutron notifications.
 
+    Listen in order to mediate with the metering framework.
     """
     event_types = ['l3.meter']
 
