@@ -1,6 +1,8 @@
 #
 # Copyright 2014 Cisco Systems,Inc.
 #
+# Author: Pradeep Kilambi <pkilambi@cisco.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -12,12 +14,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
-import warnings
-
-from oslo_log import log
+from oslo.utils import timeutils
 
 from ceilometer.network.services import base
+from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common import log
 from ceilometer import sample
 
 LOG = log.getLogger(__name__)
@@ -33,13 +34,6 @@ class FirewallPollster(base.BaseServicesPollster):
               'firewall_policy_id',
               ]
 
-    def __init__(self, conf):
-        super().__init__(conf)
-
-        warnings.warn('Support for Neutron FWaaS has been deprecated '
-                      'and will be removed in a future release.',
-                      category=DeprecationWarning, stacklevel=2)
-
     @property
     def default_discovery(self):
         return 'fw_services'
@@ -48,13 +42,13 @@ class FirewallPollster(base.BaseServicesPollster):
         resources = resources or []
 
         for fw in resources:
-            LOG.debug("Firewall : %s", fw)
+            LOG.debug("Firewall : %s" % fw)
             status = self.get_status_id(fw['status'])
             if status == -1:
                 # unknown status, skip this sample
-                LOG.warning("Unknown status %(stat)s received on fw %(id)s,"
-                            "skipping sample",
-                            {'stat': fw['status'], 'id': fw['id']})
+                LOG.warn(_("Unknown status %(stat)s received on fw %(id)s,"
+                           "skipping sample") % {'stat': fw['status'],
+                                                 'id': fw['id']})
                 continue
 
             yield sample.Sample(
@@ -65,6 +59,7 @@ class FirewallPollster(base.BaseServicesPollster):
                 user_id=None,
                 project_id=fw['tenant_id'],
                 resource_id=fw['id'],
+                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=self.extract_metadata(fw)
             )
 
@@ -80,13 +75,6 @@ class FirewallPolicyPollster(base.BaseServicesPollster):
               'audited',
               ]
 
-    def __init__(self, conf):
-        super().__init__(conf)
-
-        warnings.warn('Support for Neutron FWaaS has been deprecated '
-                      'and will be removed in a future release.',
-                      category=DeprecationWarning, stacklevel=2)
-
     @property
     def default_discovery(self):
         return 'fw_policy'
@@ -95,15 +83,16 @@ class FirewallPolicyPollster(base.BaseServicesPollster):
         resources = resources or []
 
         for fw in resources:
-            LOG.debug("Firewall Policy: %s", fw)
+            LOG.debug("Firewall Policy: %s" % fw)
 
             yield sample.Sample(
                 name='network.services.firewall.policy',
                 type=sample.TYPE_GAUGE,
-                unit='firewall_policy',
+                unit='policy',
                 volume=1,
                 user_id=None,
                 project_id=fw['tenant_id'],
                 resource_id=fw['id'],
+                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=self.extract_metadata(fw)
             )
