@@ -1,6 +1,8 @@
 #
 # Copyright 2014 Cisco Systems,Inc.
 #
+# Author: Pradeep Kilambi <pkilambi@cisco.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -15,13 +17,13 @@
 
 import abc
 import collections
-import warnings
 
-from oslo_log import log
+from oslo.utils import timeutils
+import six
 
-from ceilometer.i18n import _
 from ceilometer.network.services import base
-from ceilometer import neutron_client
+from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common import log
 from ceilometer import sample
 
 LOG = log.getLogger(__name__)
@@ -31,37 +33,8 @@ LBStatsData = collections.namedtuple(
     ['active_connections', 'total_connections', 'bytes_in', 'bytes_out']
 )
 
-LOAD_BALANCER_STATUS_V2 = {
-    'offline': 0,
-    'online': 1,
-    'no_monitor': 3,
-    'error': 4,
-    'degraded': 5,
-    'disabled': 6
-}
 
-
-class BaseLBPollster(base.BaseServicesPollster):
-    """Base Class for Load Balancer pollster"""
-
-    def __init__(self, conf):
-        super(BaseLBPollster, self).__init__(conf)
-        self.lb_version = self.conf.service_types.neutron_lbaas_version
-
-        warnings.warn('Support for Neutron LBaaS has been deprecated '
-                      'and will be removed in a future release.',
-                      category=DeprecationWarning, stacklevel=3)
-
-    def get_load_balancer_status_id(self, value):
-        if self.lb_version == 'v1':
-            resource_status = self.get_status_id(value)
-        elif self.lb_version == 'v2':
-            status = value.lower()
-            resource_status = LOAD_BALANCER_STATUS_V2.get(status, -1)
-        return resource_status
-
-
-class LBPoolPollster(BaseLBPollster):
+class LBPoolPollster(base.BaseServicesPollster):
     """Pollster to capture Load Balancer pool status samples."""
 
     FIELDS = ['admin_state_up',
@@ -85,12 +58,12 @@ class LBPoolPollster(BaseLBPollster):
 
         for pool in resources:
             LOG.debug("Load Balancer Pool : %s" % pool)
-            status = self.get_load_balancer_status_id(pool['status'])
+            status = self.get_status_id(pool['status'])
             if status == -1:
                 # unknown status, skip this sample
-                LOG.warning(_("Unknown status %(stat)s received on pool "
-                              "%(id)s, skipping sample")
-                            % {'stat': pool['status'], 'id': pool['id']})
+                LOG.warn(_("Unknown status %(stat)s received on pool %(id)s, "
+                           "skipping sample") % {'stat': pool['status'],
+                                                 'id': pool['id']})
                 continue
 
             yield sample.Sample(
@@ -101,6 +74,7 @@ class LBPoolPollster(BaseLBPollster):
                 user_id=None,
                 project_id=pool['tenant_id'],
                 resource_id=pool['id'],
+                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=self.extract_metadata(pool)
             )
 
@@ -135,9 +109,9 @@ class LBVipPollster(base.BaseServicesPollster):
             status = self.get_status_id(vip['status'])
             if status == -1:
                 # unknown status, skip this sample
-                LOG.warning(_("Unknown status %(stat)s received on vip "
-                              "%(id)s, skipping sample")
-                            % {'stat': vip['status'], 'id': vip['id']})
+                LOG.warn(_("Unknown status %(stat)s received on vip %(id)s, "
+                         "skipping sample") % {'stat': vip['status'],
+                                               'id': vip['id']})
                 continue
 
             yield sample.Sample(
@@ -148,11 +122,12 @@ class LBVipPollster(base.BaseServicesPollster):
                 user_id=None,
                 project_id=vip['tenant_id'],
                 resource_id=vip['id'],
+                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=self.extract_metadata(vip)
             )
 
 
-class LBMemberPollster(BaseLBPollster):
+class LBMemberPollster(base.BaseServicesPollster):
     """Pollster to capture Load Balancer Member status samples."""
 
     FIELDS = ['admin_state_up',
@@ -173,11 +148,11 @@ class LBMemberPollster(BaseLBPollster):
 
         for member in resources:
             LOG.debug("Load Balancer Member : %s" % member)
-            status = self.get_load_balancer_status_id(member['status'])
+            status = self.get_status_id(member['status'])
             if status == -1:
-                LOG.warning(_("Unknown status %(stat)s received on member "
-                              "%(id)s, skipping sample")
-                            % {'stat': member['status'], 'id': member['id']})
+                LOG.warn(_("Unknown status %(stat)s received on member %(id)s,"
+                         "skipping sample") % {'stat': member['status'],
+                                               'id': member['id']})
                 continue
             yield sample.Sample(
                 name='network.services.lb.member',
@@ -187,6 +162,7 @@ class LBMemberPollster(BaseLBPollster):
                 user_id=None,
                 project_id=member['tenant_id'],
                 resource_id=member['id'],
+                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=self.extract_metadata(member)
             )
 
@@ -212,26 +188,29 @@ class LBHealthMonitorPollster(base.BaseServicesPollster):
             yield sample.Sample(
                 name='network.services.lb.health_monitor',
                 type=sample.TYPE_GAUGE,
-                unit='health_monitor',
+                unit='monitor',
                 volume=1,
                 user_id=None,
                 project_id=probe['tenant_id'],
                 resource_id=probe['id'],
+                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=self.extract_metadata(probe)
             )
 
 
-class _LBStatsPollster(base.BaseServicesPollster, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class _LBStatsPollster(base.BaseServicesPollster):
     """Base Statistics pollster.
 
      It is capturing the statistics info and yielding samples for connections
      and bandwidth.
     """
 
-    def __init__(self, conf):
-        super(_LBStatsPollster, self).__init__(conf)
-        self.client = neutron_client.Client(self.conf)
-        self.lb_version = self.conf.service_types.neutron_lbaas_version
+    def _get_lb_pools(self):
+        return self.nc.pool_get_all()
+
+    def _get_pool_stats(self, pool_id):
+        return self.nc.pool_stats(pool_id)
 
     @staticmethod
     def make_sample_from_pool(pool, name, type, unit, volume,
@@ -246,13 +225,14 @@ class _LBStatsPollster(base.BaseServicesPollster, metaclass=abc.ABCMeta):
             user_id=None,
             project_id=pool['tenant_id'],
             resource_id=pool['id'],
+            timestamp=timeutils.isotime(),
             resource_metadata=resource_metadata,
         )
 
     def _populate_stats_cache(self, pool_id, cache):
         i_cache = cache.setdefault("lbstats", {})
         if pool_id not in i_cache:
-            stats = self.client.pool_stats(pool_id)['stats']
+            stats = self._get_pool_stats(pool_id)['stats']
             i_cache[pool_id] = LBStatsData(
                 active_connections=stats['active_connections'],
                 total_connections=stats['total_connections'],
@@ -261,48 +241,22 @@ class _LBStatsPollster(base.BaseServicesPollster, metaclass=abc.ABCMeta):
             )
         return i_cache[pool_id]
 
-    def _populate_stats_cache_v2(self, loadbalancer_id, cache):
-        i_cache = cache.setdefault("lbstats", {})
-        if loadbalancer_id not in i_cache:
-            stats = self.client.get_loadbalancer_stats(loadbalancer_id)
-            i_cache[loadbalancer_id] = LBStatsData(
-                active_connections=stats['active_connections'],
-                total_connections=stats['total_connections'],
-                bytes_in=stats['bytes_in'],
-                bytes_out=stats['bytes_out'],
-            )
-        return i_cache[loadbalancer_id]
-
     @property
     def default_discovery(self):
-        discovery_resource = 'lb_pools'
-        if self.lb_version == 'v2':
-            discovery_resource = 'lb_loadbalancers'
-        return discovery_resource
+        return 'lb_pools'
 
     @abc.abstractmethod
     def _get_sample(pool, c_data):
         """Return one Sample."""
 
     def get_samples(self, manager, cache, resources):
-        if self.lb_version == 'v1':
-            for pool in resources:
-                try:
-                    c_data = self._populate_stats_cache(pool['id'], cache)
-                    yield self._get_sample(pool, c_data)
-                except Exception:
-                    LOG.exception('Ignoring pool %(pool_id)s',
-                                  {'pool_id': pool['id']})
-        elif self.lb_version == 'v2':
-            for loadbalancer in resources:
-                try:
-                    c_data = self._populate_stats_cache_v2(loadbalancer['id'],
-                                                           cache)
-                    yield self._get_sample(loadbalancer, c_data)
-                except Exception:
-                    LOG.exception(
-                        'Ignoring loadbalancer %(loadbalancer_id)s',
-                        {'loadbalancer_id': loadbalancer['id']})
+        for pool in resources:
+            try:
+                c_data = self._populate_stats_cache(pool['id'], cache)
+                yield self._get_sample(pool, c_data)
+            except Exception as err:
+                LOG.exception(_('Ignoring pool %(pool_id)s: %(error)s'),
+                              {'pool_id': pool['id'], 'error': err})
 
 
 class LBActiveConnectionsPollster(_LBStatsPollster):
@@ -327,7 +281,7 @@ class LBTotalConnectionsPollster(_LBStatsPollster):
         return make_sample_from_pool(
             pool,
             name='network.services.lb.total.connections',
-            type=sample.TYPE_CUMULATIVE,
+            type=sample.TYPE_GAUGE,
             unit='connection',
             volume=data.total_connections,
         )
@@ -341,7 +295,7 @@ class LBBytesInPollster(_LBStatsPollster):
         return make_sample_from_pool(
             pool,
             name='network.services.lb.incoming.bytes',
-            type=sample.TYPE_GAUGE,
+            type=sample.TYPE_CUMULATIVE,
             unit='B',
             volume=data.bytes_in,
         )
@@ -355,7 +309,7 @@ class LBBytesOutPollster(_LBStatsPollster):
         return make_sample_from_pool(
             pool,
             name='network.services.lb.outgoing.bytes',
-            type=sample.TYPE_GAUGE,
+            type=sample.TYPE_CUMULATIVE,
             unit='B',
             volume=data.bytes_out,
         )
@@ -373,94 +327,6 @@ def make_sample_from_pool(pool, name, type, unit, volume,
         user_id=None,
         project_id=pool['tenant_id'],
         resource_id=pool['id'],
+        timestamp=timeutils.isotime(),
         resource_metadata=resource_metadata,
     )
-
-
-class LBListenerPollster(BaseLBPollster):
-    """Pollster to capture Load Balancer Listener status samples."""
-
-    FIELDS = ['admin_state_up',
-              'connection_limit',
-              'description',
-              'name',
-              'default_pool_id',
-              'protocol',
-              'protocol_port',
-              'operating_status',
-              'loadbalancers'
-              ]
-
-    @property
-    def default_discovery(self):
-        return 'lb_listeners'
-
-    def get_samples(self, manager, cache, resources):
-        resources = resources or []
-
-        for listener in resources:
-            LOG.debug("Load Balancer Listener : %s" % listener)
-            status = self.get_load_balancer_status_id(
-                listener['operating_status'])
-            if status == -1:
-                # unknown status, skip this sample
-                LOG.warning(_("Unknown status %(stat)s received on listener "
-                              "%(id)s, skipping sample")
-                            % {'stat': listener['operating_status'],
-                               'id': listener['id']})
-                continue
-
-            yield sample.Sample(
-                name='network.services.lb.listener',
-                type=sample.TYPE_GAUGE,
-                unit='listener',
-                volume=status,
-                user_id=None,
-                project_id=listener['tenant_id'],
-                resource_id=listener['id'],
-                resource_metadata=self.extract_metadata(listener)
-            )
-
-
-class LBLoadBalancerPollster(BaseLBPollster):
-    """Pollster to capture Load Balancer status samples."""
-
-    FIELDS = ['admin_state_up',
-              'description',
-              'vip_address',
-              'listeners',
-              'name',
-              'vip_subnet_id',
-              'operating_status',
-              ]
-
-    @property
-    def default_discovery(self):
-        return 'lb_loadbalancers'
-
-    def get_samples(self, manager, cache, resources):
-        resources = resources or []
-
-        for loadbalancer in resources:
-            LOG.debug("Load Balancer: %s" % loadbalancer)
-            status = self.get_load_balancer_status_id(
-                loadbalancer['operating_status'])
-            if status == -1:
-                # unknown status, skip this sample
-                LOG.warning(_("Unknown status %(stat)s received "
-                              "on Load Balancer "
-                              "%(id)s, skipping sample")
-                            % {'stat': loadbalancer['operating_status'],
-                               'id': loadbalancer['id']})
-                continue
-
-            yield sample.Sample(
-                name='network.services.lb.loadbalancer',
-                type=sample.TYPE_GAUGE,
-                unit='loadbalancer',
-                volume=status,
-                user_id=None,
-                project_id=loadbalancer['tenant_id'],
-                resource_id=loadbalancer['id'],
-                resource_metadata=self.extract_metadata(loadbalancer)
-            )
