@@ -23,7 +23,7 @@ class Driver():
 
     @abc.abstractmethod
     def get_sample_data(self, meter_name, parse_url, params, cache):
-        '''Return volume, resource_id, resource_metadata, timestamp in tuple.
+        """Return volume, resource_id, resource_metadata, timestamp in tuple.
 
         If not implemented for meter_name, returns None
-        '''
+        """
