@@ -1,5 +1,7 @@
 # Copyright (C) 2014 eNovance SAS <licensing@enovance.com>
 #
+# Author: Sylvain Afchain <sylvain.afchain@enovance.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -12,14 +14,16 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import copy
-
-from oslo_log import log
+from oslo.config import cfg
 import requests
 import six
 from six.moves.urllib import parse as urlparse
 
-from ceilometer.i18n import _
+from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common import log
+
+
+CONF = cfg.CONF
 
 
 LOG = log.getLogger(__name__)
@@ -32,23 +36,53 @@ class OpencontrailAPIFailed(Exception):
 class AnalyticsAPIBaseClient(object):
     """Opencontrail Base Statistics REST API Client."""
 
-    def __init__(self, conf, endpoint, data):
-        self.conf = conf
+    def __init__(self, endpoint, username, password, domain, verify_ssl=True):
         self.endpoint = endpoint
-        self.data = data or {}
+        self.username = username
+        self.password = password
+        self.domain = domain
+        self.verify_ssl = verify_ssl
+        self.sid = None
 
-    def request(self, path, fqdn_uuid, data=None):
-        req_data = copy.copy(self.data)
-        if data:
-            req_data.update(data)
+    def authenticate(self):
+        path = '/authenticate'
+        data = {'username': self.username,
+                'password': self.password,
+                'domain': self.domain}
 
-        req_params = self._get_req_params(data=req_data)
+        req_params = self._get_req_params(data=data)
+        url = urlparse.urljoin(self.endpoint, path)
+        resp = requests.post(url, **req_params)
+        if resp.status_code != 302:
+            raise OpencontrailAPIFailed(
+                _('Opencontrail API returned %(status)s %(reason)s') %
+                {'status': resp.status_code, 'reason': resp.reason})
+        self.sid = resp.cookies['connect.sid']
 
-        url = urlparse.urljoin(self.endpoint, path + fqdn_uuid)
+    def request(self, path, fqdn_uuid, data, retry=True):
+        if not self.sid:
+            self.authenticate()
+
+        if not data:
+            data = {'fqnUUID': fqdn_uuid}
+        else:
+            data['fqnUUID'] = fqdn_uuid
+
+        req_params = self._get_req_params(data=data,
+                                          cookies={'connect.sid': self.sid})
+
+        url = urlparse.urljoin(self.endpoint, path)
         self._log_req(url, req_params)
         resp = requests.get(url, **req_params)
         self._log_res(resp)
 
+        # it seems that the sid token has to be renewed
+        if resp.status_code == 302:
+            self.sid = 0
+            if retry:
+                return self.request(path, fqdn_uuid, data,
+                                    retry=False)
+
         if resp.status_code != 200:
             raise OpencontrailAPIFailed(
                 _('Opencontrail API returned %(status)s %(reason)s') %
@@ -56,20 +90,22 @@ class AnalyticsAPIBaseClient(object):
 
         return resp
 
-    def _get_req_params(self, data=None):
+    def _get_req_params(self, params=None, data=None, cookies=None):
         req_params = {
             'headers': {
                 'Accept': 'application/json'
             },
             'data': data,
+            'verify': self.verify_ssl,
             'allow_redirects': False,
-            'timeout': self.conf.http_timeout,
+            'cookies': cookies
         }
 
         return req_params
 
-    def _log_req(self, url, req_params):
-        if not self.conf.debug:
+    @staticmethod
+    def _log_req(url, req_params):
+        if not CONF.debug:
             return
 
         curl_command = ['REQ: curl -i -X GET ']
@@ -85,8 +121,9 @@ class AnalyticsAPIBaseClient(object):
 
         LOG.debug(''.join(curl_command))
 
-    def _log_res(self, resp):
-        if not self.conf.debug:
+    @staticmethod
+    def _log_res(resp):
+        if not CONF.debug:
             return
 
         dump = ['RES: \n', 'HTTP %.1f %s %s\n' % (resp.raw.version,
@@ -104,19 +141,24 @@ class AnalyticsAPIBaseClient(object):
 class NetworksAPIClient(AnalyticsAPIBaseClient):
     """Opencontrail Statistics REST API Client."""
 
-    def get_vm_statistics(self, fqdn_uuid, data=None):
-        """Get statistics of a virtual-machines.
+    def get_port_statistics(self, fqdn_uuid):
+        """Get port statistics of a network
 
         URL:
-            {endpoint}/analytics/uves/virtual-machine/{fqdn_uuid}
+            /tenant/networking/virtual-machines/details
+        PARAMS:
+            fqdnUUID=fqdn_uuid
+            type=vn
         """
 
-        path = '/analytics/uves/virtual-machine/'
-        resp = self.request(path, fqdn_uuid, data)
+        path = '/api/tenant/networking/virtual-machines/details'
+        resp = self.request(path, fqdn_uuid, {'type': 'vn'})
 
         return resp.json()
 
 
 class Client(object):
-    def __init__(self, conf, endpoint, data=None):
-        self.networks = NetworksAPIClient(conf, endpoint, data)
+
+    def __init__(self, endpoint, username, password, domain, verify_ssl=True):
+        self.networks = NetworksAPIClient(endpoint, username, password,
+                                          domain, verify_ssl)
