@@ -20,7 +20,7 @@ import requests
 from requests import auth
 import six
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 
 
@@ -188,8 +188,7 @@ class Client():
 
     def _log_req(self, url):
 
-        curl_command = ['REQ: curl -i -X GET ']
-        curl_command.append('"%s" ' % (url))
+        curl_command = ['REQ: curl -i -X GET ', '"%s" ' % (url)]
 
         if 'auth' in self._req_params:
             auth_class = self._req_params['auth']
@@ -209,12 +208,11 @@ class Client():
     @staticmethod
     def _log_res(resp):
 
-        dump = ['RES: \n']
-        dump.append('HTTP %.1f %s %s\n' % (resp.raw.version,
-                                           resp.status_code,
-                                           resp.reason))
-        dump.extend(['%s: %s\n' % (k, v)
-                     for k, v in six.iteritems(resp.headers)])
+        dump = ['RES: \n', 'HTTP %.1f %s %s\n' % (resp.raw.version,
+                                                  resp.status_code,
+                                                  resp.reason)]
+        dump.extend('%s: %s\n' % (k, v)
+                    for k, v in six.iteritems(resp.headers))
         dump.append('\n')
         if resp.content:
             dump.extend([resp.content, '\n'])
