@@ -1,5 +1,7 @@
 # Copyright (C) 2014 eNovance SAS <licensing@enovance.com>
 #
+# Author: Sylvain Afchain <sylvain.afchain@enovance.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -16,17 +18,20 @@ import functools
 
 from neutronclient.common import exceptions
 from neutronclient.v2_0 import client as clientv20
-from oslo_config import cfg
-from oslo_log import log
+from oslo.config import cfg
 
-from ceilometer import keystone_client
+from ceilometer.openstack.common import log
 
-SERVICE_OPTS = [
+
+service_types_opts = [
     cfg.StrOpt('neutron',
                default='network',
                help='Neutron service type.'),
 ]
 
+cfg.CONF.register_opts(service_types_opts, group='service_types')
+cfg.CONF.import_group('service_credentials', 'ceilometer.service')
+
 LOG = log.getLogger(__name__)
 
 
@@ -37,10 +42,8 @@ def logged(func):
         try:
             return func(*args, **kwargs)
         except exceptions.NeutronClientException as e:
-            if e.status_code == 404:
-                LOG.warning("The resource could not be found.")
-            else:
-                LOG.warning(e)
+            # handles 404's when services are disabled in neutron
+            LOG.warn(e)
             return []
         except Exception as e:
             LOG.exception(e)
@@ -49,24 +52,64 @@ def logged(func):
     return with_logging
 
 
-class Client:
+class Client(object):
     """A client which gets information via python-neutronclient."""
 
-    def __init__(self, conf):
-        creds = conf.service_credentials
+    def __init__(self):
+        conf = cfg.CONF.service_credentials
         params = {
-            'session': keystone_client.get_session(conf),
-            'endpoint_type': creds.interface,
-            'region_name': creds.region_name,
-            'service_type': conf.service_types.neutron,
+            'insecure': conf.insecure,
+            'ca_cert': conf.os_cacert,
+            'username': conf.os_username,
+            'password': conf.os_password,
+            'auth_url': conf.os_auth_url,
+            'region_name': conf.os_region_name,
+            'endpoint_type': conf.os_endpoint_type,
+            'service_type': cfg.CONF.service_types.neutron
         }
+
+        if conf.os_tenant_id:
+            params['tenant_id'] = conf.os_tenant_id
+        else:
+            params['tenant_name'] = conf.os_tenant_name
+
         self.client = clientv20.Client(**params)
 
+    @logged
+    def network_get_all(self):
+        """Returns all networks."""
+        resp = self.client.list_networks()
+        return resp.get('networks')
+
     @logged
     def port_get_all(self):
         resp = self.client.list_ports()
         return resp.get('ports')
 
+    @logged
+    def vip_get_all(self):
+        resp = self.client.list_vips()
+        return resp.get('vips')
+
+    @logged
+    def pool_get_all(self):
+        resp = self.client.list_pools()
+        return resp.get('pools')
+
+    @logged
+    def member_get_all(self):
+        resp = self.client.list_members()
+        return resp.get('members')
+
+    @logged
+    def health_monitor_get_all(self):
+        resp = self.client.list_health_monitors()
+        return resp.get('health_monitors')
+
+    @logged
+    def pool_stats(self, pool):
+        return self.client.retrieve_pool_stats(pool)
+
     @logged
     def vpn_get_all(self):
         resp = self.client.list_vpnservices()
@@ -86,8 +129,3 @@ class Client:
     def fw_policy_get_all(self):
         resp = self.client.list_firewall_policies()
         return resp.get('firewall_policies')
-
-    @logged
-    def fip_get_all(self):
-        fips = self.client.list_floatingips()['floatingips']
-        return fips
