@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Author: John Tran <jhtran@att.com>
 #
@@ -22,6 +21,22 @@ from oslo.config import cfg
 
 from ceilometer.openstack.common import log
 
+
+nova_opts = [
+    cfg.BoolOpt('nova_http_log_debug',
+                default=False,
+                help='Allow novaclient\'s debug log output.'),
+]
+
+service_types_opts = [
+    cfg.StrOpt('nova',
+               default='compute',
+               help='Nova service type.'),
+]
+
+cfg.CONF.register_opts(nova_opts)
+cfg.CONF.register_opts(service_types_opts, group='service_types')
+
 cfg.CONF.import_group('service_credentials', 'ceilometer.service')
 
 LOG = log.getLogger(__name__)
@@ -43,7 +58,7 @@ def logged(func):
 class Client(object):
     """A client which gets information via python-novaclient."""
 
-    def __init__(self):
+    def __init__(self, bypass_url=None, auth_token=None):
         """Initialize a nova client object."""
         conf = cfg.CONF.service_credentials
         tenant = conf.os_tenant_id or conf.os_tenant_name
@@ -52,25 +67,35 @@ class Client(object):
             api_key=conf.os_password,
             project_id=tenant,
             auth_url=conf.os_auth_url,
+            auth_token=auth_token,
             region_name=conf.os_region_name,
             endpoint_type=conf.os_endpoint_type,
+            service_type=cfg.CONF.service_types.nova,
+            bypass_url=bypass_url,
             cacert=conf.os_cacert,
             insecure=conf.insecure,
+            http_log_debug=cfg.CONF.nova_http_log_debug,
             no_cache=True)
 
     def _with_flavor_and_image(self, instances):
+        flavor_cache = {}
+        image_cache = {}
         for instance in instances:
-            self._with_flavor(instance)
-            self._with_image(instance)
+            self._with_flavor(instance, flavor_cache)
+            self._with_image(instance, image_cache)
 
         return instances
 
-    def _with_flavor(self, instance):
+    def _with_flavor(self, instance, cache):
         fid = instance.flavor['id']
-        try:
-            flavor = self.nova_client.flavors.get(fid)
-        except novaclient.exceptions.NotFound:
-            flavor = None
+        if fid in cache:
+            flavor = cache.get(fid)
+        else:
+            try:
+                flavor = self.nova_client.flavors.get(fid)
+            except novaclient.exceptions.NotFound:
+                flavor = None
+            cache[fid] = flavor
 
         attr_defaults = [('name', 'unknown-id-%s' % fid),
                          ('vcpus', 0), ('ram', 0), ('disk', 0),
@@ -82,7 +107,7 @@ class Client(object):
                 continue
             instance.flavor[attr] = getattr(flavor, attr, default)
 
-    def _with_image(self, instance):
+    def _with_image(self, instance, cache):
         try:
             iid = instance.image['id']
         except TypeError:
@@ -91,19 +116,24 @@ class Client(object):
             instance.ramdisk_id = None
             return
 
-        try:
-            image = self.nova_client.images.get(iid)
-        except novaclient.exceptions.NotFound:
-            instance.image['name'] = 'unknown-id-%s' % iid
-            instance.kernel_id = None
-            instance.ramdisk_id = None
-            return
+        if iid in cache:
+            image = cache.get(iid)
+        else:
+            try:
+                image = self.nova_client.images.get(iid)
+            except novaclient.exceptions.NotFound:
+                image = None
+            cache[iid] = image
 
-        instance.image['name'] = getattr(image, 'name')
+        attr_defaults = [('kernel_id', None),
+                         ('ramdisk_id', None)]
+
+        instance.image['name'] = (
+            getattr(image, 'name') if image else 'unknown-id-%s' % iid)
         image_metadata = getattr(image, 'metadata', None)
 
-        for attr in ['kernel_id', 'ramdisk_id']:
-            ameta = image_metadata.get(attr) if image_metadata else None
+        for attr, default in attr_defaults:
+            ameta = image_metadata.get(attr) if image_metadata else default
             setattr(instance, attr, ameta)
 
     @logged
@@ -114,6 +144,14 @@ class Client(object):
             detailed=True,
             search_opts=search_opts))
 
+    @logged
+    def instance_get_all(self):
+        """Returns list of all instances."""
+        search_opts = {'all_tenants': True}
+        return self.nova_client.servers.list(
+            detailed=True,
+            search_opts=search_opts)
+
     @logged
     def floating_ip_get_all(self):
         """Returns all floating ips."""
