@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #         Tyaptin Ilya <ityaptin@mirantis.com>
@@ -23,6 +22,7 @@ import hashlib
 import hmac
 
 from oslo.config import cfg
+import six
 
 from ceilometer import utils
 
@@ -40,8 +40,7 @@ METER_PUBLISH_OPTS = [
 
 
 def register_opts(config):
-    """Register the options for publishing metering messages.
-    """
+    """Register the options for publishing metering messages."""
     config.register_opts(METER_PUBLISH_OPTS, group="publisher")
 
 
@@ -49,8 +48,7 @@ register_opts(cfg.CONF)
 
 
 def compute_signature(message, secret):
-    """Return the signature for a message dictionary.
-    """
+    """Return the signature for a message dictionary."""
     digest_maker = hmac.new(secret, '', hashlib.sha256)
     for name, value in utils.recursive_keypairs(message):
         if name == 'message_signature':
@@ -58,17 +56,56 @@ def compute_signature(message, secret):
             # been part of the original message.
             continue
         digest_maker.update(name)
-        digest_maker.update(unicode(value).encode('utf-8'))
+        digest_maker.update(six.text_type(value).encode('utf-8'))
     return digest_maker.hexdigest()
 
 
-def verify_signature(message, secret):
-    """Check the signature in the message against the value computed
-    from the rest of the contents.
+def besteffort_compare_digest(first, second):
+    """Returns True if both string inputs are equal, otherwise False.
+
+    This function should take a constant amount of time regardless of
+    how many characters in the strings match.
+
     """
-    old_sig = message.get('message_signature')
+    # NOTE(sileht): compare_digest method protected for timing-attacks
+    # exists since python >= 2.7.7 and python >= 3.3
+    # this a bit less-secure python fallback version
+    # taken from https://github.com/openstack/python-keystoneclient/blob/
+    # master/keystoneclient/middleware/memcache_crypt.py#L88
+    if len(first) != len(second):
+        return False
+    result = 0
+    if six.PY3 and isinstance(first, bytes) and isinstance(second, bytes):
+        for x, y in zip(first, second):
+            result |= x ^ y
+    else:
+        for x, y in zip(first, second):
+            result |= ord(x) ^ ord(y)
+    return result == 0
+
+
+if hasattr(hmac, 'compare_digest'):
+    compare_digest = hmac.compare_digest
+else:
+    compare_digest = besteffort_compare_digest
+
+
+def verify_signature(message, secret):
+    """Check the signature in the message.
+
+    Message is verified against the value computed from the rest of the
+    contents.
+    """
+    old_sig = message.get('message_signature', '')
     new_sig = compute_signature(message, secret)
-    return new_sig == old_sig
+
+    if isinstance(old_sig, six.text_type):
+        try:
+            old_sig = old_sig.encode('ascii')
+        except UnicodeDecodeError:
+            return False
+
+    return compare_digest(new_sig, old_sig)
 
 
 def meter_message_from_counter(sample, secret):
