@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -18,26 +17,26 @@
 """Base classes for storage engines
 """
 
-import abc
 import datetime
+import inspect
 import math
-import six
 
+from oslo.utils import timeutils
+import six
 from six import moves
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
-from ceilometer.openstack.common import timeutils
+import ceilometer
 
 
 def iter_period(start, end, period):
-    """Split a time from start to end in periods of a number of seconds. This
-    function yield the (start, end) time for each period composing the time
-    passed as argument.
+    """Split a time from start to end in periods of a number of seconds.
+
+    This function yields the (start, end) time for each period composing the
+    time passed as argument.
 
     :param start: When the period set start.
     :param end: When the period end starts.
     :param period: The duration of the period.
-
     """
     period_start = start
     increment = datetime.timedelta(seconds=period)
@@ -65,7 +64,7 @@ def _handle_sort_key(model_name, sort_key=None):
     if not sort_key:
         return sort_keys
     # NOTE(Fengqian): We need to put the sort key from user
-    #in the first place of sort keys list.
+    # in the first place of sort keys list.
     try:
         sort_keys.remove(sort_key)
     except ValueError:
@@ -86,8 +85,8 @@ class NoResultFound(Exception):
 class Pagination(object):
     """Class for pagination query."""
 
-    def __init__(self, limit=None, primary_sort_dir='desc', sort_keys=[],
-                 sort_dirs=[], marker_value=None):
+    def __init__(self, limit=None, primary_sort_dir='desc', sort_keys=None,
+                 sort_dirs=None, marker_value=None):
         """This puts all parameters used for paginate query together.
 
         :param limit: Maximum number of items to return;
@@ -102,25 +101,43 @@ class Pagination(object):
         self.limit = limit
         self.primary_sort_dir = primary_sort_dir
         self.marker_value = marker_value
-        self.sort_keys = sort_keys
-        self.sort_dirs = sort_dirs
+        self.sort_keys = sort_keys or []
+        self.sort_dirs = sort_dirs or []
 
 
-@six.add_metaclass(abc.ABCMeta)
-class StorageEngine(object):
-    """Base class for storage engines."""
+class Model(object):
+    """Base class for storage API models."""
 
-    @abc.abstractmethod
-    def get_connection(self, conf):
-        """Return a Connection instance based on the configuration settings."""
+    def __init__(self, **kwds):
+        self.fields = list(kwds)
+        for k, v in six.iteritems(kwds):
+            setattr(self, k, v)
+
+    def as_dict(self):
+        d = {}
+        for f in self.fields:
+            v = getattr(self, f)
+            if isinstance(v, Model):
+                v = v.as_dict()
+            elif isinstance(v, list) and v and isinstance(v[0], Model):
+                v = [sub.as_dict() for sub in v]
+            d[f] = v
+        return d
+
+    def __eq__(self, other):
+        return self.as_dict() == other.as_dict()
+
+    @classmethod
+    def get_field_names(cls):
+        fields = inspect.getargspec(cls.__init__)[0]
+        return set(fields) - set(["self"])
 
 
 class Connection(object):
     """Base class for storage system connections."""
 
-    """A dictionary representing the capabilities of this driver.
-    """
-    DEFAULT_CAPABILITIES = {
+    # A dictionary representing the capabilities of this driver.
+    CAPABILITIES = {
         'meters': {'pagination': False,
                    'query': {'simple': False,
                              'metadata': False,
@@ -149,16 +166,16 @@ class Connection(object):
                                            'stddev': False,
                                            'cardinality': False}}
                        },
-        'alarms': {'query': {'simple': False,
-                             'complex': False},
-                   'history': {'query': {'simple': False,
-                                         'complex': False}}},
         'events': {'query': {'simple': False}},
     }
 
-    @staticmethod
-    def __init__(conf):
+    STORAGE_CAPABILITIES = {
+        'storage': {'production_ready': False},
+    }
+
+    def __init__(self, url):
         """Constructor."""
+        pass
 
     @staticmethod
     def upgrade():
@@ -173,42 +190,28 @@ class Connection(object):
 
         All timestamps must be naive utc datetime object.
         """
-        raise NotImplementedError('Projects not implemented')
+        raise ceilometer.NotImplementedError(
+            'Recording metering data is not implemented')
 
     @staticmethod
     def clear_expired_metering_data(ttl):
-        """Clear expired data from the backend storage system according to the
-        time-to-live.
+        """Clear expired data from the backend storage system.
+
+        Clearing occurs according to the time-to-live.
 
         :param ttl: Number of seconds to keep records for.
-
         """
-        raise NotImplementedError('Clearing samples not implemented')
-
-    @staticmethod
-    def get_users(source=None):
-        """Return an iterable of user id strings.
-
-        :param source: Optional source filter.
-        """
-        raise NotImplementedError('Users not implemented')
-
-    @staticmethod
-    def get_projects(source=None):
-        """Return an iterable of project id strings.
-
-        :param source: Optional source filter.
-        """
-        raise NotImplementedError('Projects not implemented')
+        raise ceilometer.NotImplementedError(
+            'Clearing samples not implemented')
 
     @staticmethod
     def get_resources(user=None, project=None, source=None,
                       start_timestamp=None, start_timestamp_op=None,
                       end_timestamp=None, end_timestamp_op=None,
-                      metaquery={}, resource=None, pagination=None):
-        """Return an iterable of models.Resource instances containing
-        resource information.
+                      metaquery=None, resource=None, pagination=None):
+        """Return an iterable of models.Resource instances.
 
+        Iterable items containing resource information.
         :param user: Optional ID for user that owns the resource.
         :param project: Optional ID for project that owns the resource.
         :param source: Optional source filter.
@@ -220,14 +223,14 @@ class Connection(object):
         :param resource: Optional resource filter.
         :param pagination: Optional pagination query.
         """
-        raise NotImplementedError('Resources not implemented')
+        raise ceilometer.NotImplementedError('Resources not implemented')
 
     @staticmethod
     def get_meters(user=None, project=None, resource=None, source=None,
-                   metaquery={}, pagination=None):
-        """Return an iterable of model.Meter instances containing meter
-        information.
+                   metaquery=None, pagination=None):
+        """Return an iterable of model.Meter instances.
 
+        Iterable items containing meter information.
         :param user: Optional ID for user that owns the resource.
         :param project: Optional ID for project that owns the resource.
         :param resource: Optional resource filter.
@@ -235,7 +238,7 @@ class Connection(object):
         :param metaquery: Optional dict with metadata to match on.
         :param pagination: Optional pagination query.
         """
-        raise NotImplementedError('Meters not implemented')
+        raise ceilometer.NotImplementedError('Meters not implemented')
 
     @staticmethod
     def get_samples(sample_filter, limit=None):
@@ -244,7 +247,7 @@ class Connection(object):
         :param sample_filter: Filter.
         :param limit: Maximum number of results to return.
         """
-        raise NotImplementedError('Samples not implemented')
+        raise ceilometer.NotImplementedError('Samples not implemented')
 
     @staticmethod
     def get_meter_statistics(sample_filter, period=None, groupby=None,
@@ -253,66 +256,7 @@ class Connection(object):
 
         The filter must have a meter value set.
         """
-        raise NotImplementedError('Statistics not implemented')
-
-    @staticmethod
-    def get_alarms(name=None, user=None,
-                   project=None, enabled=None, alarm_id=None, pagination=None):
-        """Yields a lists of alarms that match filters."""
-        raise NotImplementedError('Alarms not implemented')
-
-    @staticmethod
-    def create_alarm(alarm):
-        """Create an alarm. Returns the alarm as created.
-
-        :param alarm: The alarm to create.
-        """
-        raise NotImplementedError('Alarms not implemented')
-
-    @staticmethod
-    def update_alarm(alarm):
-        """Update alarm."""
-        raise NotImplementedError('Alarms not implemented')
-
-    @staticmethod
-    def delete_alarm(alarm_id):
-        """Delete an alarm."""
-        raise NotImplementedError('Alarms not implemented')
-
-    @staticmethod
-    def get_alarm_changes(alarm_id, on_behalf_of,
-                          user=None, project=None, type=None,
-                          start_timestamp=None, start_timestamp_op=None,
-                          end_timestamp=None, end_timestamp_op=None):
-        """Yields list of AlarmChanges describing alarm history
-
-        Changes are always sorted in reverse order of occurrence, given
-        the importance of currency.
-
-        Segregation for non-administrative users is done on the basis
-        of the on_behalf_of parameter. This allows such users to have
-        visibility on both the changes initiated by themselves directly
-        (generally creation, rule changes, or deletion) and also on those
-        changes initiated on their behalf by the alarming service (state
-        transitions after alarm thresholds are crossed).
-
-        :param alarm_id: ID of alarm to return changes for
-        :param on_behalf_of: ID of tenant to scope changes query (None for
-                             administrative user, indicating all projects)
-        :param user: Optional ID of user to return changes for
-        :param project: Optional ID of project to return changes for
-        :project type: Optional change type
-        :param start_timestamp: Optional modified timestamp start range
-        :param start_timestamp_op: Optional timestamp start range operation
-        :param end_timestamp: Optional modified timestamp end range
-        :param end_timestamp_op: Optional timestamp end range operation
-        """
-        raise NotImplementedError('Alarm history not implemented')
-
-    @staticmethod
-    def record_alarm_change(alarm_change):
-        """Record alarm change event."""
-        raise NotImplementedError('Alarm history not implemented')
+        raise ceilometer.NotImplementedError('Statistics not implemented')
 
     @staticmethod
     def clear():
@@ -324,40 +268,38 @@ class Connection(object):
 
         :param events: a list of model.Event objects.
         """
-        raise NotImplementedError('Events not implemented.')
+        raise ceilometer.NotImplementedError('Events not implemented.')
 
     @staticmethod
     def get_events(event_filter):
-        """Return an iterable of model.Event objects.
-        """
-        raise NotImplementedError('Events not implemented.')
+        """Return an iterable of model.Event objects."""
+        raise ceilometer.NotImplementedError('Events not implemented.')
 
     @staticmethod
     def get_event_types():
-        """Return all event types as an iterable of strings.
-        """
-        raise NotImplementedError('Events not implemented.')
+        """Return all event types as an iterable of strings."""
+        raise ceilometer.NotImplementedError('Events not implemented.')
 
     @staticmethod
     def get_trait_types(event_type):
-        """Return a dictionary containing the name and data type of
-        the trait type. Only trait types for the provided event_type are
-        returned.
+        """Return a dictionary containing the name and data type of the trait.
 
+        Only trait types for the provided event_type are
+        returned.
         :param event_type: the type of the Event
         """
-        raise NotImplementedError('Events not implemented.')
+        raise ceilometer.NotImplementedError('Events not implemented.')
 
     @staticmethod
     def get_traits(event_type, trait_type=None):
-        """Return all trait instances associated with an event_type. If
-        trait_type is specified, only return instances of that trait type.
+        """Return all trait instances associated with an event_type.
 
+        If trait_type is specified, only return instances of that trait type.
         :param event_type: the type of the Event to filter by
         :param trait_type: the name of the Trait to filter by
         """
 
-        raise NotImplementedError('Events not implemented.')
+        raise ceilometer.NotImplementedError('Events not implemented.')
 
     @staticmethod
     def query_samples(filter_expr=None, orderby=None, limit=None):
@@ -368,35 +310,18 @@ class Connection(object):
         :param limit: Maximum number of results to return.
         """
 
-        raise NotImplementedError('Complex query for samples '
-                                  'is not implemented.')
+        raise ceilometer.NotImplementedError('Complex query for samples '
+                                             'is not implemented.')
 
-    @staticmethod
-    def query_alarms(filter_expr=None, orderby=None, limit=None):
-        """Return an iterable of model.Alarm objects.
+    @classmethod
+    def get_capabilities(cls):
+        """Return an dictionary with the capabilities of each driver."""
+        return cls.CAPABILITIES
 
-        :param filter_expr: Filter expression for query.
-        :param orderby: List of field name and direction pairs for order by.
-        :param limit: Maximum number of results to return.
+    @classmethod
+    def get_storage_capabilities(cls):
+        """Return a dictionary representing the performance capabilities.
+
+        This is needed to evaluate the performance of each driver.
         """
-
-        raise NotImplementedError('Complex query for alarms '
-                                  'is not implemented.')
-
-    @staticmethod
-    def query_alarm_history(filter_expr=None, orderby=None, limit=None):
-        """Return an iterable of model.AlarmChange objects.
-
-        :param filter_expr: Filter expression for query.
-        :param orderby: List of field name and direction pairs for order by.
-        :param limit: Maximum number of results to return.
-        """
-
-        raise NotImplementedError('Complex query for alarms '
-                                  'history is not implemented.')
-
-    @staticmethod
-    def get_capabilities():
-        """Return an dictionary representing the capabilities of this driver.
-        """
-        raise NotImplementedError('Capabilities not implemented.')
+        return cls.STORAGE_CAPABILITIES
