@@ -1,7 +1,6 @@
-# -*- encoding: utf-8 -*-
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
-# Copyright © 2013 eNovance
-# Copyright © 2013 IBM Corp
+# Copyright 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2013 eNovance
+# Copyright 2013 IBM Corp
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #         Julien Danjou <julien@danjou.info>
@@ -29,33 +28,37 @@ import sys
 
 import bson.code
 import bson.objectid
+from oslo.utils import timeutils
 import pymongo
+import six
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+import ceilometer
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import timeutils
 from ceilometer import storage
 from ceilometer.storage import base
 from ceilometer.storage import models
+from ceilometer.storage.mongo import utils as pymongo_utils
 from ceilometer.storage import pymongo_base
 from ceilometer import utils
 
 LOG = log.getLogger(__name__)
 
 
-class DB2Storage(base.StorageEngine):
+AVAILABLE_CAPABILITIES = {
+    'resources': {'query': {'simple': True,
+                            'metadata': True}},
+    'statistics': {'groupby': True,
+                   'query': {'simple': True,
+                             'metadata': True},
+                   'aggregation': {'standard': True}}
+}
+
+
+class Connection(pymongo_base.Connection):
     """The db2 storage for Ceilometer
 
     Collections::
 
-        - user
-          - { _id: user id
-              source: [ array of source ids reporting for the user ]
-              }
-        - project
-          - { _id: project id
-              source: [ array of source ids reporting for the project ]
-              }
         - meter
           - the raw incoming data
         - resource
@@ -69,35 +72,9 @@ class DB2Storage(base.StorageEngine):
             }
     """
 
-    def get_connection(self, conf):
-        """Return a Connection instance based on the configuration settings.
-        """
-        return Connection(conf)
-
-
-AVAILABLE_CAPABILITIES = {
-    'meters': {'query': {'simple': True,
-                         'metadata': True}},
-    'resources': {'query': {'simple': True,
-                            'metadata': True}},
-    'samples': {'query': {'simple': True,
-                          'metadata': True,
-                          'complex': True}},
-    'statistics': {'groupby': True,
-                   'query': {'simple': True,
-                             'metadata': True},
-                   'aggregation': {'standard': True}},
-    'alarms': {'query': {'simple': True,
-                         'complex': True},
-               'history': {'query': {'simple': True}}},
-}
-
-
-class Connection(pymongo_base.Connection):
-    """DB2 connection.
-    """
-
-    CONNECTION_POOL = pymongo_base.ConnectionPool()
+    CAPABILITIES = utils.update_nested(pymongo_base.Connection.CAPABILITIES,
+                                       AVAILABLE_CAPABILITIES)
+    CONNECTION_POOL = pymongo_utils.ConnectionPool()
 
     GROUP = {'_id': '$counter_name',
              'unit': {'$min': '$counter_unit'},
@@ -120,8 +97,7 @@ class Connection(pymongo_base.Connection):
 
     SECONDS_IN_A_DAY = 86400
 
-    def __init__(self, conf):
-        url = conf.database.connection
+    def __init__(self, url):
 
         # Since we are using pymongo, even though we are connecting to DB2
         # we still have to make sure that the scheme which used to distinguish
@@ -150,13 +126,10 @@ class Connection(pymongo_base.Connection):
             self.db.authenticate(connection_options['username'],
                                  connection_options['password'])
 
-        self.CAPABILITIES = utils.update_nested(self.DEFAULT_CAPABILITIES,
-                                                AVAILABLE_CAPABILITIES)
-
         self.upgrade()
 
     @classmethod
-    def _build_sort_instructions(cls, sort_keys=[], sort_dir='desc'):
+    def _build_sort_instructions(cls, sort_keys=None, sort_dir='desc'):
         """Returns a sort_instruction.
 
         Sort instructions are used in the query to determine what attributes
@@ -166,6 +139,7 @@ class Connection(pymongo_base.Connection):
         :param sort_dir: direction in which results be sorted (asc, desc).
         :return: sort parameters
         """
+        sort_keys = sort_keys or []
         sort_instructions = []
         _sort_dir = cls.SORT_OPERATION_MAP.get(
             sort_dir, cls.SORT_OPERATION_MAP['desc'])
@@ -212,20 +186,13 @@ class Connection(pymongo_base.Connection):
             self.db.resource.remove({'_id': resource_id})
             self.db.meter.remove({'_id': meter_id})
 
-            # The following code is to ensure that the keys for collections
-            # are set as objectId so that db2 index on key can be created
-            # correctly
-            user_id = str(bson.objectid.ObjectId())
-            self.db.user.insert({'_id': user_id})
-            self.db.user.remove({'_id': user_id})
-
-            project_id = str(bson.objectid.ObjectId())
-            self.db.project.insert({'_id': project_id})
-            self.db.project.remove({'_id': project_id})
+        # remove API v1 related table
+        self.db.user.drop()
+        self.db.project.drop()
 
     def clear(self):
         # db2 does not support drop_database, remove all collections
-        for col in ['user', 'project', 'resource', 'meter']:
+        for col in ['resource', 'meter']:
             self.db[col].drop()
         # drop_database command does nothing on db2 database since this has
         # not been implemented. However calling this method is important for
@@ -240,22 +207,6 @@ class Connection(pymongo_base.Connection):
         :param data: a dictionary such as returned by
                      ceilometer.meter.meter_message_from_counter
         """
-        # Make sure we know about the user and project
-        self.db.user.update(
-            {'_id': data['user_id'] or 'null'},
-            {'$addToSet': {'source': data['source'],
-                           },
-             },
-            upsert=True,
-        )
-        self.db.project.update(
-            {'_id': data['project_id']},
-            {'$addToSet': {'source': data['source'],
-                           },
-             },
-            upsert=True,
-        )
-
         # Record the updated resource metadata
         self.db.resource.update(
             {'_id': data['resource_id']},
@@ -287,7 +238,7 @@ class Connection(pymongo_base.Connection):
     def get_resources(self, user=None, project=None, source=None,
                       start_timestamp=None, start_timestamp_op=None,
                       end_timestamp=None, end_timestamp_op=None,
-                      metaquery={}, resource=None, pagination=None):
+                      metaquery=None, resource=None, pagination=None):
         """Return an iterable of models.Resource instances
 
         :param user: Optional ID for user that owns the resource.
@@ -302,7 +253,9 @@ class Connection(pymongo_base.Connection):
         :param pagination: Optional pagination query.
         """
         if pagination:
-            raise NotImplementedError('Pagination not implemented')
+            raise ceilometer.NotImplementedError('Pagination not implemented')
+
+        metaquery = metaquery or {}
 
         q = {}
         if user is not None:
@@ -315,16 +268,16 @@ class Connection(pymongo_base.Connection):
             q['resource_id'] = resource
         # Add resource_ prefix so it matches the field in the db
         q.update(dict(('resource_' + k, v)
-                      for (k, v) in metaquery.iteritems()))
+                      for (k, v) in six.iteritems(metaquery)))
 
         if start_timestamp or end_timestamp:
             # Look for resources matching the above criteria and with
             # samples in the time range we care about, then change the
             # resource query to return just those resources by id.
-            ts_range = pymongo_base.make_timestamp_range(start_timestamp,
-                                                         end_timestamp,
-                                                         start_timestamp_op,
-                                                         end_timestamp_op)
+            ts_range = pymongo_utils.make_timestamp_range(start_timestamp,
+                                                          end_timestamp,
+                                                          start_timestamp_op,
+                                                          end_timestamp_op)
             if ts_range:
                 q['timestamp'] = ts_range
 
@@ -353,20 +306,22 @@ class Connection(pymongo_base.Connection):
 
     def get_meter_statistics(self, sample_filter, period=None, groupby=None,
                              aggregate=None):
-        """Return an iterable of models.Statistics instance containing meter
-        statistics described by the query parameters.
+        """Return an iterable of models.Statistics instance.
 
-        The filter must have a meter value set.
+        Items are containing meter statistics described by the query
+        parameters. The filter must have a meter value set.
         """
         if (groupby and
                 set(groupby) - set(['user_id', 'project_id',
                                     'resource_id', 'source'])):
-            raise NotImplementedError("Unable to group by these fields")
+            raise ceilometer.NotImplementedError(
+                "Unable to group by these fields")
 
         if aggregate:
-            raise NotImplementedError('Selectable aggregates not implemented')
+            raise ceilometer.NotImplementedError(
+                'Selectable aggregates not implemented')
 
-        q = pymongo_base.make_query_from_filter(sample_filter)
+        q = pymongo_utils.make_query_from_filter(sample_filter)
 
         if period:
             if sample_filter.start:
@@ -431,16 +386,13 @@ class Connection(pymongo_base.Connection):
             if period:
                 stat.period = period
                 periods = key.get('timestamp')
-                stat.period_start = period_start + \
-                    datetime.timedelta(**(_to_offset(periods)))
-                stat.period_end = period_start + \
-                    datetime.timedelta(**(_to_offset(periods + 1)))
+                stat.period_start = (period_start +
+                                     datetime.
+                                     timedelta(**(_to_offset(periods))))
+                stat.period_end = (period_start +
+                                   datetime.
+                                   timedelta(**(_to_offset(periods + 1))))
             else:
                 stat.period_start = stat.duration_start
                 stat.period_end = stat.duration_end
             yield stat
-
-    def get_capabilities(self):
-        """Return an dictionary representing the capabilities of this driver.
-        """
-        return self.CAPABILITIES
