@@ -1,8 +1,7 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
-# Copyright © 2013 eNovance
-# Copyright © 2014 Red Hat, Inc
+# Copyright 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2013 eNovance
+# Copyright 2014 Red Hat, Inc
 #
 # Authors: Doug Hellmann <doug.hellmann@dreamhost.com>
 #          Julien Danjou <julien@danjou.info>
@@ -19,8 +18,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-"""MongoDB storage backend
-"""
+"""MongoDB storage backend"""
 
 import calendar
 import copy
@@ -31,16 +29,17 @@ import uuid
 
 import bson.code
 import bson.objectid
-import pymongo
-
 from oslo.config import cfg
+from oslo.utils import timeutils
+import pymongo
+import six
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+import ceilometer
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import timeutils
 from ceilometer import storage
 from ceilometer.storage import base
 from ceilometer.storage import models
+from ceilometer.storage.mongo import utils as pymongo_utils
 from ceilometer.storage import pymongo_base
 from ceilometer import utils
 
@@ -50,19 +49,28 @@ cfg.CONF.import_opt('time_to_live', 'ceilometer.storage',
 LOG = log.getLogger(__name__)
 
 
-class MongoDBStorage(base.StorageEngine):
+AVAILABLE_CAPABILITIES = {
+    'resources': {'query': {'simple': True,
+                            'metadata': True}},
+    'statistics': {'groupby': True,
+                   'query': {'simple': True,
+                             'metadata': True},
+                   'aggregation': {'standard': True,
+                                   'selectable': {'max': True,
+                                                  'min': True,
+                                                  'sum': True,
+                                                  'avg': True,
+                                                  'count': True,
+                                                  'stddev': True,
+                                                  'cardinality': True}}}
+}
+
+
+class Connection(pymongo_base.Connection):
     """Put the data into a MongoDB database
 
     Collections::
 
-        - user
-          - { _id: user id
-              source: [ array of source ids reporting for the user ]
-              }
-        - project
-          - { _id: project id
-              source: [ array of source ids reporting for the project ]
-              }
         - meter
           - the raw incoming data
         - resource
@@ -76,54 +84,14 @@ class MongoDBStorage(base.StorageEngine):
             }
     """
 
-    def get_connection(self, conf):
-        """Return a Connection instance based on the configuration settings.
-        """
-        return Connection(conf)
-
-
-AVAILABLE_CAPABILITIES = {
-    'meters': {'query': {'simple': True,
-                         'metadata': True}},
-    'resources': {'query': {'simple': True,
-                            'metadata': True}},
-    'samples': {'query': {'simple': True,
-                          'metadata': True,
-                          'complex': True}},
-    'statistics': {'groupby': True,
-                   'query': {'simple': True,
-                             'metadata': True},
-                   'aggregation': {'standard': True,
-                                   'selectable': {
-                                       'max': True,
-                                       'min': True,
-                                       'sum': True,
-                                       'avg': True,
-                                       'count': True,
-                                       'stddev': True,
-                                       'cardinality': True}}
-                   },
-    'alarms': {'query': {'simple': True,
-                         'complex': True},
-               'history': {'query': {'simple': True,
-                                     'complex': True}}},
-}
-
-
-class Connection(pymongo_base.Connection):
-    """MongoDB connection.
-    """
-
-    CONNECTION_POOL = pymongo_base.ConnectionPool()
+    CAPABILITIES = utils.update_nested(pymongo_base.Connection.CAPABILITIES,
+                                       AVAILABLE_CAPABILITIES)
+    CONNECTION_POOL = pymongo_utils.ConnectionPool()
 
     REDUCE_GROUP_CLEAN = bson.code.Code("""
     function ( curr, result ) {
         if (result.resources.indexOf(curr.resource_id) < 0)
             result.resources.push(curr.resource_id);
-        if (result.users.indexOf(curr.user_id) < 0)
-            result.users.push(curr.user_id);
-        if (result.projects.indexOf(curr.project_id) < 0)
-            result.projects.push(curr.project_id);
     }
     """)
 
@@ -418,8 +386,7 @@ class Connection(pymongo_base.Connection):
     _APOCALYPSE = datetime.datetime(year=datetime.MAXYEAR, month=12, day=31,
                                     hour=23, minute=59, second=59)
 
-    def __init__(self, conf):
-        url = conf.database.connection
+    def __init__(self, url):
 
         # NOTE(jd) Use our own connection pooling on top of the Pymongo one.
         # We need that otherwise we overflow the MongoDB instance with new
@@ -437,9 +404,6 @@ class Connection(pymongo_base.Connection):
             self.db.authenticate(connection_options['username'],
                                  connection_options['password'])
 
-        self.CAPABILITIES = utils.update_nested(self.DEFAULT_CAPABILITIES,
-                                                AVAILABLE_CAPABILITIES)
-
         # NOTE(jd) Upgrading is just about creating index, so let's do this
         # on connection to be sure at least the TTL is correcly updated if
         # needed.
@@ -477,6 +441,9 @@ class Connection(pymongo_base.Connection):
                                       sparse=True)
         self.db.meter.ensure_index([('timestamp', pymongo.DESCENDING)],
                                    name='timestamp_idx')
+        # remove API v1 related table
+        self.db.user.drop()
+        self.db.project.drop()
 
         indexes = self.db.meter.index_information()
 
@@ -513,22 +480,6 @@ class Connection(pymongo_base.Connection):
         :param data: a dictionary such as returned by
                      ceilometer.meter.meter_message_from_counter
         """
-        # Make sure we know about the user and project
-        self.db.user.update(
-            {'_id': data['user_id']},
-            {'$addToSet': {'source': data['source'],
-                           },
-             },
-            upsert=True,
-        )
-        self.db.project.update(
-            {'_id': data['project_id']},
-            {'$addToSet': {'source': data['source'],
-                           },
-             },
-            upsert=True,
-        )
-
         # Record the updated resource metadata - we use $setOnInsert to
         # unconditionally insert sample timestamps and resource metadata
         # (in the update case, this must be conditional on the sample not
@@ -585,11 +536,10 @@ class Connection(pymongo_base.Connection):
         self.db.meter.insert(record)
 
     def clear_expired_metering_data(self, ttl):
-        """Clear expired data from the backend storage system according to the
-        time-to-live.
+        """Clear expired data from the backend storage system.
 
+        Clearing occurs according to the time-to-live.
         :param ttl: Number of seconds to keep records for.
-
         """
         results = self.db.meter.group(
             key={},
@@ -597,13 +547,9 @@ class Connection(pymongo_base.Connection):
             reduce=self.REDUCE_GROUP_CLEAN,
             initial={
                 'resources': [],
-                'users': [],
-                'projects': [],
             }
         )[0]
 
-        self.db.user.remove({'_id': {'$nin': results['users']}})
-        self.db.project.remove({'_id': {'$nin': results['projects']}})
         self.db.resource.remove({'_id': {'$nin': results['resources']}})
 
     @staticmethod
@@ -639,7 +585,7 @@ class Connection(pymongo_base.Connection):
         return dict(criteria_equ, ** criteria_cmp)
 
     @classmethod
-    def _build_paginate_query(cls, marker, sort_keys=[], sort_dir='desc'):
+    def _build_paginate_query(cls, marker, sort_keys=None, sort_dir='desc'):
         """Returns a query with sorting / pagination.
 
         Pagination works by requiring sort_key and sort_dir.
@@ -653,20 +599,22 @@ class Connection(pymongo_base.Connection):
         :return: sort parameters, query to use
         """
         all_sort = []
+        sort_keys = sort_keys or []
         all_sort, _op = cls._build_sort_instructions(sort_keys, sort_dir)
 
         if marker is not None:
             sort_criteria_list = []
 
             for i in range(len(sort_keys)):
-                #NOTE(fengqian): Generate the query criteria recursively.
-                #sort_keys=[k1, k2, k3], maker_value=[v1, v2, v3]
-                #sort_flags = ['$lt', '$gt', 'lt'].
-                #The query criteria should be
-                #{'k3': {'$lt': 'v3'}, 'k2': {'eq': 'v2'}, 'k1': {'eq': 'v1'}},
-                #{'k2': {'$gt': 'v2'}, 'k1': {'eq': 'v1'}},
-                #{'k1': {'$lt': 'v1'}} with 'OR' operation.
-                #Each recurse will generate one items of three.
+                # NOTE(fengqian): Generate the query criteria recursively.
+                # sort_keys=[k1, k2, k3], maker_value=[v1, v2, v3]
+                # sort_flags = ['$lt', '$gt', 'lt'].
+                # The query criteria should be
+                # {'k3': {'$lt': 'v3'}, 'k2': {'eq': 'v2'}, 'k1':
+                #     {'eq': 'v1'}},
+                # {'k2': {'$gt': 'v2'}, 'k1': {'eq': 'v1'}},
+                # {'k1': {'$lt': 'v1'}} with 'OR' operation.
+                # Each recurse will generate one items of three.
                 sort_criteria_list.append(cls._recurse_sort_keys(
                                           sort_keys[:(len(sort_keys) - i)],
                                           marker, _op))
@@ -678,7 +626,7 @@ class Connection(pymongo_base.Connection):
         return all_sort, metaquery
 
     @classmethod
-    def _build_sort_instructions(cls, sort_keys=[], sort_dir='desc'):
+    def _build_sort_instructions(cls, sort_keys=None, sort_dir='desc'):
         """Returns a sort_instruction and paging operator.
 
         Sort instructions are used in the query to determine what attributes
@@ -688,6 +636,7 @@ class Connection(pymongo_base.Connection):
         :param sort_dir: direction in which results be sorted (asc, desc).
         :return: sort instructions and paging operator
         """
+        sort_keys = sort_keys or []
         sort_instructions = []
         _sort_dir, operation = cls.SORT_OPERATION_MAPPING.get(
             sort_dir, cls.SORT_OPERATION_MAPPING['desc'])
@@ -700,12 +649,13 @@ class Connection(pymongo_base.Connection):
 
     @classmethod
     def paginate_query(cls, q, db_collection, limit=None, marker=None,
-                       sort_keys=[], sort_dir='desc'):
+                       sort_keys=None, sort_dir='desc'):
         """Returns a query result with sorting / pagination.
 
         Pagination works by requiring sort_key and sort_dir.
         We use the last item in previous page as the 'marker' for pagination.
         So we return values that follow the passed marker in the order.
+
         :param q: the query dict passed in.
         :param db_collection: Database collection that be query.
         :param limit: maximum number of items to return.
@@ -713,17 +663,19 @@ class Connection(pymongo_base.Connection):
                        results after this item.
         :param sort_keys: array of attributes by which results be sorted.
         :param sort_dir: direction in which results be sorted (asc, desc).
-        return: The query with sorting/pagination added.
+
+        :return: The query with sorting/pagination added.
         """
 
+        sort_keys = sort_keys or []
         all_sort, query = cls._build_paginate_query(marker,
                                                     sort_keys,
                                                     sort_dir)
         q.update(query)
 
-        #NOTE(Fengqian):MongoDB collection.find can not handle limit
-        #when it equals None, it will raise TypeError, so we treate
-        #None as 0 for the value of limit.
+        # NOTE(Fengqian): MongoDB collection.find can not handle limit
+        # when it equals None, it will raise TypeError, so we treat
+        # None as 0 for the value of limit.
         if limit is None:
             limit = 0
         return db_collection.find(q, limit=limit, sort=all_sort)
@@ -732,9 +684,9 @@ class Connection(pymongo_base.Connection):
                                         start_timestamp, start_timestamp_op,
                                         end_timestamp, end_timestamp_op,
                                         metaquery, resource):
-        """Return an iterable of models.Resource instances constrained
-           by sample timestamp.
+        """Return an iterable of models.Resource instances
 
+        Items are constrained by sample timestamp.
         :param query: project/user/source query
         :param start_timestamp: modified timestamp start range.
         :param start_timestamp_op: start time operator, like gt, ge.
@@ -748,7 +700,7 @@ class Connection(pymongo_base.Connection):
 
         # Add resource_ prefix so it matches the field in the db
         query.update(dict(('resource_' + k, v)
-                          for (k, v) in metaquery.iteritems()))
+                          for (k, v) in six.iteritems(metaquery)))
 
         # FIXME(dhellmann): This may not perform very well,
         # but doing any better will require changing the database
@@ -757,10 +709,10 @@ class Connection(pymongo_base.Connection):
         # Look for resources matching the above criteria and with
         # samples in the time range we care about, then change the
         # resource query to return just those resources by id.
-        ts_range = pymongo_base.make_timestamp_range(start_timestamp,
-                                                     end_timestamp,
-                                                     start_timestamp_op,
-                                                     end_timestamp_op)
+        ts_range = pymongo_utils.make_timestamp_range(start_timestamp,
+                                                      end_timestamp,
+                                                      start_timestamp_op,
+                                                      end_timestamp_op)
         if ts_range:
             query['timestamp'] = ts_range
 
@@ -792,9 +744,9 @@ class Connection(pymongo_base.Connection):
             self.db[out].drop()
 
     def _get_floating_resources(self, query, metaquery, resource):
-        """Return an iterable of models.Resource instances unconstrained
-           by timestamp.
+        """Return an iterable of models.Resource instances
 
+        Items are unconstrained by timestamp.
         :param query: project/user/source query
         :param metaquery: dict with metadata to match on.
         :param resource: resource filter.
@@ -803,7 +755,7 @@ class Connection(pymongo_base.Connection):
             query['_id'] = resource
 
         query.update(dict((k, v)
-                          for (k, v) in metaquery.iteritems()))
+                          for (k, v) in six.iteritems(metaquery)))
 
         keys = base._handle_sort_key('resource')
         sort_keys = ['last_sample_timestamp' if i == 'timestamp' else i
@@ -825,7 +777,7 @@ class Connection(pymongo_base.Connection):
     def get_resources(self, user=None, project=None, source=None,
                       start_timestamp=None, start_timestamp_op=None,
                       end_timestamp=None, end_timestamp_op=None,
-                      metaquery={}, resource=None, pagination=None):
+                      metaquery=None, resource=None, pagination=None):
         """Return an iterable of models.Resource instances
 
         :param user: Optional ID for user that owns the resource.
@@ -840,7 +792,9 @@ class Connection(pymongo_base.Connection):
         :param pagination: Optional pagination query.
         """
         if pagination:
-            raise NotImplementedError('Pagination not implemented')
+            raise ceilometer.NotImplementedError('Pagination not implemented')
+
+        metaquery = metaquery or {}
 
         query = {}
         if user is not None:
@@ -884,25 +838,26 @@ class Connection(pymongo_base.Connection):
                 params = dict(aggregate_param=a.param)
                 fragments += (fragment_map[a.func] % params)
             else:
-                raise NotImplementedError('Selectable aggregate function %s'
-                                          ' is not supported' % a.func)
+                raise ceilometer.NotImplementedError(
+                    'Selectable aggregate function %s'
+                    ' is not supported' % a.func)
 
         return fragments
 
     def get_meter_statistics(self, sample_filter, period=None, groupby=None,
                              aggregate=None):
-        """Return an iterable of models.Statistics instance containing meter
-        statistics described by the query parameters.
-
-        The filter must have a meter value set.
+        """Return an iterable of models.Statistics instance.
 
+        Items are containing meter statistics described by the query
+        parameters. The filter must have a meter value set.
         """
         if (groupby and
                 set(groupby) - set(['user_id', 'project_id',
                                     'resource_id', 'source'])):
-            raise NotImplementedError("Unable to group by these fields")
+            raise ceilometer.NotImplementedError(
+                "Unable to group by these fields")
 
-        q = pymongo_base.make_query_from_filter(sample_filter)
+        q = pymongo_utils.make_query_from_filter(sample_filter)
 
         if period:
             if sample_filter.start:
@@ -989,8 +944,3 @@ class Connection(pymongo_base.Connection):
         stats_args['groupby'] = (dict(
             (g, result['groupby'][g]) for g in groupby) if groupby else None)
         return models.Statistics(**stats_args)
-
-    def get_capabilities(self):
-        """Return an dictionary representing the capabilities of this driver.
-        """
-        return self.CAPABILITIES
