@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance SAS <licensing@enovance.com>
+# Copyright 2013 eNovance SAS <licensing@enovance.com>
 #
 # Author: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
 #
@@ -37,8 +36,8 @@ def _convert_data_type(table, col, from_t, to_t, pk_attr='id'):
 
     query = sa.select([key_attr, orig_col])
     for key, value in migration.paged(query):
-        table.update().where(key_attr == key)\
-            .values({temp_col_n: value}).execute()
+        (table.update().where(key_attr == key).values({temp_col_n: value}).
+         execute())
 
     orig_col.drop()
     new_col.alter(name=col)
