@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Red Hat, Inc
+# Copyright 2013 Red Hat, Inc
 #
 # Author: Eoghan Glynn <eglynn@redhat.com>
 #
@@ -22,11 +21,11 @@ import mock
 import pytz
 import uuid
 
+from oslo.utils import timeutils
 from six import moves
 
 from ceilometer.alarm.evaluator import threshold
-from ceilometer.openstack.common import timeutils
-from ceilometer.storage import models
+from ceilometer.alarm.storage import models
 from ceilometer.tests.alarm.evaluator import base
 from ceilometerclient import exc
 from ceilometerclient.v2 import statistics
@@ -234,8 +233,8 @@ class TestEvaluate(base.TestEvaluatorBase):
             self._assert_all_alarms('ok')
             self.assertEqual([],
                              self.api_client.alarms.set_state.call_args_list)
-            reason = 'Remaining as ok due to 4 samples inside' \
-                     ' threshold, most recent: 8.0'
+            reason = ('Remaining as ok due to 4 samples inside'
+                      ' threshold, most recent: 8.0')
             reason_datas = self._reason_data('inside', 4, 8.0)
             expected = [mock.call(self.alarms[1], 'ok', reason, reason_datas)]
             self.assertEqual(expected, self.notifier.notify.call_args_list)
@@ -256,8 +255,8 @@ class TestEvaluate(base.TestEvaluatorBase):
             self._assert_all_alarms('alarm')
             self.assertEqual([],
                              self.api_client.alarms.set_state.call_args_list)
-            reason = 'Remaining as alarm due to 4 samples outside' \
-                     ' threshold, most recent: 7.0'
+            reason = ('Remaining as alarm due to 4 samples outside'
+                      ' threshold, most recent: 7.0')
             reason_datas = self._reason_data('outside', 4, 7.0)
             expected = [mock.call(self.alarms[1], 'alarm',
                                   reason, reason_datas)]
@@ -322,16 +321,17 @@ class TestEvaluate(base.TestEvaluatorBase):
         alarm = self.alarms[0]
         if exclude_outliers is not None:
             alarm.rule['exclude_outliers'] = exclude_outliers
-        timeutils.utcnow.override_time = datetime.datetime(2012, 7, 2, 10, 45)
-        constraint = self.evaluator._bound_duration(alarm, [])
-        self.assertEqual([
-            {'field': 'timestamp',
-             'op': 'le',
-             'value': timeutils.utcnow().isoformat()},
-            {'field': 'timestamp',
-             'op': 'ge',
-             'value': start},
-        ], constraint)
+        with mock.patch.object(timeutils, 'utcnow') as mock_utcnow:
+            mock_utcnow.return_value = datetime.datetime(2012, 7, 2, 10, 45)
+            constraint = self.evaluator._bound_duration(alarm, [])
+            self.assertEqual([
+                {'field': 'timestamp',
+                 'op': 'le',
+                 'value': timeutils.utcnow().isoformat()},
+                {'field': 'timestamp',
+                 'op': 'ge',
+                 'value': start},
+            ], constraint)
 
     def test_bound_duration_outlier_exclusion_defaulted(self):
         self._do_test_bound_duration('2012-07-02T10:39:00')
@@ -448,7 +448,8 @@ class TestEvaluate(base.TestEvaluatorBase):
     def test_simple_alarm_no_clear_without_outlier_exclusion(self):
         self. _do_test_simple_alarm_clear_outlier_exclusion(False)
 
-    def test_state_change_inside_time_constraint(self):
+    @mock.patch.object(timeutils, 'utcnow')
+    def test_state_change_inside_time_constraint(self, mock_utcnow):
         self._set_all_alarms('ok')
         self.alarms[0].time_constraints = [
             {'name': 'test',
@@ -460,9 +461,9 @@ class TestEvaluate(base.TestEvaluatorBase):
         self.alarms[1].time_constraints = self.alarms[0].time_constraints
         dt = datetime.datetime(2014, 1, 1, 12, 0, 0,
                                tzinfo=pytz.timezone('Europe/Ljubljana'))
+        mock_utcnow.return_value = dt.astimezone(pytz.UTC)
         with mock.patch('ceilometerclient.client.get_client',
                         return_value=self.api_client):
-            timeutils.set_time_override(dt.astimezone(pytz.UTC))
             # the following part based on test_simple_insufficient
             self.api_client.statistics.list.return_value = []
             self._evaluate_all_alarms()
@@ -485,7 +486,8 @@ class TestEvaluate(base.TestEvaluatorBase):
                 for alarm in self.alarms]
             self.assertEqual(expected, self.notifier.notify.call_args_list)
 
-    def test_no_state_change_outside_time_constraint(self):
+    @mock.patch.object(timeutils, 'utcnow')
+    def test_no_state_change_outside_time_constraint(self, mock_utcnow):
         self._set_all_alarms('ok')
         self.alarms[0].time_constraints = [
             {'name': 'test',
@@ -497,9 +499,9 @@ class TestEvaluate(base.TestEvaluatorBase):
         self.alarms[1].time_constraints = self.alarms[0].time_constraints
         dt = datetime.datetime(2014, 1, 1, 15, 0, 0,
                                tzinfo=pytz.timezone('Europe/Ljubljana'))
+        mock_utcnow.return_value = dt.astimezone(pytz.UTC)
         with mock.patch('ceilometerclient.client.get_client',
                         return_value=self.api_client):
-            timeutils.set_time_override(dt.astimezone(pytz.UTC))
             self.api_client.statistics.list.return_value = []
             self._evaluate_all_alarms()
             self._assert_all_alarms('ok')
