@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Red Hat, Inc
+# Copyright 2013 Red Hat, Inc
 #
 # Author: Eoghan Glynn <eglynn@redhat.com>
 #
@@ -19,43 +18,66 @@
 """
 import datetime
 import logging
-import six
 import uuid
 
 import mock
+from oslo.config import fixture as fixture_config
+from oslo.utils import timeutils
 from six import moves
 
 from ceilometer.alarm.partition import coordination
-from ceilometer.openstack.common.fixture import config
-from ceilometer.openstack.common import test
-from ceilometer.openstack.common import timeutils
-from ceilometer.storage import models
+from ceilometer.alarm.storage import models
+from ceilometer.tests import base as tests_base
 
 
-class TestCoordinate(test.BaseTestCase):
+class MockLoggingHandler(logging.Handler):
+    """Mock logging handler to check for expected logs."""
+
+    def __init__(self, *args, **kwargs):
+        self.reset()
+        logging.Handler.__init__(self, *args, **kwargs)
+
+    def emit(self, record):
+        self.messages[record.levelname.lower()].append(record.getMessage())
+
+    def reset(self):
+        self.messages = {'debug': [],
+                         'info': [],
+                         'warning': [],
+                         'error': [],
+                         'critical': []}
+
+
+class TestCoordinate(tests_base.BaseTestCase):
     def setUp(self):
         super(TestCoordinate, self).setUp()
-        self.CONF = self.useFixture(config.Config()).conf
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.setup_messaging(self.CONF)
+
         self.test_interval = 120
+        self.CONF.import_opt('evaluation_interval',
+                             'ceilometer.alarm.service',
+                             group='alarm')
         self.CONF.set_override('evaluation_interval',
                                self.test_interval,
                                group='alarm')
         self.api_client = mock.Mock()
         self.override_start = datetime.datetime(2012, 7, 2, 10, 45)
-        timeutils.utcnow.override_time = self.override_start
+        patcher = mock.patch.object(timeutils, 'utcnow')
+        self.addCleanup(patcher.stop)
+        self.mock_utcnow = patcher.start()
+        self.mock_utcnow.return_value = self.override_start
         self.partition_coordinator = coordination.PartitionCoordinator()
         self.partition_coordinator.coordination_rpc = mock.Mock()
-        #add extra logger to check exception conditions and logged content
-        self.output = six.moves.StringIO()
-        self.str_handler = logging.StreamHandler(self.output)
+        # add extra logger to check exception conditions and logged content
+        self.str_handler = MockLoggingHandler()
         coordination.LOG.logger.addHandler(self.str_handler)
 
     def tearDown(self):
         super(TestCoordinate, self).tearDown()
-        timeutils.utcnow.override_time = None
         # clean up the logger
         coordination.LOG.logger.removeHandler(self.str_handler)
-        self.output.close()
+        self.str_handler.close()
 
     def _no_alarms(self):
         self.api_client.alarms.list.return_value = []
@@ -112,7 +134,7 @@ class TestCoordinate(test.BaseTestCase):
 
     def _advance_time(self, factor):
         delta = datetime.timedelta(seconds=self.test_interval * factor)
-        timeutils.utcnow.override_time += delta
+        self.mock_utcnow.return_value = timeutils.utcnow() + delta
 
     def _younger_by(self, offset):
         return self.partition_coordinator.this.priority + offset
@@ -129,14 +151,14 @@ class TestCoordinate(test.BaseTestCase):
         younger = self._younger_by(offset)
         pid = uuid.uuid4()
         self.partition_coordinator.presence(pid, younger)
-        return (pid, younger)
+        return pid, younger
 
     def _check_assignments(self, others, alarm_ids, per_worker,
-                           expect_uneffected=[]):
+                           expect_uneffected=None):
         rpc = self.partition_coordinator.coordination_rpc
         calls = rpc.assign.call_args_list
         return self._check_distribution(others, alarm_ids, per_worker, calls,
-                                        expect_uneffected)
+                                        expect_uneffected or [])
 
     def _check_allocation(self, others, alarm_ids, per_worker):
         rpc = self.partition_coordinator.coordination_rpc
@@ -144,7 +166,8 @@ class TestCoordinate(test.BaseTestCase):
         return self._check_distribution(others, alarm_ids, per_worker, calls)
 
     def _check_distribution(self, others, alarm_ids, per_worker, calls,
-                            expect_uneffected=[]):
+                            expect_uneffected=None):
+        expect_uneffected = expect_uneffected or []
         uneffected = [pid for pid, _ in others]
         uneffected.extend(expect_uneffected)
         remainder = list(alarm_ids)
@@ -403,24 +426,26 @@ class TestCoordinate(test.BaseTestCase):
         self.partition_coordinator._is_master = mock.Mock(
             side_effect=Exception('Boom!'))
         self.partition_coordinator.check_mastership(10, None)
-        self.assertTrue('mastership check failed' in self.output.getvalue())
+        self.assertIn('mastership check failed',
+                      self.str_handler.messages['error'])
 
     def test_report_presence(self):
         self.partition_coordinator.coordination_rpc.presence = mock.Mock(
             side_effect=Exception('Boom!'))
         self.partition_coordinator.report_presence()
-        self.assertTrue('presence reporting failed' in self.output.getvalue())
+        self.assertIn('presence reporting failed',
+                      self.str_handler.messages['error'])
 
     def test_assigned_alarms(self):
         api_client = mock.MagicMock()
-        api_client.alarms = mock.Mock(side_effect=Exception('Boom!'))
+        api_client.alarms.list = mock.Mock(side_effect=Exception('Boom!'))
         self.partition_coordinator.assignment = ['something']
         self.partition_coordinator.assigned_alarms(api_client)
-        self.assertTrue('assignment retrieval failed' in
-                        self.output.getvalue())
+        self.assertIn('assignment retrieval failed',
+                      self.str_handler.messages['error'])
 
 
-class TestPartitionIdentity(test.BaseTestCase):
+class TestPartitionIdentity(tests_base.BaseTestCase):
     def setUp(self):
         super(TestPartitionIdentity, self).setUp()
         self.id_1st = coordination.PartitionIdentity(str(uuid.uuid4()), 1)
