@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Red Hat, Inc
+# Copyright 2013 Red Hat, Inc
 #
 # Author: Eoghan Glynn <eglynn@redhat.com>
 #
@@ -18,27 +17,29 @@
 """Tests for ceilometer.alarm.service.PartitionedAlarmService.
 """
 import contextlib
-
 import mock
+from oslo.config import fixture as fixture_config
 from stevedore import extension
 
 from ceilometer.alarm import service
-from ceilometer.openstack.common.fixture import config
-from ceilometer.openstack.common import test
+from ceilometer.tests import base as tests_base
 
 
-class TestPartitionedAlarmService(test.BaseTestCase):
+class TestPartitionedAlarmService(tests_base.BaseTestCase):
     def setUp(self):
         super(TestPartitionedAlarmService, self).setUp()
+
         self.threshold_eval = mock.Mock()
         self.api_client = mock.MagicMock()
-        self.CONF = self.useFixture(config.Config()).conf
+        self.CONF = self.useFixture(fixture_config.Config()).conf
 
         self.CONF.set_override('host',
                                'fake_host')
         self.CONF.set_override('partition_rpc_topic',
                                'fake_topic',
                                group='alarm')
+        self.setup_messaging(self.CONF)
+
         self.partitioned = service.PartitionedAlarmService()
         self.partitioned.tg = mock.Mock()
         self.partitioned.partition_coordinator = mock.Mock()
@@ -54,16 +55,15 @@ class TestPartitionedAlarmService(test.BaseTestCase):
         self.partitioned.extension_manager = self.extension_mgr
 
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
-    def test_start(self):
+    def test_lifecycle(self):
         test_interval = 120
         self.CONF.set_override('evaluation_interval',
                                test_interval,
                                group='alarm')
         get_client = 'ceilometerclient.client.get_client'
-        create_conn = 'ceilometer.openstack.common.rpc.create_connection'
-        with contextlib.nested(mock.patch(get_client,
-                                          return_value=self.api_client),
-                               mock.patch(create_conn)):
+        with contextlib.nested(
+                mock.patch(get_client, return_value=self.api_client),
+                mock.patch.object(self.partitioned.rpc_server, 'start')):
             self.partitioned.start()
             pc = self.partitioned.partition_coordinator
             expected = [
@@ -82,6 +82,7 @@ class TestPartitionedAlarmService(test.BaseTestCase):
             ]
             actual = self.partitioned.tg.add_timer.call_args_list
             self.assertEqual(expected, actual)
+            self.partitioned.stop()
 
     def test_presence_reporting(self):
         priority = 42
