@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2012 Red Hat, Inc.
 # Copyright 2013 IBM Corp.
@@ -22,21 +21,15 @@
 import base64
 import datetime
 import json as jsonutils
-import logging
-import testscenarios
 import webtest.app
 
 from ceilometer.publisher import utils
 from ceilometer import sample
-from ceilometer.tests.api.v2 import FunctionalTest
+from ceilometer.tests.api import v2
 from ceilometer.tests import db as tests_db
 
-load_tests = testscenarios.load_tests_apply_scenarios
 
-LOG = logging.getLogger(__name__)
-
-
-class TestListEmptyMeters(FunctionalTest,
+class TestListEmptyMeters(v2.FunctionalTest,
                           tests_db.MixinTestsWithBackendScenarios):
 
     def test_empty(self):
@@ -44,31 +37,31 @@ class TestListEmptyMeters(FunctionalTest,
         self.assertEqual([], data)
 
 
-class TestValidateUserInput(FunctionalTest,
+class TestValidateUserInput(v2.FunctionalTest,
                             tests_db.MixinTestsWithBackendScenarios):
 
     def test_list_meters_query_float_metadata(self):
         self.assertRaises(webtest.app.AppError, self.get_json,
                           '/meters/meter.test',
                           q=[{'field': 'metadata.util',
-                          'op': 'eq',
-                          'value': '0.7.5',
-                          'type': 'float'}])
+                              'op': 'eq',
+                              'value': '0.7.5',
+                              'type': 'float'}])
         self.assertRaises(webtest.app.AppError, self.get_json,
                           '/meters/meter.test',
                           q=[{'field': 'metadata.util',
-                          'op': 'eq',
-                          'value': 'abacaba',
-                          'type': 'boolean'}])
+                              'op': 'eq',
+                              'value': 'abacaba',
+                              'type': 'boolean'}])
         self.assertRaises(webtest.app.AppError, self.get_json,
                           '/meters/meter.test',
                           q=[{'field': 'metadata.util',
-                          'op': 'eq',
-                          'value': '45.765',
-                          'type': 'integer'}])
+                              'op': 'eq',
+                              'value': '45.765',
+                              'type': 'integer'}])
 
 
-class TestListMeters(FunctionalTest,
+class TestListMeters(v2.FunctionalTest,
                      tests_db.MixinTestsWithBackendScenarios):
 
     def setUp(self):
@@ -135,6 +128,22 @@ class TestListMeters(FunctionalTest,
                                        'util': 0.75,
                                        'is_public': False},
                     source='test_source'),
+                sample.Sample(
+                    'meter.test.new',
+                    'cumulative',
+                    '',
+                    1,
+                    'user-id',
+                    'project-id',
+                    'resource-id',
+                    timestamp=datetime.datetime(2012, 7, 2, 10, 40),
+                    resource_metadata={'display_name': 'test-server',
+                                       'tag': 'self.sample3',
+                                       'size': 0,
+                                       'util': 0.75,
+                                       'is_public': False},
+                    source='test_source'),
+
                 sample.Sample(
                     'meter.mine',
                     'gauge',
@@ -154,6 +163,17 @@ class TestListMeters(FunctionalTest,
                                        'size': 0,
                                        'util': 0.58,
                                        'is_public': True},
+                    source='test_source1'),
+                sample.Sample(
+                    u'meter.accent\xe9\u0437',
+                    'gauge',
+                    '',
+                    1,
+                    'user-id4',
+                    'project-id2',
+                    'resource-id4',
+                    timestamp=datetime.datetime(2014, 7, 2, 10, 43),
+                    resource_metadata={},
                     source='test_source1')]:
             msg = utils.meter_message_from_counter(
                 cnt,
@@ -163,13 +183,14 @@ class TestListMeters(FunctionalTest,
 
     def test_list_meters(self):
         data = self.get_json('/meters')
-        self.assertEqual(4, len(data))
+        self.assertEqual(6, len(data))
         self.assertEqual(set(['resource-id',
                               'resource-id2',
                               'resource-id3',
                               'resource-id4']),
                          set(r['resource_id'] for r in data))
-        self.assertEqual(set(['meter.test', 'meter.mine']),
+        self.assertEqual(set(['meter.test', 'meter.mine', 'meter.test.new',
+                              u'meter.accent\xe9\u0437']),
                          set(r['name'] for r in data))
         self.assertEqual(set(['test_source', 'test_source1']),
                          set(r['source'] for r in data))
@@ -190,7 +211,7 @@ class TestListMeters(FunctionalTest,
 
     def test_list_samples(self):
         data = self.get_json('/samples')
-        self.assertEqual(5, len(data))
+        self.assertEqual(7, len(data))
 
     def test_query_samples_with_invalid_field_name_and_non_eq_operator(self):
         resp = self.get_json('/samples',
@@ -239,9 +260,9 @@ class TestListMeters(FunctionalTest,
     def test_list_meters_query_wrong_type_metadata(self):
         resp = self.get_json('/meters/meter.test',
                              q=[{'field': 'metadata.size',
-                             'op': 'eq',
-                             'value': '0',
-                             'type': 'blob'}],
+                                 'op': 'eq',
+                                 'value': '0',
+                                 'type': 'blob'}],
                              expect_errors=True
                              )
         expected_error_message = 'The data type blob is not supported.'
@@ -379,9 +400,9 @@ class TestListMeters(FunctionalTest,
     def test_list_meters_query_integer_metadata(self):
         data = self.get_json('/meters/meter.test',
                              q=[{'field': 'metadata.size',
-                             'op': 'eq',
-                             'value': '0',
-                             'type': 'integer'}]
+                                 'op': 'eq',
+                                 'value': '0',
+                                 'type': 'integer'}]
                              )
         self.assertEqual(2, len(data))
         self.assertEqual(set(['resource-id',
@@ -395,9 +416,9 @@ class TestListMeters(FunctionalTest,
     def test_list_meters_query_float_metadata(self):
         data = self.get_json('/meters/meter.test',
                              q=[{'field': 'metadata.util',
-                             'op': 'eq',
-                             'value': '0.75',
-                             'type': 'float'}]
+                                 'op': 'eq',
+                                 'value': '0.75',
+                                 'type': 'float'}]
                              )
         self.assertEqual(2, len(data))
         self.assertEqual(set(['resource-id',
@@ -411,9 +432,9 @@ class TestListMeters(FunctionalTest,
     def test_list_meters_query_boolean_metadata(self):
         data = self.get_json('/meters/meter.mine',
                              q=[{'field': 'metadata.is_public',
-                             'op': 'eq',
-                             'value': 'False',
-                             'type': 'boolean'}]
+                                 'op': 'eq',
+                                 'value': 'False',
+                                 'type': 'boolean'}]
                              )
         self.assertEqual(1, len(data))
         self.assertEqual(set(['resource-id2']),
@@ -427,8 +448,8 @@ class TestListMeters(FunctionalTest,
     def test_list_meters_query_string_metadata(self):
         data = self.get_json('/meters/meter.test',
                              q=[{'field': 'metadata.tag',
-                             'op': 'eq',
-                             'value': 'self.sample'}]
+                                 'op': 'eq',
+                                 'value': 'self.sample'}]
                              )
         self.assertEqual(1, len(data))
         self.assertEqual(set(['resource-id']),
@@ -462,7 +483,7 @@ class TestListMeters(FunctionalTest,
                                             'value': 'resource-id',
                                             }])
         nids = set(r['name'] for r in data)
-        self.assertEqual(set(['meter.test']), nids)
+        self.assertEqual(set(['meter.test', 'meter.test.new']), nids)
 
         sids = set(r['source'] for r in data)
         self.assertEqual(set(['test_source']), sids)
@@ -475,7 +496,7 @@ class TestListMeters(FunctionalTest,
                                             'value': 'test_source1',
                                             }])
         nids = set(r['name'] for r in data)
-        self.assertEqual(set(['meter.mine']), nids)
+        self.assertEqual(set(['meter.mine', u'meter.accent\xe9\u0437']), nids)
 
         sids = set(r['source'] for r in data)
         self.assertEqual(set(['test_source1']), sids)
@@ -530,7 +551,7 @@ class TestListMeters(FunctionalTest,
                                  'value': 'test_source_doesnt_exist',
                                  }],
                              )
-        assert not data
+        self.assertIsEmpty(data)
 
     def test_with_user(self):
         data = self.get_json('/meters',
@@ -543,7 +564,8 @@ class TestListMeters(FunctionalTest,
         self.assertEqual(set(['user-id']), uids)
 
         nids = set(r['name'] for r in data)
-        self.assertEqual(set(['meter.mine', 'meter.test']), nids)
+        self.assertEqual(set(['meter.mine', 'meter.test', 'meter.test.new']),
+                         nids)
 
         rids = set(r['resource_id'] for r in data)
         self.assertEqual(set(['resource-id', 'resource-id2']), rids)
@@ -644,6 +666,6 @@ class TestListMeters(FunctionalTest,
     def test_list_meters_meter_id(self):
         data = self.get_json('/meters')
         for i in data:
-            expected = base64.encodestring('%s+%s' % (i['resource_id'],
-                                                      i['name']))
+            meter_id = '%s+%s' % (i['resource_id'], i['name'])
+            expected = base64.encodestring(meter_id.encode('utf-8'))
             self.assertEqual(expected, i['meter_id'])
