@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -19,17 +18,13 @@
 
 import datetime
 
-import testscenarios
-
 from ceilometer.publisher import utils
 from ceilometer import sample
-from ceilometer.tests.api.v2 import FunctionalTest
+from ceilometer.tests.api import v2
 from ceilometer.tests import db as tests_db
 
-load_tests = testscenarios.load_tests_apply_scenarios
 
-
-class TestMaxProjectVolume(FunctionalTest,
+class TestMaxProjectVolume(v2.FunctionalTest,
                            tests_db.MixinTestsWithBackendScenarios):
 
     PATH = '/meters/volume.size/statistics'
@@ -127,7 +122,7 @@ class TestMaxProjectVolume(FunctionalTest,
         self.assertEqual(1, data[0]['count'])
 
 
-class TestMaxResourceVolume(FunctionalTest,
+class TestMaxResourceVolume(v2.FunctionalTest,
                             tests_db.MixinTestsWithBackendScenarios):
 
     PATH = '/meters/volume.size/statistics'
@@ -248,7 +243,7 @@ class TestMaxResourceVolume(FunctionalTest,
         self.assertEqual(1, data[0]['count'])
 
 
-class TestSumProjectVolume(FunctionalTest,
+class TestSumProjectVolume(v2.FunctionalTest,
                            tests_db.MixinTestsWithBackendScenarios):
 
     PATH = '/meters/volume.size/statistics'
@@ -348,7 +343,7 @@ class TestSumProjectVolume(FunctionalTest,
         self.assertEqual(1, data[0]['count'])
 
 
-class TestSumResourceVolume(FunctionalTest,
+class TestSumResourceVolume(v2.FunctionalTest,
                             tests_db.MixinTestsWithBackendScenarios):
 
     PATH = '/meters/volume.size/statistics'
@@ -474,7 +469,7 @@ class TestSumResourceVolume(FunctionalTest,
         self.assertEqual(1, data[0]['count'])
 
 
-class TestGroupByInstance(FunctionalTest,
+class TestGroupByInstance(v2.FunctionalTest,
                           tests_db.MixinTestsWithBackendScenarios):
 
     PATH = '/meters/instance/statistics'
@@ -1218,7 +1213,8 @@ class TestGroupByInstance(FunctionalTest,
                                      u'2013-08-01T14:00:00'])
 
 
-class TestGroupBySource(FunctionalTest,
+@tests_db.run_with('mongodb', 'hbase', 'db2')
+class TestGroupBySource(v2.FunctionalTest,
                         tests_db.MixinTestsWithBackendScenarios):
 
     # FIXME(terriyu): We have to put test_group_by_source in its own class
@@ -1227,13 +1223,6 @@ class TestGroupBySource(FunctionalTest,
     # moved to TestGroupByInstance with all the other group by statistics
     # tests.
 
-    scenarios = [
-        ('mongodb',
-         dict(database_connection=tests_db.MongoDBFakeConnectionUrl())),
-        ('hbase', dict(database_connection=tests_db.HBaseFakeConnectionUrl())),
-        ('db2', dict(database_connection=tests_db.DB2FakeConnectionUrl())),
-    ]
-
     PATH = '/meters/instance/statistics'
 
     def setUp(self):
@@ -1329,7 +1318,7 @@ class TestGroupBySource(FunctionalTest,
                 self.assertEqual(4, r['avg'])
 
 
-class TestSelectableAggregates(FunctionalTest,
+class TestSelectableAggregates(v2.FunctionalTest,
                                tests_db.MixinTestsWithBackendScenarios):
 
     PATH = '/meters/instance/statistics'
@@ -1572,7 +1561,8 @@ class TestSelectableAggregates(FunctionalTest,
                          'Bad aggregate: cardinality.injection_attack')
 
 
-class TestUnparameterizedAggregates(FunctionalTest,
+@tests_db.run_with('mongodb', 'hbase', 'db2')
+class TestUnparameterizedAggregates(v2.FunctionalTest,
                                     tests_db.MixinTestsWithBackendScenarios):
 
     # We put the stddev test case in a separate class so that we
@@ -1583,13 +1573,6 @@ class TestUnparameterizedAggregates(FunctionalTest,
     # For hbase & db2, the skip on NotImplementedError logic works
     # in the usual way.
 
-    scenarios = [
-        ('mongodb',
-         dict(database_connection=tests_db.MongoDBFakeConnectionUrl())),
-        ('hbase', dict(database_connection=tests_db.HBaseFakeConnectionUrl())),
-        ('db2', dict(database_connection=tests_db.DB2FakeConnectionUrl())),
-    ]
-
     PATH = '/meters/instance/statistics'
 
     def setUp(self):
