@@ -1,7 +1,6 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 eNovance <licensing@enovance.com>
-# Copyright © 2012 Red Hat, Inc
+# Copyright 2012 eNovance <licensing@enovance.com>
+# Copyright 2012 Red Hat, Inc
 #
 # Author: Julien Danjou <julien@danjou.info>
 # Author: Eoghan Glynn <eglynn@redhat.com>
@@ -21,10 +20,11 @@
 """
 
 import mock
+from oslotest import base
+import six
 
 from ceilometer.compute import manager
 from ceilometer.compute.pollsters import util
-from ceilometer.openstack.common import test
 
 
 class FauxInstance(object):
@@ -43,7 +43,7 @@ class FauxInstance(object):
             return default
 
 
-class TestLocationMetadata(test.BaseTestCase):
+class TestLocationMetadata(base.BaseTestCase):
 
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def setUp(self):
@@ -61,6 +61,7 @@ class TestLocationMetadata(test.BaseTestCase):
                                     'kernel_id': 'kernel id',
                                     'os_type': 'linux',
                                     'ramdisk_id': 'ramdisk id',
+                                    'status': 'active',
                                     'ephemeral_gb': 0,
                                     'root_gb': 20,
                                     'disk_gb': 20,
@@ -81,7 +82,7 @@ class TestLocationMetadata(test.BaseTestCase):
 
     def test_metadata(self):
         md = util._get_metadata_from_object(self.instance)
-        for prop, value in self.INSTANCE_PROPERTIES.iteritems():
+        for prop, value in six.iteritems(self.INSTANCE_PROPERTIES):
             if prop not in ("metadata"):
                 # Special cases
                 if prop == 'name':
@@ -98,8 +99,17 @@ class TestLocationMetadata(test.BaseTestCase):
         self.assertEqual(1, len(user_metadata))
 
     def test_metadata_empty_image(self):
-        self.INSTANCE_PROPERTIES['image'] = ''
+        self.INSTANCE_PROPERTIES['image'] = None
         self.instance = FauxInstance(**self.INSTANCE_PROPERTIES)
         md = util._get_metadata_from_object(self.instance)
+        self.assertIsNone(md['image'])
         self.assertIsNone(md['image_ref'])
         self.assertIsNone(md['image_ref_url'])
+
+    def test_metadata_image_through_conductor(self):
+        # There should be no links here, should default to None
+        self.INSTANCE_PROPERTIES['image'] = {'id': 1}
+        self.instance = FauxInstance(**self.INSTANCE_PROPERTIES)
+        md = util._get_metadata_from_object(self.instance)
+        self.assertEqual(1, md['image_ref'])
+        self.assertIsNone(md['image_ref_url'])
