@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Rackspace Hosting.
+# Copyright 2013 Rackspace Hosting.
 #
 # Author: Monsyne Dragon <mdragon@rackspace.com>
 #
@@ -308,7 +307,7 @@ class TestTraitDefinition(ConverterBase):
             jsonpath_rw.parse('(payload.test)|(payload.other)'))
 
     def test_invalid_path_config(self):
-        #test invalid jsonpath...
+        # test invalid jsonpath...
         cfg = dict(fields='payload.bogus(')
         self.assertRaises(converter.EventDefinitionException,
                           converter.TraitDefinition,
@@ -317,7 +316,7 @@ class TestTraitDefinition(ConverterBase):
                           self.fake_plugin_mgr)
 
     def test_invalid_plugin_config(self):
-        #test invalid jsonpath...
+        # test invalid jsonpath...
         cfg = dict(fields='payload.test', plugin=dict(bogus="true"))
         self.assertRaises(converter.EventDefinitionException,
                           converter.TraitDefinition,
@@ -326,7 +325,7 @@ class TestTraitDefinition(ConverterBase):
                           self.fake_plugin_mgr)
 
     def test_unknown_plugin(self):
-        #test invalid jsonpath...
+        # test invalid jsonpath...
         cfg = dict(fields='payload.test', plugin=dict(name='bogus'))
         self.assertRaises(converter.EventDefinitionException,
                           converter.TraitDefinition,
@@ -352,7 +351,7 @@ class TestTraitDefinition(ConverterBase):
         self.assertEqual(models.Trait.DATETIME_TYPE, t.trait_type)
 
     def test_invalid_type_config(self):
-        #test invalid jsonpath...
+        # test invalid jsonpath...
         cfg = dict(type='bogus', fields='payload.test')
         self.assertRaises(converter.EventDefinitionException,
                           converter.TraitDefinition,
@@ -547,7 +546,7 @@ class TestEventDefinition(ConverterBase):
         edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
         self.assertTrue(edef.is_catchall)
 
-    @mock.patch('ceilometer.openstack.common.timeutils.utcnow')
+    @mock.patch('oslo.utils.timeutils.utcnow')
     def test_extract_when(self, mock_utcnow):
         now = datetime.datetime.utcnow()
         modified = now + datetime.timedelta(minutes=1)
@@ -624,7 +623,7 @@ class TestNotificationConverter(ConverterBase):
             host='cydonia')
         self.fake_plugin_mgr = {}
 
-    @mock.patch('ceilometer.openstack.common.timeutils.utcnow')
+    @mock.patch('oslo.utils.timeutils.utcnow')
     def test_converter_missing_keys(self, mock_utcnow):
         # test a malformed notification
         now = datetime.datetime.utcnow()
