@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Rackspace Hosting.
+# Copyright 2013 Rackspace Hosting.
 #
 # Author: Monsyne Dragon <mdragon@rackspace.com>
 #
@@ -15,12 +14,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from oslotest import base
 
 from ceilometer.event import trait_plugins
-from ceilometer.openstack.common import test
 
 
-class TestSplitterPlugin(test.BaseTestCase):
+class TestSplitterPlugin(base.BaseTestCase):
 
     def setUp(self):
         super(TestSplitterPlugin, self).setUp()
@@ -67,7 +66,7 @@ class TestSplitterPlugin(test.BaseTestCase):
         self.assertIs(None, value)
 
 
-class TestBitfieldPlugin(test.BaseTestCase):
+class TestBitfieldPlugin(base.BaseTestCase):
 
     def setUp(self):
         super(TestBitfieldPlugin, self).setUp()
