@@ -13,14 +13,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import datetime
+
+from oslo.utils import timeutils
+from oslotest import base
+
 from ceilometer.network import statistics
 from ceilometer.network.statistics import driver
-from ceilometer.openstack.common import test
-from ceilometer.openstack.common import timeutils
 from ceilometer import sample
 
 
-class TestBase(test.BaseTestCase):
+class TestBase(base.BaseTestCase):
 
     def test_subclass_ok(self):
 
@@ -35,19 +38,19 @@ class TestBase(test.BaseTestCase):
     def test_subclass_ng(self):
 
         class NgSubclass1(statistics._Base):
-            '''meter_name is lost.'''
+            """meter_name is lost."""
 
             meter_type = sample.TYPE_GAUGE
             meter_unit = 'B'
 
         class NgSubclass2(statistics._Base):
-            '''meter_type is lost.'''
+            """meter_type is lost."""
 
             meter_name = 'foo'
             meter_unit = 'B'
 
         class NgSubclass3(statistics._Base):
-            '''meter_unit is lost.'''
+            """meter_unit is lost."""
 
             meter_name = 'foo'
             meter_type = sample.TYPE_GAUGE
@@ -57,7 +60,7 @@ class TestBase(test.BaseTestCase):
         self.assertRaises(TypeError, NgSubclass3)
 
 
-class TestBaseGetSamples(test.BaseTestCase):
+class TestBaseGetSamples(base.BaseTestCase):
 
     def setUp(self):
         super(TestBaseGetSamples, self).setUp()
@@ -91,7 +94,9 @@ class TestBaseGetSamples(test.BaseTestCase):
         return FakeDriver
 
     def _make_timestamps(self, count):
-        return [timeutils.isotime() for i in range(count)]
+        now = timeutils.utcnow()
+        return [timeutils.isotime(now + datetime.timedelta(seconds=i))
+                for i in range(count)]
 
     def _get_samples(self, *resources):
 
@@ -134,7 +139,7 @@ class TestBaseGetSamples(test.BaseTestCase):
         samples = self._get_samples('http://foo', 'http://bar')
 
         self.assertEqual(len(samples), 2)
-        self._assert_sample(samples[0], 1, 'a', {'spam': 'egg'}, times[2])
+        self._assert_sample(samples[0], 1, 'a', {'spam': 'egg'}, times[0])
         self._assert_sample(samples[1], 2, 'b', None, times[1])
 
     def test_get_samples_two_driver_one_resource(self):
@@ -175,3 +180,13 @@ class TestBaseGetSamples(test.BaseTestCase):
         samples = self._get_samples('http://foo')
 
         self.assertEqual(len(samples), 0)
+
+    def test_get_samples_return_no_generator(self):
+        class NoneFakeDriver(driver.Driver):
+
+            def get_sample_data(self, meter_name, parse_url, params, cache):
+                return None
+
+        self._setup_ext_mgr(http=NoneFakeDriver())
+        samples = self._get_samples('http://foo')
+        self.assertFalse(samples)
