@@ -1,7 +1,6 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 eNovance <licensing@enovance.com>
+# Copyright 2012 eNovance <licensing@enovance.com>
 #
 # Copyright 2013 IBM Corp
 # All Rights Reserved.
@@ -21,14 +20,14 @@
 # under the License.
 
 import mock
+from oslotest import base
 
 from ceilometer.central import manager
 from ceilometer.network import floatingip
 from ceilometer.openstack.common import context
-from ceilometer.openstack.common import test
 
 
-class TestFloatingIPPollster(test.BaseTestCase):
+class TestFloatingIPPollster(base.BaseTestCase):
 
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def setUp(self):
@@ -36,6 +35,9 @@ class TestFloatingIPPollster(test.BaseTestCase):
         self.addCleanup(mock.patch.stopall)
         self.context = context.get_admin_context()
         self.manager = manager.AgentManager()
+        self.manager.keystone = mock.Mock()
+        self.manager.keystone.service_catalog.get_endpoints = mock.Mock(
+            return_value={'network': mock.ANY})
         self.pollster = floatingip.FloatingIPPollster()
         fake_ips = self.fake_get_ips()
         patch_virt = mock.patch('ceilometer.nova_client.Client.'
@@ -54,6 +56,9 @@ class TestFloatingIPPollster(test.BaseTestCase):
             ips.append(ip)
         return ips
 
+    def test_default_discovery(self):
+        self.assertEqual('endpoint:compute', self.pollster.default_discovery)
+
     # FIXME(dhellmann): Is there a useful way to define this
     # test without a database?
     #
@@ -68,7 +73,7 @@ class TestFloatingIPPollster(test.BaseTestCase):
     #         assert False, 'Should have seen an error'
 
     def test_get_samples_not_empty(self):
-        samples = list(self.pollster.get_samples(self.manager, {}))
+        samples = list(self.pollster.get_samples(self.manager, {}, ['e']))
         self.assertEqual(3, len(samples))
         # It's necessary to verify all the attributes extracted by Nova
         # API /os-floating-ips to make sure they're available and correct.
@@ -85,11 +90,10 @@ class TestFloatingIPPollster(test.BaseTestCase):
         self.assertEqual("public", samples[2].resource_metadata["pool"])
 
     def test_get_meter_names(self):
-        samples = list(self.pollster.get_samples(self.manager, {}))
+        samples = list(self.pollster.get_samples(self.manager, {}, ['e']))
         self.assertEqual(set(['ip.floating']), set([s.name for s in samples]))
 
     def test_get_samples_cached(self):
-        cache = {}
-        cache['floating_ips'] = self.fake_get_ips()[:2]
-        samples = list(self.pollster.get_samples(self.manager, cache))
+        cache = {'e-floating_ips': self.fake_get_ips()[:2]}
+        samples = list(self.pollster.get_samples(self.manager, cache, ['e']))
         self.assertEqual(2, len(samples))
