@@ -1,7 +1,6 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 eNovance <licensing@enovance.com>
+# Copyright 2012 eNovance <licensing@enovance.com>
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -17,21 +16,20 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import mock
+from oslo.config import fixture as fixture_config
+from oslotest import mockpatch
 import six
 
-import mock
-import webob
-
 from ceilometer.objectstore import swift_middleware
-from ceilometer.openstack.common.fixture import config
-from ceilometer.openstack.common.fixture.mockpatch import PatchObject
-from ceilometer.openstack.common import test
 from ceilometer import pipeline
+from ceilometer.tests import base as tests_base
 
 
 class FakeApp(object):
-    def __init__(self, body=['This string is 28 bytes long']):
-        self.body = body
+    def __init__(self, body=None):
+
+        self.body = body or ['This string is 28 bytes long']
 
     def __call__(self, env, start_response):
         yield
@@ -45,7 +43,28 @@ class FakeApp(object):
             yield line
 
 
-class TestSwiftMiddleware(test.BaseTestCase):
+class FakeRequest(object):
+    """A bare bones request object
+
+    The middleware will inspect this for request method,
+    wsgi.input and headers.
+    """
+
+    def __init__(self, path, environ=None, headers=None):
+        environ = environ or {}
+        headers = headers or {}
+
+        environ['PATH_INFO'] = path
+
+        if 'wsgi.input' not in environ:
+            environ['wsgi.input'] = six.moves.cStringIO('')
+
+        for header, value in headers.iteritems():
+            environ['HTTP_%s' % header.upper()] = value
+        self.environ = environ
+
+
+class TestSwiftMiddleware(tests_base.BaseTestCase):
 
     class _faux_pipeline_manager(pipeline.PipelineManager):
         class _faux_pipeline(object):
@@ -68,22 +87,20 @@ class TestSwiftMiddleware(test.BaseTestCase):
     def setUp(self):
         super(TestSwiftMiddleware, self).setUp()
         self.pipeline_manager = self._faux_pipeline_manager()
-        self.useFixture(PatchObject(pipeline, 'setup_pipeline',
-                                    side_effect=self._fake_setup_pipeline))
-        self.CONF = self.useFixture(config.Config()).conf
+        self.useFixture(mockpatch.PatchObject(
+            pipeline, 'setup_pipeline',
+            side_effect=self._fake_setup_pipeline))
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.setup_messaging(self.CONF)
 
     @staticmethod
     def start_response(*args):
             pass
 
-    def test_rpc_setup(self):
-        swift_middleware.CeilometerMiddleware(FakeApp(), {})
-        self.assertEqual('ceilometer', self.CONF.control_exchange)
-
     def test_get(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(), {})
-        req = webob.Request.blank('/1.0/account/container/obj',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/1.0/account/container/obj',
+                          environ={'REQUEST_METHOD': 'GET'})
         resp = app(req.environ, self.start_response)
         self.assertEqual(["This string is 28 bytes long"], list(resp))
         samples = self.pipeline_manager.pipelines[0].samples
@@ -102,10 +119,11 @@ class TestSwiftMiddleware(test.BaseTestCase):
 
     def test_put(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(body=['']), {})
-        req = webob.Request.blank('/1.0/account/container/obj',
-                                  environ={'REQUEST_METHOD': 'PUT',
-                                           'wsgi.input':
-                                           six.moves.cStringIO('some stuff')})
+        req = FakeRequest(
+            '/1.0/account/container/obj',
+            environ={'REQUEST_METHOD': 'PUT',
+                     'wsgi.input':
+                     six.moves.cStringIO('some stuff')})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(2, len(samples))
@@ -123,7 +141,7 @@ class TestSwiftMiddleware(test.BaseTestCase):
 
     def test_post(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(body=['']), {})
-        req = webob.Request.blank(
+        req = FakeRequest(
             '/1.0/account/container/obj',
             environ={'REQUEST_METHOD': 'POST',
                      'wsgi.input': six.moves.cStringIO('some other stuff')})
@@ -144,8 +162,8 @@ class TestSwiftMiddleware(test.BaseTestCase):
 
     def test_head(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(body=['']), {})
-        req = webob.Request.blank('/1.0/account/container/obj',
-                                  environ={'REQUEST_METHOD': 'HEAD'})
+        req = FakeRequest('/1.0/account/container/obj',
+                          environ={'REQUEST_METHOD': 'HEAD'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(1, len(samples))
@@ -161,8 +179,8 @@ class TestSwiftMiddleware(test.BaseTestCase):
     def test_bogus_request(self):
         """Test even for arbitrary request method, this will still work."""
         app = swift_middleware.CeilometerMiddleware(FakeApp(body=['']), {})
-        req = webob.Request.blank('/1.0/account/container/obj',
-                                  environ={'REQUEST_METHOD': 'BOGUS'})
+        req = FakeRequest('/1.0/account/container/obj',
+                          environ={'REQUEST_METHOD': 'BOGUS'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
 
@@ -178,8 +196,8 @@ class TestSwiftMiddleware(test.BaseTestCase):
 
     def test_get_container(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(), {})
-        req = webob.Request.blank('/1.0/account/container',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/1.0/account/container',
+                          environ={'REQUEST_METHOD': 'GET'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(2, len(samples))
@@ -191,8 +209,8 @@ class TestSwiftMiddleware(test.BaseTestCase):
 
     def test_no_metadata_headers(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(), {})
-        req = webob.Request.blank('/1.0/account/container',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/1.0/account/container',
+                          environ={'REQUEST_METHOD': 'GET'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(2, len(samples))
@@ -208,10 +226,10 @@ class TestSwiftMiddleware(test.BaseTestCase):
         app = swift_middleware.CeilometerMiddleware(FakeApp(), {
             'metadata_headers': 'X_VAR1, x-var2, x-var3'
         })
-        req = webob.Request.blank('/1.0/account/container',
-                                  environ={'REQUEST_METHOD': 'GET'},
-                                  headers={'X_VAR1': 'value1',
-                                           'X_VAR2': 'value2'})
+        req = FakeRequest('/1.0/account/container',
+                          environ={'REQUEST_METHOD': 'GET'},
+                          headers={'X_VAR1': 'value1',
+                                   'X_VAR2': 'value2'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(2, len(samples))
@@ -228,12 +246,33 @@ class TestSwiftMiddleware(test.BaseTestCase):
                          data.resource_metadata['http_header_x_var2'])
         self.assertFalse('http_header_x_var3' in data.resource_metadata)
 
+    def test_metadata_headers_unicode(self):
+        app = swift_middleware.CeilometerMiddleware(FakeApp(), {
+            'metadata_headers': 'unicode'
+        })
+        uni = u'\xef\xbd\xa1\xef\xbd\xa5'
+        req = FakeRequest('/1.0/account/container',
+                          environ={'REQUEST_METHOD': 'GET'},
+                          headers={'UNICODE': uni})
+        list(app(req.environ, self.start_response))
+        samples = self.pipeline_manager.pipelines[0].samples
+        self.assertEqual(2, len(samples))
+        data = samples[0]
+        http_headers = [k for k in data.resource_metadata.keys()
+                        if k.startswith('http_header_')]
+        self.assertEqual(1, len(http_headers))
+        self.assertEqual('1.0', data.resource_metadata['version'])
+        self.assertEqual('container', data.resource_metadata['container'])
+        self.assertIsNone(data.resource_metadata['object'])
+        self.assertEqual(uni.encode('utf-8'),
+                         data.resource_metadata['http_header_unicode'])
+
     def test_metadata_headers_on_not_existing_header(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(), {
             'metadata_headers': 'x-var3'
         })
-        req = webob.Request.blank('/1.0/account/container',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/1.0/account/container',
+                          environ={'REQUEST_METHOD': 'GET'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(2, len(samples))
@@ -247,15 +286,15 @@ class TestSwiftMiddleware(test.BaseTestCase):
 
     def test_bogus_path(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(), {})
-        req = webob.Request.blank('//v1/account/container',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/5.0//',
+                          environ={'REQUEST_METHOD': 'GET'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(0, len(samples))
 
     def test_missing_resource_id(self):
         app = swift_middleware.CeilometerMiddleware(FakeApp(), {})
-        req = webob.Request.blank('/5.0/', environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/v1/', environ={'REQUEST_METHOD': 'GET'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(0, len(samples))
@@ -265,8 +304,8 @@ class TestSwiftMiddleware(test.BaseTestCase):
     def test_publish_sample_fail(self, mocked_publish_sample):
         mocked_publish_sample.side_effect = Exception("a exception")
         app = swift_middleware.CeilometerMiddleware(FakeApp(body=["test"]), {})
-        req = webob.Request.blank('/1.0/account/container',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/1.0/account/container',
+                          environ={'REQUEST_METHOD': 'GET'})
         resp = list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples
         self.assertEqual(0, len(samples))
@@ -276,8 +315,8 @@ class TestSwiftMiddleware(test.BaseTestCase):
     def test_reseller_prefix(self):
         # No reseller prefix set: ensure middleware uses AUTH_
         app = swift_middleware.CeilometerMiddleware(FakeApp(), {})
-        req = webob.Request.blank('/1.0/AUTH_account/container/obj',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/1.0/AUTH_account/container/obj',
+                          environ={'REQUEST_METHOD': 'GET'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples[0]
         self.assertEqual("account", samples.resource_id)
@@ -285,8 +324,8 @@ class TestSwiftMiddleware(test.BaseTestCase):
         # Custom reseller prefix set
         app = swift_middleware.CeilometerMiddleware(
             FakeApp(), {'reseller_prefix': 'CUSTOM_'})
-        req = webob.Request.blank('/1.0/CUSTOM_account/container/obj',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/1.0/CUSTOM_account/container/obj',
+                          environ={'REQUEST_METHOD': 'GET'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples[0]
         self.assertEqual("account", samples.resource_id)
@@ -295,8 +334,8 @@ class TestSwiftMiddleware(test.BaseTestCase):
         # Custom reseller prefix set, but without trailing underscore
         app = swift_middleware.CeilometerMiddleware(
             FakeApp(), {'reseller_prefix': 'CUSTOM'})
-        req = webob.Request.blank('/1.0/CUSTOM_account/container/obj',
-                                  environ={'REQUEST_METHOD': 'GET'})
+        req = FakeRequest('/1.0/CUSTOM_account/container/obj',
+                          environ={'REQUEST_METHOD': 'GET'})
         list(app(req.environ, self.start_response))
         samples = self.pipeline_manager.pipelines[0].samples[0]
         self.assertEqual("account", samples.resource_id)
