@@ -1,6 +1,6 @@
-# -*- encoding: utf-8 -*-
+# -*- coding: utf-8 -*-
 #
-# Copyright © 2013 Intel Corp.
+# Copyright 2013 Intel Corp.
 #
 # Authors: Yunhong Jiang <yunhong.jiang@intel.com>
 #          Julien Danjou <julien@danjou.info>
@@ -19,30 +19,34 @@
 
 import abc
 import datetime
+import traceback
 
+import mock
+from oslo.utils import timeutils
+from oslotest import base
+from oslotest import mockpatch
 import six
 from stevedore import extension
 
-from ceilometer.openstack.common.fixture import mockpatch
-from ceilometer.openstack.common import test
-from ceilometer.openstack.common import timeutils
 from ceilometer import pipeline
 from ceilometer import publisher
 from ceilometer.publisher import test as test_publisher
 from ceilometer import sample
 from ceilometer import transformer
 from ceilometer.transformer import accumulator
+from ceilometer.transformer import arithmetic
 from ceilometer.transformer import conversions
 
 
 @six.add_metaclass(abc.ABCMeta)
-class BasePipelineTestCase(test.BaseTestCase):
+class BasePipelineTestCase(base.BaseTestCase):
     def fake_tem_init(self):
-        """Fake a transformerManager for pipeline
-           The faked entry point setting is below:
-           update: TransformerClass
-           except: TransformerClassException
-           drop:   TransformerClassDrop
+        """Fake a transformerManager for pipeline.
+
+        The faked entry point setting is below:
+        update: TransformerClass
+        except: TransformerClassException
+        drop:   TransformerClassDrop
         """
         pass
 
@@ -52,8 +56,10 @@ class BasePipelineTestCase(test.BaseTestCase):
             'except': self.TransformerClassException,
             'drop': self.TransformerClassDrop,
             'cache': accumulator.TransformerAccumulator,
+            'aggregator': conversions.AggregatorTransformer,
             'unit_conversion': conversions.ScalingTransformer,
             'rate_of_change': conversions.RateOfChangeTransformer,
+            'arithmetic': arithmetic.ArithmeticTransformer,
         }
 
         if name in class_name_ext:
@@ -142,6 +148,15 @@ class BasePipelineTestCase(test.BaseTestCase):
 
         self._setup_pipeline_cfg()
 
+        self._reraise_exception = True
+        self.useFixture(mockpatch.Patch(
+            'ceilometer.pipeline.LOG.exception',
+            side_effect=self._handle_reraise_exception))
+
+    def _handle_reraise_exception(self, msg):
+        if self._reraise_exception:
+            raise Exception(traceback.format_exc())
+
     @abc.abstractmethod
     def _setup_pipeline_cfg(self):
         """Setup the appropriate form of pipeline config."""
@@ -418,6 +433,7 @@ class BasePipelineTestCase(test.BaseTestCase):
                          getattr(self.TransformerClass.samples[1], "name"))
 
     def test_multiple_pipeline_exception(self):
+        self._reraise_exception = False
         self._break_pipeline_cfg()
         pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
                                                     self.transformer_manager)
@@ -590,6 +606,7 @@ class BasePipelineTestCase(test.BaseTestCase):
                          getattr(publisher.samples[0], 'name'))
 
     def test_multiple_publisher_isolation(self):
+        self._reraise_exception = False
         self._set_pipeline_cfg('publishers', ['except://', 'new://'])
         pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
                                                     self.transformer_manager)
@@ -864,9 +881,9 @@ class BasePipelineTestCase(test.BaseTestCase):
 
     def _do_test_rate_of_change_conversion(self, prev, curr, type, expected,
                                            offset=1, weight=None):
-        s = "(resource_metadata.user_metadata.autoscaling_weight or 1.0)" \
-            "* (resource_metadata.non.existent or 1.0)" \
-            "* (100.0 / (10**9 * (resource_metadata.cpu_number or 1)))"
+        s = ("(resource_metadata.user_metadata.autoscaling_weight or 1.0)"
+             "* (resource_metadata.non.existent or 1.0)"
+             "* (100.0 / (10**9 * (resource_metadata.cpu_number or 1)))")
         transformer_cfg = [
             {
                 'name': 'rate_of_change',
@@ -1113,3 +1130,656 @@ class BasePipelineTestCase(test.BaseTestCase):
         meters = ('disk.read.bytes', 'disk.write.requests')
         units = ('B', 'request')
         self._do_test_rate_of_change_mapping(pipe, meters, units)
+
+    def _do_test_aggregator(self, parameters, expected_length):
+        transformer_cfg = [
+            {
+                'name': 'aggregator',
+                'parameters': parameters,
+            },
+        ]
+        self._set_pipeline_cfg('transformers', transformer_cfg)
+        self._set_pipeline_cfg('counters', ['storage.objects.incoming.bytes'])
+        counters = [
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=26,
+                unit='B',
+                user_id='test_user',
+                project_id='test_proj',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '1.0'}
+            ),
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=16,
+                unit='B',
+                user_id='test_user',
+                project_id='test_proj',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '2.0'}
+            ),
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=53,
+                unit='B',
+                user_id='test_user_bis',
+                project_id='test_proj_bis',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '1.0'}
+            ),
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=42,
+                unit='B',
+                user_id='test_user_bis',
+                project_id='test_proj_bis',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '2.0'}
+            ),
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=15,
+                unit='B',
+                user_id='test_user',
+                project_id='test_proj_bis',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '2.0'}
+            ),
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=2,
+                unit='B',
+                user_id='test_user_bis',
+                project_id='test_proj',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '3.0'}
+            ),
+        ]
+
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        pipe = pipeline_manager.pipelines[0]
+
+        pipe.publish_samples(None, counters)
+        pipe.flush(None)
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+        self.assertEqual(expected_length, len(publisher.samples))
+        return sorted(publisher.samples, key=lambda s: s.volume)
+
+    def test_aggregator_meter_type(self):
+        volumes = [1.0, 2.0, 3.0]
+        transformer_cfg = [
+            {
+                'name': 'aggregator',
+                'parameters': {'size': len(volumes) * len(sample.TYPES)}
+            },
+        ]
+        self._set_pipeline_cfg('transformers', transformer_cfg)
+        self._set_pipeline_cfg('counters',
+                               ['testgauge', 'testcumulative', 'testdelta'])
+        counters = []
+        for sample_type in sample.TYPES:
+            for volume in volumes:
+                counters.append(sample.Sample(
+                    name='test' + sample_type,
+                    type=sample_type,
+                    volume=volume,
+                    unit='B',
+                    user_id='test_user',
+                    project_id='test_proj',
+                    resource_id='test_resource',
+                    timestamp=timeutils.utcnow().isoformat(),
+                    resource_metadata={'version': '1.0'}
+                ))
+
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        pipe = pipeline_manager.pipelines[0]
+
+        pipe.publish_samples(None, counters)
+        pipe.flush(None)
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+        actual = sorted(s.volume for s in publisher.samples)
+        self.assertEqual([2.0, 3.0, 6.0], actual)
+
+    def test_aggregator_input_validation(self):
+        aggregator = conversions.AggregatorTransformer("1", "15", None,
+                                                       None, None)
+        self.assertEqual(1, aggregator.size)
+        self.assertEqual(15, aggregator.retention_time)
+
+        self.assertRaises(ValueError, conversions.AggregatorTransformer,
+                          "abc", "cde", None, None, None)
+
+    def test_aggregator_metadata(self):
+        for conf, expected_version in [('last', '2.0'), ('first', '1.0')]:
+            samples = self._do_test_aggregator({
+                'resource_metadata': conf,
+                'target': {'name': 'aggregated-bytes'}
+            }, expected_length=4)
+            s = samples[0]
+            self.assertEqual('aggregated-bytes', s.name)
+            self.assertEqual(2, s.volume)
+            self.assertEqual('test_user_bis', s.user_id)
+            self.assertEqual('test_proj', s.project_id)
+            self.assertEqual({'version': '3.0'},
+                             s.resource_metadata)
+            s = samples[1]
+            self.assertEqual('aggregated-bytes', s.name)
+            self.assertEqual(15, s.volume)
+            self.assertEqual('test_user', s.user_id)
+            self.assertEqual('test_proj_bis', s.project_id)
+            self.assertEqual({'version': '2.0'},
+                             s.resource_metadata)
+            s = samples[2]
+            self.assertEqual('aggregated-bytes', s.name)
+            self.assertEqual(42, s.volume)
+            self.assertEqual('test_user', s.user_id)
+            self.assertEqual('test_proj', s.project_id)
+            self.assertEqual({'version': expected_version},
+                             s.resource_metadata)
+            s = samples[3]
+            self.assertEqual('aggregated-bytes', s.name)
+            self.assertEqual(95, s.volume)
+            self.assertEqual('test_user_bis', s.user_id)
+            self.assertEqual('test_proj_bis', s.project_id)
+            self.assertEqual({'version': expected_version},
+                             s.resource_metadata)
+
+    def test_aggregator_user_last_and_metadata_last(self):
+        samples = self._do_test_aggregator({
+            'resource_metadata': 'last',
+            'user_id': 'last',
+            'target': {'name': 'aggregated-bytes'}
+        }, expected_length=2)
+        s = samples[0]
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(44, s.volume)
+        self.assertEqual('test_user_bis', s.user_id)
+        self.assertEqual('test_proj', s.project_id)
+        self.assertEqual({'version': '3.0'},
+                         s.resource_metadata)
+        s = samples[1]
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(110, s.volume)
+        self.assertEqual('test_user', s.user_id)
+        self.assertEqual('test_proj_bis', s.project_id)
+        self.assertEqual({'version': '2.0'},
+                         s.resource_metadata)
+
+    def test_aggregator_user_first_and_metadata_last(self):
+        samples = self._do_test_aggregator({
+            'resource_metadata': 'last',
+            'user_id': 'first',
+            'target': {'name': 'aggregated-bytes'}
+        }, expected_length=2)
+        s = samples[0]
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(44, s.volume)
+        self.assertEqual('test_user', s.user_id)
+        self.assertEqual('test_proj', s.project_id)
+        self.assertEqual({'version': '3.0'},
+                         s.resource_metadata)
+        s = samples[1]
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(110, s.volume)
+        self.assertEqual('test_user_bis', s.user_id)
+        self.assertEqual('test_proj_bis', s.project_id)
+        self.assertEqual({'version': '2.0'},
+                         s.resource_metadata)
+
+    def test_aggregator_all_first(self):
+        samples = self._do_test_aggregator({
+            'resource_metadata': 'first',
+            'user_id': 'first',
+            'project_id': 'first',
+            'target': {'name': 'aggregated-bytes'}
+        }, expected_length=1)
+        s = samples[0]
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(154, s.volume)
+        self.assertEqual('test_user', s.user_id)
+        self.assertEqual('test_proj', s.project_id)
+        self.assertEqual({'version': '1.0'},
+                         s.resource_metadata)
+
+    def test_aggregator_all_last(self):
+        samples = self._do_test_aggregator({
+            'resource_metadata': 'last',
+            'user_id': 'last',
+            'project_id': 'last',
+            'target': {'name': 'aggregated-bytes'}
+        }, expected_length=1)
+        s = samples[0]
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(154, s.volume)
+        self.assertEqual('test_user_bis', s.user_id)
+        self.assertEqual('test_proj', s.project_id)
+        self.assertEqual({'version': '3.0'},
+                         s.resource_metadata)
+
+    def test_aggregator_all_mixed(self):
+        samples = self._do_test_aggregator({
+            'resource_metadata': 'drop',
+            'user_id': 'first',
+            'project_id': 'last',
+            'target': {'name': 'aggregated-bytes'}
+        }, expected_length=1)
+        s = samples[0]
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(154, s.volume)
+        self.assertEqual('test_user', s.user_id)
+        self.assertEqual('test_proj', s.project_id)
+        self.assertEqual({}, s.resource_metadata)
+
+    def test_aggregator_metadata_default(self):
+        samples = self._do_test_aggregator({
+            'user_id': 'last',
+            'project_id': 'last',
+            'target': {'name': 'aggregated-bytes'}
+        }, expected_length=1)
+        s = samples[0]
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(154, s.volume)
+        self.assertEqual('test_user_bis', s.user_id)
+        self.assertEqual('test_proj', s.project_id)
+        self.assertEqual({'version': '3.0'},
+                         s.resource_metadata)
+
+    @mock.patch('ceilometer.transformer.conversions.LOG')
+    def test_aggregator_metadata_invalid(self, mylog):
+        samples = self._do_test_aggregator({
+            'resource_metadata': 'invalid',
+            'user_id': 'last',
+            'project_id': 'last',
+            'target': {'name': 'aggregated-bytes'}
+        }, expected_length=1)
+        s = samples[0]
+        self.assertTrue(mylog.warn.called)
+        self.assertEqual('aggregated-bytes', s.name)
+        self.assertEqual(154, s.volume)
+        self.assertEqual('test_user_bis', s.user_id)
+        self.assertEqual('test_proj', s.project_id)
+        self.assertEqual({'version': '3.0'},
+                         s.resource_metadata)
+
+    def test_aggregator_sized_flush(self):
+        transformer_cfg = [
+            {
+                'name': 'aggregator',
+                'parameters': {'size': 2},
+            },
+        ]
+        self._set_pipeline_cfg('transformers', transformer_cfg)
+        self._set_pipeline_cfg('counters', ['storage.objects.incoming.bytes'])
+        counters = [
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=26,
+                unit='B',
+                user_id='test_user',
+                project_id='test_proj',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '1.0'}
+            ),
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=16,
+                unit='B',
+                user_id='test_user_bis',
+                project_id='test_proj_bis',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '2.0'}
+            )
+        ]
+
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        pipe = pipeline_manager.pipelines[0]
+
+        pipe.publish_samples(None, [counters[0]])
+        pipe.flush(None)
+        publisher = pipe.publishers[0]
+        self.assertEqual(0, len(publisher.samples))
+
+        pipe.publish_samples(None, [counters[1]])
+        pipe.flush(None)
+        publisher = pipe.publishers[0]
+        self.assertEqual(2, len(publisher.samples))
+
+    def test_aggregator_timed_flush(self):
+        timeutils.set_time_override()
+        transformer_cfg = [
+            {
+                'name': 'aggregator',
+                'parameters': {'size': 900, 'retention_time': 60},
+            },
+        ]
+        self._set_pipeline_cfg('transformers', transformer_cfg)
+        self._set_pipeline_cfg('counters', ['storage.objects.incoming.bytes'])
+        counters = [
+            sample.Sample(
+                name='storage.objects.incoming.bytes',
+                type=sample.TYPE_DELTA,
+                volume=26,
+                unit='B',
+                user_id='test_user',
+                project_id='test_proj',
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '1.0'}
+            ),
+        ]
+
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        pipe = pipeline_manager.pipelines[0]
+
+        pipe.publish_samples(None, counters)
+        pipe.flush(None)
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+        self.assertEqual(0, len(publisher.samples))
+
+        timeutils.advance_time_seconds(120)
+        pipe.flush(None)
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+        self.assertEqual(1, len(publisher.samples))
+
+    def test_aggregator_without_authentication(self):
+        transformer_cfg = [
+            {
+                'name': 'aggregator',
+                'parameters': {'size': 2},
+            },
+        ]
+        self._set_pipeline_cfg('transformers', transformer_cfg)
+        self._set_pipeline_cfg('counters', ['storage.objects.outgoing.bytes'])
+        counters = [
+            sample.Sample(
+                name='storage.objects.outgoing.bytes',
+                type=sample.TYPE_DELTA,
+                volume=26,
+                unit='B',
+                user_id=None,
+                project_id=None,
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '1.0'}
+            ),
+            sample.Sample(
+                name='storage.objects.outgoing.bytes',
+                type=sample.TYPE_DELTA,
+                volume=16,
+                unit='B',
+                user_id=None,
+                project_id=None,
+                resource_id='test_resource',
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata={'version': '2.0'}
+            )
+        ]
+
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        pipe = pipeline_manager.pipelines[0]
+
+        pipe.publish_samples(None, [counters[0]])
+        pipe.flush(None)
+        publisher = pipe.publishers[0]
+        self.assertEqual(0, len(publisher.samples))
+
+        pipe.publish_samples(None, [counters[1]])
+        pipe.flush(None)
+        publisher = pipe.publishers[0]
+
+        self.assertEqual(1, len(publisher.samples))
+        self.assertEqual(42, getattr(publisher.samples[0], 'volume'))
+        self.assertEqual("test_resource", getattr(publisher.samples[0],
+                                                  'resource_id'))
+
+    def _do_test_arithmetic_expr_parse(self, expr, expected):
+        actual = arithmetic.ArithmeticTransformer.parse_expr(expr)
+        self.assertEqual(expected, actual)
+
+    def test_arithmetic_expr_parse(self):
+        expr = '$(cpu) + $(cpu.util)'
+        expected = ('cpu.volume + _cpu_util_ESC.volume',
+                    {
+                        'cpu': 'cpu',
+                        'cpu.util': '_cpu_util_ESC'
+                    })
+        self._do_test_arithmetic_expr_parse(expr, expected)
+
+    def test_arithmetic_expr_parse_parameter(self):
+        expr = '$(cpu) + $(cpu.util).resource_metadata'
+        expected = ('cpu.volume + _cpu_util_ESC.resource_metadata',
+                    {
+                        'cpu': 'cpu',
+                        'cpu.util': '_cpu_util_ESC'
+                    })
+        self._do_test_arithmetic_expr_parse(expr, expected)
+
+    def test_arithmetic_expr_parse_reserved_keyword(self):
+        expr = '$(class) + $(cpu.util)'
+        expected = ('_class_ESC.volume + _cpu_util_ESC.volume',
+                    {
+                        'class': '_class_ESC',
+                        'cpu.util': '_cpu_util_ESC'
+                    })
+        self._do_test_arithmetic_expr_parse(expr, expected)
+
+    def test_arithmetic_expr_parse_already_escaped(self):
+        expr = '$(class) + $(_class_ESC)'
+        expected = ('_class_ESC.volume + __class_ESC_ESC.volume',
+                    {
+                        'class': '_class_ESC',
+                        '_class_ESC': '__class_ESC_ESC'
+                    })
+        self._do_test_arithmetic_expr_parse(expr, expected)
+
+    def _do_test_arithmetic(self, expression, scenario, expected):
+        transformer_cfg = [
+            {
+                'name': 'arithmetic',
+                'parameters': {
+                    'target': {'name': 'new_meter',
+                               'unit': '%',
+                               'type': sample.TYPE_GAUGE,
+                               'expr': expression},
+                }
+            },
+        ]
+        self._set_pipeline_cfg('transformers', transformer_cfg)
+        self._set_pipeline_cfg('counters',
+                               list(set(s['name'] for s in scenario)))
+        counters = []
+        test_resources = ['test_resource1', 'test_resource2']
+        for resource_id in test_resources:
+            for s in scenario:
+                counters.append(sample.Sample(
+                    name=s['name'],
+                    type=sample.TYPE_CUMULATIVE,
+                    volume=s['volume'],
+                    unit='ns',
+                    user_id='test_user',
+                    project_id='test_proj',
+                    resource_id=resource_id,
+                    timestamp=timeutils.utcnow().isoformat(),
+                    resource_metadata=s.get('metadata')
+                ))
+
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        pipe = pipeline_manager.pipelines[0]
+
+        pipe.publish_samples(None, counters)
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+        expected_len = len(test_resources) * len(expected)
+        self.assertEqual(0, len(publisher.samples))
+        pipe.flush(None)
+        self.assertEqual(expected_len, len(publisher.samples))
+
+        # bucket samples by resource first
+        samples_by_resource = dict((r, []) for r in test_resources)
+        for s in publisher.samples:
+            samples_by_resource[s.resource_id].append(s)
+
+        for resource_id in samples_by_resource:
+            self.assertEqual(len(expected),
+                             len(samples_by_resource[resource_id]))
+            for i, s in enumerate(samples_by_resource[resource_id]):
+                self.assertEqual('new_meter', getattr(s, 'name'))
+                self.assertEqual(resource_id, getattr(s, 'resource_id'))
+                self.assertEqual('%', getattr(s, 'unit'))
+                self.assertEqual(sample.TYPE_GAUGE, getattr(s, 'type'))
+                self.assertEqual(expected[i], getattr(s, 'volume'))
+
+    def test_arithmetic_transformer(self):
+        expression = '100.0 * $(memory.usage) / $(memory)'
+        scenario = [
+            dict(name='memory', volume=1024.0),
+            dict(name='memory.usage', volume=512.0),
+        ]
+        expected = [50.0]
+        self._do_test_arithmetic(expression, scenario, expected)
+
+    def test_arithmetic_transformer_expr_empty(self):
+        expression = ''
+        scenario = [
+            dict(name='memory', volume=1024.0),
+            dict(name='memory.usage', volume=512.0),
+        ]
+        expected = []
+        self._do_test_arithmetic(expression, scenario, expected)
+
+    def test_arithmetic_transformer_expr_misconfigured(self):
+        expression = '512.0 * 3'
+        scenario = [
+            dict(name='memory', volume=1024.0),
+            dict(name='memory.usage', volume=512.0),
+        ]
+        expected = []
+        self._do_test_arithmetic(expression, scenario, expected)
+
+    def test_arithmetic_transformer_nan(self):
+        expression = 'float(\'nan\') * $(memory.usage) / $(memory)'
+        scenario = [
+            dict(name='memory', volume=1024.0),
+            dict(name='memory.usage', volume=512.0),
+        ]
+        expected = []
+        self._do_test_arithmetic(expression, scenario, expected)
+
+    def test_arithmetic_transformer_exception(self):
+        expression = '$(memory) / 0'
+        scenario = [
+            dict(name='memory', volume=1024.0),
+            dict(name='memory.usage', volume=512.0),
+        ]
+        expected = []
+        self._do_test_arithmetic(expression, scenario, expected)
+
+    def test_arithmetic_transformer_multiple_samples(self):
+        expression = '100.0 * $(memory.usage) / $(memory)'
+        scenario = [
+            dict(name='memory', volume=2048.0),
+            dict(name='memory.usage', volume=512.0),
+            dict(name='memory', volume=1024.0),
+        ]
+        expected = [50.0]
+        self._do_test_arithmetic(expression, scenario, expected)
+
+    def test_arithmetic_transformer_missing(self):
+        expression = '100.0 * $(memory.usage) / $(memory)'
+        scenario = [dict(name='memory.usage', volume=512.0)]
+        expected = []
+        self._do_test_arithmetic(expression, scenario, expected)
+
+    def test_arithmetic_transformer_more_than_needed(self):
+        expression = '100.0 * $(memory.usage) / $(memory)'
+        scenario = [
+            dict(name='memory', volume=1024.0),
+            dict(name='memory.usage', volume=512.0),
+            dict(name='cpu_util', volume=90.0),
+        ]
+        expected = [50.0]
+        self._do_test_arithmetic(expression, scenario, expected)
+
+    def test_arithmetic_transformer_cache_cleared(self):
+        transformer_cfg = [
+            {
+                'name': 'arithmetic',
+                'parameters': {
+                    'target': {'name': 'new_meter',
+                               'expr': '$(memory.usage) + 2'}
+                }
+            },
+        ]
+        self._set_pipeline_cfg('transformers', transformer_cfg)
+        self._set_pipeline_cfg('counters', ['memory.usage'])
+        counter = sample.Sample(
+            name='memory.usage',
+            type=sample.TYPE_GAUGE,
+            volume=1024.0,
+            unit='MB',
+            user_id='test_user',
+            project_id='test_proj',
+            resource_id='test_resource',
+            timestamp=timeutils.utcnow().isoformat(),
+            resource_metadata=None
+        )
+
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        pipe = pipeline_manager.pipelines[0]
+
+        pipe.publish_samples(None, [counter])
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+        self.assertEqual(0, len(publisher.samples))
+        pipe.flush(None)
+        self.assertEqual(1, len(publisher.samples))
+        self.assertEqual(1026.0, publisher.samples[0].volume)
+
+        pipe.flush(None)
+        self.assertEqual(1, len(publisher.samples))
+
+        counter.volume = 2048.0
+        pipe.publish_samples(None, [counter])
+        pipe.flush(None)
+        self.assertEqual(2, len(publisher.samples))
+        self.assertEqual(2050.0, publisher.samples[1].volume)
+
+    def test_aggregator_timed_flush_no_matching_samples(self):
+        timeutils.set_time_override()
+        transformer_cfg = [
+            {
+                'name': 'aggregator',
+                'parameters': {'size': 900, 'retention_time': 60},
+            },
+        ]
+        self._set_pipeline_cfg('transformers', transformer_cfg)
+        self._set_pipeline_cfg('counters', ['unrelated-sample'])
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        timeutils.advance_time_seconds(200)
+        pipe = pipeline_manager.pipelines[0]
+        pipe.flush(None)
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+        self.assertEqual(0, len(publisher.samples))
