@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Rackspace Hosting
+# Copyright 2013 Rackspace Hosting
 #
 # Author: Thomas Maddox <thomas.maddox@rackspace.com>
 #
@@ -19,16 +18,16 @@
 import datetime
 
 import mock
+from oslotest import base
 import sqlalchemy
 from sqlalchemy.dialects.mysql import DECIMAL
 from sqlalchemy.types import NUMERIC
 
-from ceilometer.openstack.common import test
 from ceilometer.storage.sqlalchemy import models
 from ceilometer import utils
 
 
-class PreciseTimestampTest(test.BaseTestCase):
+class PreciseTimestampTest(base.BaseTestCase):
 
     @staticmethod
     def fake_dialect(name):
