@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance
+# Copyright 2013 eNovance
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -18,11 +17,12 @@
 import datetime
 import math
 
-from ceilometer.openstack.common import test
+from oslotest import base as testbase
+
 from ceilometer.storage import base
 
 
-class BaseTest(test.BaseTestCase):
+class BaseTest(testbase.BaseTestCase):
 
     def test_iter_period(self):
         times = list(base.iter_period(
