@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Julien Danjou
+# Copyright 2013 Julien Danjou
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -20,9 +19,9 @@ from ceilometer import transformer
 
 
 class TransformerAccumulator(transformer.TransformerBase):
-    """Transformer that accumulates sample until a threshold, and then flush
-    them out in the wild.
+    """Transformer that accumulates samples until a threshold.
 
+    And then flushes them out into the wild.
     """
 
     def __init__(self, size=1, **kwargs):
