@@ -18,20 +18,44 @@
 
 """Utilities and helper functions."""
 
+import bisect
 import calendar
 import copy
 import datetime
 import decimal
+import hashlib
 import multiprocessing
+import struct
 
-from ceilometer.openstack.common import timeutils
-from ceilometer.openstack.common import units
+from ceilometer.openstack.common import processutils
+from oslo.config import cfg
+from oslo.utils import timeutils
+from oslo.utils import units
+import six
+
+
+rootwrap_conf = cfg.StrOpt('rootwrap_config',
+                           default="/etc/ceilometer/rootwrap.conf",
+                           help='Path to the rootwrap configuration file to'
+                                'use for running commands as root')
+CONF = cfg.CONF
+CONF.register_opt(rootwrap_conf)
+
+
+def _get_root_helper():
+    return 'sudo ceilometer-rootwrap %s' % CONF.rootwrap_config
+
+
+def execute(*cmd, **kwargs):
+    """Convenience wrapper around oslo's execute() method."""
+    if 'run_as_root' in kwargs and 'root_helper' not in kwargs:
+        kwargs['root_helper'] = _get_root_helper()
+    return processutils.execute(*cmd, **kwargs)
 
 
 def recursive_keypairs(d, separator=':'):
-    """Generator that produces sequence of keypairs for nested dictionaries.
-    """
-    for name, value in sorted(d.iteritems()):
+    """Generator that produces sequence of keypairs for nested dictionaries."""
+    for name, value in sorted(six.iteritems(d)):
         if isinstance(value, dict):
             for subname, subvalue in recursive_keypairs(value, separator):
                 yield ('%s%s%s' % (name, separator, subname), subvalue)
@@ -45,9 +69,9 @@ def recursive_keypairs(d, separator=':'):
             # to avoid inconsistencies in the message signature computation
             # for equivalent payloads modulo ordering
             first = lambda i: i[0]
-            m = map(lambda x: unicode(dict(sorted(x.items(), key=first))
-                                      if isinstance(x, dict)
-                                      else x).encode('utf-8'),
+            m = map(lambda x: six.text_type(dict(sorted(x.items(), key=first))
+                                            if isinstance(x, dict)
+                                            else x).encode('utf-8'),
                     value)
             yield name, list(m)
         else:
@@ -55,10 +79,9 @@ def recursive_keypairs(d, separator=':'):
 
 
 def restore_nesting(d, separator=':'):
-    """Unwinds a flattened dict to restore nesting.
-    """
+    """Unwinds a flattened dict to restore nesting."""
     d = copy.copy(d) if any([separator in k for k in d.keys()]) else d
-    for k, v in d.items():
+    for k, v in d.copy().items():
         if separator in k:
             top, rem = k.split(separator, 1)
             nest = d[top] if isinstance(d.get(top), dict) else {}
@@ -78,14 +101,13 @@ def dt_to_decimal(utc):
         return None
 
     decimal.getcontext().prec = 30
-    return decimal.Decimal(str(calendar.timegm(utc.utctimetuple()))) + \
-        (decimal.Decimal(str(utc.microsecond)) /
-         decimal.Decimal("1000000.0"))
+    return (decimal.Decimal(str(calendar.timegm(utc.utctimetuple()))) +
+            (decimal.Decimal(str(utc.microsecond)) /
+            decimal.Decimal("1000000.0")))
 
 
 def decimal_to_dt(dec):
-    """Return a datetime from Decimal unixtime format.
-    """
+    """Return a datetime from Decimal unixtime format."""
     if dec is None:
         return None
 
@@ -108,7 +130,7 @@ def stringify_timestamps(data):
     """Stringify any datetimes in given dict."""
     isa_timestamp = lambda v: isinstance(v, datetime.datetime)
     return dict((k, v.isoformat() if isa_timestamp(v) else v)
-                for (k, v) in data.iteritems())
+                for (k, v) in six.iteritems(data))
 
 
 def dict_to_keyval(value, key_base=None):
@@ -119,7 +141,7 @@ def dict_to_keyval(value, key_base=None):
     """
     val_iter, key_func = None, None
     if isinstance(value, dict):
-        val_iter = value.iteritems()
+        val_iter = six.iteritems(value)
         key_func = lambda k: key_base + '.' + k if key_base else k
     elif isinstance(value, (tuple, list)):
         val_iter = enumerate(value)
@@ -151,11 +173,12 @@ def lowercase_values(mapping):
 
 
 def update_nested(original_dict, updates):
-    """Updates the leaf nodes in a nest dict, without replacing
-       entire sub-dicts.
+    """Updates the leaf nodes in a nest dict.
+
+     Updates occur without replacing entire sub-dicts.
     """
     dict_to_update = copy.deepcopy(original_dict)
-    for key, value in updates.iteritems():
+    for key, value in six.iteritems(updates):
         if isinstance(value, dict):
             sub_dict = update_nested(dict_to_update.get(key, {}), value)
             dict_to_update[key] = sub_dict
@@ -181,3 +204,37 @@ def uniq(dupes, attrs):
             deduped.append(d)
             keys.append(key(d))
     return deduped
+
+
+def hash_of_set(s):
+    return str(hash(frozenset(s)))
+
+
+class HashRing(object):
+
+    def __init__(self, nodes, replicas=100):
+        self._ring = dict()
+        self._sorted_keys = []
+
+        for node in nodes:
+            for r in six.moves.range(replicas):
+                hashed_key = self._hash('%s-%s' % (node, r))
+                self._ring[hashed_key] = node
+                self._sorted_keys.append(hashed_key)
+        self._sorted_keys.sort()
+
+    @staticmethod
+    def _hash(key):
+        return struct.unpack_from('>I',
+                                  hashlib.md5(str(key).encode()).digest())[0]
+
+    def _get_position_on_ring(self, key):
+        hashed_key = self._hash(key)
+        position = bisect.bisect(self._sorted_keys, hashed_key)
+        return position if position < len(self._sorted_keys) else 0
+
+    def get_node(self, key):
+        if not self._ring:
+            return None
+        pos = self._get_position_on_ring(key)
+        return self._ring[self._sorted_keys[pos]]
